
%%                                                           STAGplot X1.1

%                                             plots StagYY's binary output
%    . calls f_annotations
%    . calls f_background
%    . calls f_boxPosition
%    . calls f_cbRange
%    . calls f_colormap
%    . calls f_connectivity2D
%    . calls f_defaults
%    . calls f_dimParameter
%    . calls f_emptyPlot
%    . calls f_figStyle
%    . calls f_figurePos
%    . calls f_filefinder
%    . calls f_importData
%    . calls f_legendStyle
%    . calls f_lithoThickness
%    . calls f_plateDiagnostics
%    . calls f_plot2DField
%    . calls f_plotDynTOPO
%    . calls f_plotFIELDS
%    . calls f_plotIsoline
%    . calls f_plotPlateSketch
%    . calls f_plotPlateVel
%    . calls f_plotTimeGraph
%    . calls f_plotTOPO
%    . calls f_ReadStagYY
%    . calls f_ReadStagYY2
%    . calls f_readTopo3D
%    . calls f_saveDat
%    . calls f_saveField
%    . calls f_saveFig
%    . calls f_simplify
%    . calls f_splayout
%    . calls f_startup
%    . calls f_subplotPos
%    . calls f_timeArrows
%    . calls f_trackPlumes
%    . calls f_YYtoMap
% 
%    . calls MinVolEllipse
%    . calls flowfun
%    . calls cumsimp
%                                               12.12.2015  Fabio Crameri

%% UPDATES >0
% *combining Apps to StagLab*
% *supports all available StagYY model geometries*
% *supports all available StagYY output, including rprof.dat and time.dat*
% *option added for YinYang horizontal maps*
% *hot and cold plume tracking added*
% *first test version of 3-D Cartesian plate boundary tracking implemented*
% *code speed optimisations: deriving lithosphere thickness*
% *option added to plot horizontal residual temperature*
% *option added to plot heat flux*
% *option added to plot temporal evolution of tectonic parameters*
% *option added to save figure to specific directory*
% *improved code design*
% *improved user friendliness*
% *bug fixed that led to empty plate sketch plot*
% *bug fixes and updates to the dimensionalisation*

%% NOTES
% 3-D plate boundary tracking still in testing phase

function [SAVE] = STAGplot(IN,PLOT,SWITCH,TOPO,STYLE,SAVE)
if exist('IN','var') %if run from a parfile
    %% DEFAULT VARIABLES
    %...see f_defaults.m
else
    clear; clf;
    %% INPUT (...use parameter file instead)
    SAVE.StartNum = 1; SAVE.EndNum = 1;
    [IN,PLOT,SWITCH,TOPO,STYLE,SAVE] = f_defaults(SAVE); %get default variables
    IN.fname_vector   	=   {  'testDIM'  'test' };	% filename
    IN.number_vector    =   [   2           3 	];
    IN.parameter_vector =   [   11          11 	];
    IN.folder_vector	=   {   '/work/plotTest/' ...
                                '/work/plotTest/'    };    
end

%% STARTUP PROCEDURE
SAVE.app = 'STAGplot'; SAVE.appVersion = 'X1.1';
if ~isfield(SAVE,'count'); SAVE.count = 0; end
[SAVE,SWITCH] = f_startup(PLOT,SAVE,SWITCH);

%% VARIABLE CONVERSIONS
PLOT.quiverM            = [IN.quiver_plot IN.quiver_T IN.quiver_eta IN.quiver_str IN.num_del IN.scale IN.quiver_psi IN.quiver_rho IN.quiver_nstr IN.quiver_edot];
PLOT.streamfun          = [IN.plotStreamfun IN.streamfun_T IN.streamfun_eta IN.streamfun_str IN.stream_numContours IN.streamfun_rho IN.streamfun_v IN.streamfun_edot];
PLOT.streamline         = [IN.streamline_plot IN.streamline_T IN.streamline_eta IN.streamline_str];
PLOT.defmech            = [IN.defmech_T IN.defmech_eta IN.defmech_str IN.defmech_edot IN.defmechContours];
PLOT.lithoThickness     = [IN.lithoTisovalue IN.lithozmax IN.lithoThickness_T IN.lithoThickness_eta IN.lithoThickness_nstr];
PLOT.fieldContour       = [IN.fContourIsovalue IN.fieldContour_T IN.fieldContour_eta IN.fieldContour_nstr IN.fieldContour_vx IN.fieldContour_str IN.fieldContour_edot];

fieldString = '';
nrFields=0;
if IN.plotComposition;      nrFields = nrFields+1; fieldString=strcat(fieldString,'-c');  end
if IN.plotTemperature;      nrFields = nrFields+1; fieldString=strcat(fieldString,'-t');  end
if IN.plotResTemperature;   nrFields = nrFields+1; fieldString=strcat(fieldString,'-t'); end
if IN.plotViscosity;        nrFields = nrFields+1; fieldString=strcat(fieldString,'-eta');  end
if IN.plotStress;           nrFields = nrFields+1; fieldString=strcat(fieldString,'-str');  end
if IN.plotEdot;             nrFields = nrFields+1; fieldString=strcat(fieldString,'-edot');  end
if IN.plotDensity;          nrFields = nrFields+1; fieldString=strcat(fieldString,'-rho');  end
if IN.plotVelocity;         nrFields = nrFields+1; fieldString=strcat(fieldString,'-v');  end
if IN.plotVelocityX;        nrFields = nrFields+1; fieldString=strcat(fieldString,'-vx');  end
if IN.plotVelocityZ;        nrFields = nrFields+1; fieldString=strcat(fieldString,'-vz');  end
if IN.plotPressure;         nrFields = nrFields+1; fieldString=strcat(fieldString,'-p');  end
if IN.plotDynPressure;      nrFields = nrFields+1; fieldString=strcat(fieldString,'-pd');  end
if IN.plotHeatFlux;         nrFields = nrFields+1; fieldString=strcat(fieldString,'-hf'); end
if IN.plotMeltFrac;         nrFields = nrFields+1; fieldString=strcat(fieldString,'-e');  end
if IN.plotCrust;            nrFields = nrFields+1; fieldString=strcat(fieldString,'-cr');  end
if IN.plotDefMechanism;     nrFields = nrFields+1; fieldString=strcat(fieldString,'-dlc'); end
if IN.plotPrimordial;       nrFields = nrFields+1; fieldString=strcat(fieldString,'-prm');  end
if IN.plotAir;              nrFields = nrFields+1; fieldString=strcat(fieldString,'-air');  end
if IN.plotTopo;             nrFields = nrFields+1; fieldString=strcat(fieldString,'-topo');  end
if IN.plotPlateVh;          nrFields = nrFields+1; fieldString=strcat(fieldString,'-pvh');  end
if IN.plotIsolineTopo;      nrFields = nrFields+1; fieldString=strcat(fieldString,'-iltopo');  end
if IN.plotToroidal;         nrFields = nrFields+1; fieldString=strcat(fieldString,'-to');  end
if IN.plotPoloidal;         nrFields = nrFields+1; fieldString=strcat(fieldString,'-po');  end
if IN.plotStreamfun;        nrFields = nrFields+1; fieldString=strcat(fieldString,'-psi');  end
if IN.plotGeoid;            nrFields = nrFields+1; fieldString=strcat(fieldString,'-g'); end
if IN.plotDynTopo;          nrFields = nrFields+1; fieldString=strcat(fieldString,'-dtopo'); end
if IN.plotNormalStress;     nrFields = nrFields+1; fieldString=strcat(fieldString,'-nstr'); end
if IN.plotPlateSketch;      nrFields = nrFields+1; fieldString=strcat(fieldString,'-plate'); end
if IN.plotTimeGraph;        nrFields = nrFields+1; fieldString=strcat(fieldString,'-tgraph'); end
if TOPO.both && IN.plotDynTopo           
    nrFields = nrFields-1; if ~IN.plotTopo; error('TOPO.both needs IN.plotTopo switched on....'); end
end
PLOT.nr_subplot = 0;
PLOT.loop_plot  = 0;
nrPlots         = nrFields*size(IN.fname_vector,2);

%% SWITCH ADJUSTMENTS & ERROR CHECKS
if nrFields==0; error('No field to plot: choose a field to plot!'); end
if SWITCH.plotDifference
    if size(IN.fname_vector,2)~=2  %only 2 simulations/snapshots allowed for direct comparison
        error('using SWITCH.plotDifference needs maximum number of plots == 2; i.e. size(IN.fname_vector,2) = 2 !')
    end
    nrPlots = nrPlots/2;
end
if SWITCH.GraphVsTimePlot
    SWITCH.PlotInPlot = true;
end
if SWITCH.PlotInPlot 
    nrPlots = nrFields; %allows only for one file - might change that!
    if size(IN.fname_vector,2)==1 && SAVE.StartNum==SAVE.EndNum; error('SWITCH.PlotInPlot switched on makes only sense with more than one file to plot!'); end
    if SWITCH.title; SWITCH.title = false; if SWITCH.me; display('  (title has been switched off)'); end; end
    if SWITCH.texting; SWITCH.texting = false; if SWITCH.me; display('  (texting has been switched off)'); end; end
    if ~PLOT.titleOnlyTime; PLOT.titleOnlyTime = true; end
end
if SWITCH.stylePlots && ~SWITCH.simplify
    SWITCH.simplify = true; warning('SWITCH.simplify has to be switched on if SWITCH.stylePlots is switched on!');
end

%% CHECK PLATFORM
if ismac; if SWITCH.me; display('Platform:          Mac'); end
elseif isunix; if SWITCH.me; display('Platform:          Linux'); end
elseif ispc; if SWITCH.me; display('Platform:          Windows PC'); end
end

%% CHECK MATLAB RELEASE VERSION to USE NEWEST FEATURES
MatlabRelease = version('-release');
if verLessThan('matlab', '8.4.0')
    % -- Put code to run under MATLAB 2014a and earlier here --
    display(['>>>>>>>       your are currently using MatLab',MatlabRelease,'                  <<<<<<<<<'])
    display('>>>>>>> to use all available tools update to MatLab2014b or newer! <<<<<<<<<')
    PLOT.multipleColormap = false;
    if strcmp(SWITCH.ColormapAll(1,1),'auto'); SWITCH.ColormapAll{1,1} = 'parula'; end
    SWITCH.MversionSupported = false;
else
    % -- Put code to run under MATLAB 2014b and later here --
    if strcmp(SWITCH.ColormapAll(1,1),'auto')
        PLOT.multipleColormap = true;
    else
        PLOT.multipleColormap = false;
    end
    SWITCH.MversionSupported = true;
end

%% SETUP FIGURE AND COLOUR SCHEME
if ~SWITCH.PlotInPlot; clf(figure(1)); end %only if not holding on previous plot
%colour scheme
keyColor            = STYLE.keyColor; %define local variables
PLOT.keyColorLight  = [min(1,keyColor(1,1)+0.11) min(1,keyColor(1,2)+0.11) min(1,keyColor(1,3)+0.11)];
if strcmp(STYLE.colorMode,'white')
    if ~SWITCH.PlotInPlot; colordef(figure(1),'white'); end
    if IN.plotTimeGraph
        warning('colordef can currently erase line colouring in graph plots (reported MatLab bug). Type "reset(groot)" to fix temporarily.')
    end
elseif strcmp(STYLE.colorMode,'black')
    if ~SWITCH.PlotInPlot; colordef(figure(1),'black'); end
    keyColor            = 1-keyColor; %invert key colours
    STYLE.keyLineColor  = 1-STYLE.keyLineColor;
    TOPO.color          = 1-TOPO.color;
    TOPO.lineColor      = 1-TOPO.lineColor;
end

%% GET SUBPLOT LAYOUT AUTOMATICALLY
if ~isfield(PLOT,'subplotLayout') %if not predefined subplot layout
    nr_models = size(IN.fname_vector,2);
    if SWITCH.PlotInPlot; nr_models = 1; end
    if nr_models==1 && nrPlots>=4
        subplotLayout = [2 ceil(nrPlots/2)];
    else
        subplotLayout = [nr_models nrPlots/nr_models];
    end
    if PLOT.reverseLayout; subplotLayout = fliplr(subplotLayout); end
    PLOT.subplotLayout = subplotLayout;
end

%% ADJUST VARIABLES
if isfield(SAVE,'graphPlotHandles'); SAVE.graphPlotHandles = []; end
if isfield(SAVE,'PlotHandles'); SAVE.PlotHandles = []; end

%% LOOP FILES
PLOT.spNum(1,3) = 1; %subplot counter
for loop_case=1:size(IN.fname_vector,2)
    clearvars io i x2d y2d z2d var2d X3D Y3D Z3D VAR3D topo2d
    PLOT.loop_case      = loop_case;
    FILE.name           = IN.fname_vector{1,loop_case}; PLOT.fname = FILE.name;
    FILE.number         = IN.number_vector(1,loop_case);
    FILE.stem           = IN.folder_vector{1,loop_case};
    FILE.stem_im        = [FILE.stem,'+im/'];           if ispc; FILE.stem_im = strrep(FILE.stem_im,'/','\'); end
    FILE.stem           = strcat(FILE.stem,'+op/');     if ispc; FILE.stem = strrep(FILE.stem,'/','\'); end
    SWITCH.parameter    = IN.parameter_vector(1,loop_case);
    if SWITCH.PlotInPlot 
        PLOT.loop_plot=0; PLOT.nr_subplot=0; %reset to previous plot for each case
        TOPO.water = false; TOPO.areaFill = 'none';
        %gradual coloring for each time
        if SAVE.EndNum-SAVE.StartNum~=1 %needs more than one time snapshot to work
            dDarkening = PLOT.startGradColor./(ceil((SAVE.EndNum-SAVE.StartNum)/SAVE.StepNum)+1-1); %incremental increase in darkness
            PLOT.gradColor4File = PLOT.startGradColor - dDarkening.*ceil((IN.number_vector(1,1)-SAVE.StartNum)/SAVE.StepNum-1); %last one is black [0 0 0]
            clearvars dDarkening
        elseif size(IN.fname_vector,2)>1 %or needs more than one file to work
            dDarkening = PLOT.startGradColor./(size(IN.fname_vector,2)-1); %incremental increase in darkness
            PLOT.gradColor4File = PLOT.startGradColor - dDarkening.*(loop_case-1); %last one is black [0 0 0]
            clearvars dDarkening
        end
    end
    
    %% CHECK FOR INPUT FILE
    [FILE] = f_filefinder(FILE);
    if FILE.number==SAVE.EndNum; %might also be last file as defined by user
        FILE.LastFile = true;
    end
    SAVE.LastFile   = FILE.LastFile;
    PLOT.LastFile   = FILE.LastFile; %keeping that only for old parfiles
    PLOT.number     = FILE.number;
    IN.number_vector(1,loop_case) = FILE.number;
    
    %% READ DUMMY TEMPERATURE INPUT FILE -----------------------------
% [nb,X_3D,Y_3D,Z_3D,~,time,rcmb,~,aspect] = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,'temperature',SWITCH.Precision); %OLD ROUTINE CALLING
    [READ] = f_ReadStagYY2(FILE.directory, FILE.name, FILE.number, 'temperature', SWITCH.Precision);
    
    X_3D = READ.X_3D; Y_3D = READ.Y_3D; Z_3D = READ.Z_3D;
    
    % GRID ADJUSTMENTS
    if PLOT.YZ_2Dcartesian && isfield(READ,'X_3D'); %exchange x and y
        dummy_3D = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
        dummy_3Dx = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
        dummy_3Dx(:,1,:)    = X_3D(1,:,:);
        dummy_3D(:,1,:)     = Y_3D(1,:,:); Y_3D = dummy_3Dx; X_3D = dummy_3D;
        dummy_3D(:,1,:)     = Z_3D(1,:,:); Z_3D = dummy_3D;
    end
    
    %% CHECK DETAILS OF INPUT FILE -----------------------------
    GRID.aspectDomain = READ.Aspect; %aspect ratio of model-domain (not used yet!)
    if max(Z_3D(:))>0.5 && max(Z_3D(:))<1.5  %if 0.5<D<1.5 then non-dimensional  %%%NOT PERFECT
        SWITCH.dimensional_input = false; display('Input:             non-dimensional');
    else
        SWITCH.dimensional_input = true; display('Input:             dimensional');
    end
    nx = size(Z_3D,1); ny = size(Z_3D,2); nz = size(Z_3D,3);
    if READ.nb>1 %check grid type
        GRID.Type = 'yinyang';
    elseif READ.rcmb==-1 %this is stag's flag for cartesian geometry
        GRID.Type = 'cartesian';
    else
        GRID.Type = 'cylindrical';
        if nx==1 && ny~=1 %swap nx and ny
            nx = ny; ny = 1;
        end
        dummy_3D = zeros(size(X_3D,2),size(X_3D,1),size(X_3D,3));
        dummy_3D(:,1,:) = X_3D(1,:,:);  X_3D = dummy_3D;
        dummy_3D(:,1,:) = Y_3D(1,:,:);  Y_3D = dummy_3D;
        dummy_3D(:,1,:) = Z_3D(1,:,:);  Z_3D = dummy_3D;
        dummy_3D = X_3D; X_3D = Y_3D; Y_3D = dummy_3D; %swap x and y 
    end
    if (nx>1) && (ny>1) && (nz>1) %check dimension
        GRID.Dim='3-D';
    else
        GRID.Dim='2-D';
    end
    display(['Gridtype:          ',GRID.Dim,' ',GRID.Type,' (',num2str(nx),'',num2str(ny),'',num2str(nz),'',num2str(READ.nb),')'])
    GRID.nx = nx; GRID.ny = ny; GRID.nz = nz; GRID.nb = READ.nb;    

    %% KEEP T-FIELD FOR LATER USE
    if SWITCH.trackPlumes
        if strcmp(GRID.Type,'yinyang') %save T-field for later use
            PLOT.T_3Dyin = READ.VAR_3Dyin;
            PLOT.T_3Dyang = READ.VAR_3Dyang;
        else
            %plume tracking not used yet for other geometries
        end
    end
    
    %% SET FIGURE SIZE
    if loop_case==1
        h=figure(1);
        if strcmp(SWITCH.figurePosition,'auto');     %set figure position automatically
            FPOS.subplotLayout  = PLOT.subplotLayout;
            FPOS.setAxisLimit   = SWITCH.setAxisLimit;
            FPOS.axisLimit      = SWITCH.axisLimit;
            if strcmp(GRID.Type,'yinyang'); FPOS.yyNumSlices = PLOT.yyNumSlices; end
            [~] = f_figurePos(FPOS,GRID);
        else
            set(h,'Position',SWITCH.figurePosition);     %set figure position manually
        end
        clearvars FPOS
    end
    
    %% DIMENSIONAL PARAMETERS
    [SETUP,SWITCH] = f_dimParameter(SWITCH,FILE);
    if strcmp(SETUP.topBC,'free-slip')
        SWITCH.actualDepth = false;
    elseif strcmp(SETUP.topBC,'sticky-air')
        SWITCH.actualDepth = true;
    end
    display(['Top-BC:            ',SETUP.topBC])

    % SET AND INDICATE TIME
    PLOT.time       = READ.time;     %[nd] or [dim]
    PLOT.time_dim   = READ.time*SETUP.timescale/SETUP.secyear;  % get dimensional time [a]
    if PLOT.time_dim/1e6>100
        PLOT.time2plot = PLOT.time_dim/1e9; PLOT.time2plotDim = 'Ga'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e9;
    elseif PLOT.time_dim/1e6<1e-7 %0.0000001
        PLOT.time2plot = PLOT.time_dim*SETUP.secyear; PLOT.time2plotDim = 's'; PLOT.timeConvert = SETUP.timescale;
    elseif PLOT.time_dim/1e6<1e-4 %0.0001
        PLOT.time2plot = PLOT.time_dim; PLOT.time2plotDim = 'a'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear;
    elseif PLOT.time_dim/1e6<1e-1 %0.1
        PLOT.time2plot = PLOT.time_dim/1e3; PLOT.time2plotDim = 'ka'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e3;
    else
        PLOT.time2plot = PLOT.time_dim/1e6; PLOT.time2plotDim = 'Ma'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e6;
    end
    if ~SWITCH.dim && ~SWITCH.dimensional_input; PLOT.time2plot = PLOT.time; PLOT.time2plotDim = 'nd'; PLOT.timeConvert = 1; end
    display(['Time (non-dim):    ',num2str(PLOT.time,3)])
    display(['Time (dim):        ',num2str(PLOT.time2plot,3),' ',PLOT.time2plotDim])
    
    % SET 2-D GRID VARIABLES
    if strcmp(GRID.Dim,'3-D')
        x2d         = X_3D(:,1,1);
        y2d         = Y_3D(1,:,1);
        z2d         = Z_3D(1,1,:);
    elseif strcmp(GRID.Dim,'2-D')
        x2d(:,:)    = X_3D(:,1,:);
        y2d(:,:)    = Y_3D(:,1,:); % just in order to have it defined
        z2d(:,:)    = Z_3D(:,1,:);
    end

    % FLIP DEPTH VECTOR AND ACCOUNT FOR STICKY-AIR LAYER
    if strcmp(GRID.Type,'cylindrical') || strcmp(GRID.Type,'yinyang')
        GRID.Z_3Dndnf = Z_3D; %not flipped z array (non-dimensionalised later)
    end 
    if SWITCH.dimensional_input
        z2d = SETUP.D_dim-z2d;
        Z_3D = SETUP.D_dim-Z_3D;
    else
        z2d = 1.0-z2d;   % reverse z-axis  (1.)
        Z_3D = 1.0-Z_3D;
    end
    if SWITCH.actualDepth
        z2d = z2d-SETUP.d_air;  %set z=0 to real surface
        Z_3D = Z_3D-SETUP.d_air;  %set z=0 to real surface
    end
    
    % NON-DIMENSIONALISE GLOBAL GRID VARIABLES
    if SWITCH.dimensional_input
        GRID.ndFactor   = 1/SETUP.D_dim;      %[nd]
        if strcmp(GRID.Type,'cylindrical'); GRID.Z_3Dndnf = GRID.Z_3Dndnf/SETUP.D_dim; end %[nd]
    else
        GRID.ndFactor   = 1;      %[nd]
    end
    GRID.X_3Dnd     = X_3D *GRID.ndFactor;     %[nd]
    GRID.Y_3Dnd     = Y_3D *GRID.ndFactor;     %[nd]
    GRID.Z_3Dnd     = Z_3D *GRID.ndFactor;     %[nd]
    GRID.x2d_nd     = x2d *GRID.ndFactor;     %[nd]
    GRID.y2d_nd     = y2d *GRID.ndFactor;     %[nd]
    GRID.z2d_nd     = z2d *GRID.ndFactor;     %[nd]
    GRID.rcmb_nd    = READ.rcmb *GRID.ndFactor;     %[nd]
    
    % DIMENSIONALISE GLOBAL GRID VARIABLES
    if SWITCH.dim || SWITCH.dimensional_input
        GRID.dimFactor = SETUP.lengthscale;	%[m]
        %plotting variables
        if abs(max(max(Z_3D(:)*SETUP.lengthscale)))>1e3 % >1km
            GRID.dimFactor = GRID.dimFactor /1e3;	%[km]
            GRID.Xdim = 'km'; GRID.Ydim = 'km'; GRID.Zdim = 'km';
        elseif abs(max(max(Z_3D(:)*SETUP.lengthscale)))>1 % >1m
            GRID.dimFactor = GRID.dimFactor;	%[m]
            GRID.Xdim = 'm'; GRID.Ydim = 'm'; GRID.Zdim = 'm';
        else % <1m
            GRID.dimFactor = GRID.dimFactor *1e2;	%[cm]
            GRID.Xdim = 'cm'; GRID.Ydim = 'cm'; GRID.Zdim = 'cm';
        end
    else
        GRID.dimFactor = GRID.ndFactor;	%[nd]
        GRID.Xdim = 'nd'; GRID.Ydim = 'nd'; GRID.Zdim = 'nd';
    end
    GRID.X_3Dp  = X_3D *GRID.dimFactor;	%[nd], [km], [m], or [cm]
    GRID.Y_3Dp  = Y_3D *GRID.dimFactor;
    GRID.Z_3Dp  = Z_3D *GRID.dimFactor;
    GRID.x2dp   = x2d *GRID.dimFactor;
    GRID.y2dp   = y2d *GRID.dimFactor;
    GRID.z2dp   = z2d *GRID.dimFactor;
    GRID.rcmb_p = READ.rcmb *GRID.dimFactor;
    GRID.nd2dim = 1/GRID.ndFactor*GRID.dimFactor;
    if SWITCH.dim || SWITCH.dimensional_input
        X_3D        = X_3D *SETUP.lengthscale;	%[m] SI-units
        Y_3D        = Y_3D *SETUP.lengthscale;	%[m]
        Z_3D        = Z_3D *SETUP.lengthscale;	%[m]
%         GRID.x2d	= x2d *SETUP.lengthscale;	%[m]
%         GRID.y2d	= y2d *SETUP.lengthscale;	%[m]
%         GRID.z2d  	= z2d *SETUP.lengthscale;	%[m]
        READ.rcmb        = READ.rcmb *SETUP.lengthscale;	%[m] 
    end
        
    % DEFINE GLOBAL GRID VARIABLES
    GRID.X_3D = X_3D;   GRID.Y_3D = Y_3D;   GRID.Z_3D = Z_3D; %[nd] or [m] SI-units
    GRID.nx   = nx;   	GRID.ny   = ny;   	GRID.nz   = nz;
%     GRID.aspectRatio(1) = nx/nz; GRID.aspectRatio(2) = ny/nz;

    %grid spacing
    if size(GRID.X_3D,1)>1; GRID.dx = abs(GRID.X_3D(2,1,1)-GRID.X_3D(1,1,1)); end %just one value [m] or [nd]
    if size(GRID.Y_3D,2)>1; GRID.dy = abs(GRID.Y_3D(1,2,1)-GRID.Y_3D(1,1,1)); end %just one value [m] or [nd]
    if size(GRID.Z_3D,3)>1; GRID.dz = abs(GRID.Z_3D(1,1,2:end)-GRID.Z_3D(1,1,1:end-1)); end %vector [m] or [nd]
    if size(GRID.X_3Dp,1)>1; dxp = abs(GRID.X_3Dp(2,1,1)-GRID.X_3Dp(1,1,1)); end %just one value [plotting dim]
    if size(GRID.Y_3Dp,2)>1; dyp = abs(GRID.Y_3Dp(1,2,1)-GRID.Y_3Dp(1,1,1)); end %just one value [plotting dim]
    if size(GRID.Z_3Dp,3)>1; dzp = abs(GRID.Z_3Dp(1,1,2:end)-GRID.Z_3Dp(1,1,1:end-1)); end %vector [plotting dim]
    if strcmp(GRID.Dim,'2-D')
        if range(dzp)<1e-10 %uniform grid spacing
            display(['Grid Spacing:      dx = ',num2str(dxp,3),' ',GRID.Xdim,', dz = ',num2str(dzp(1,1),3),' ',GRID.Zdim])
        else %variable grid spacing
            display(['Grid Spacing:      dx = ',num2str(dxp,3),' ',GRID.Xdim,', dz = ',num2str(min(dzp(:)),3),' - ',num2str(max(dzp(:)),3),' ',GRID.Zdim])
        end
    else
        if range(dzp)<1e-10 %uniform grid spacing
            display(['Grid Spacing:      dx = ',num2str(dxp,3),' ',GRID.Xdim,', dy = ',num2str(dyp,3),' ',GRID.Ydim,', dz = ',num2str(dzp(1,1),3),' ',GRID.Zdim])
        else %variable grid spacing
            display(['Grid Spacing:      dx = ',num2str(dxp,3),' ',GRID.Xdim,', dy = ',num2str(dyp,3),' ',GRID.Ydim,', dz = ',num2str(min(dzp(:)),3),' - ',num2str(max(dzp(:)),3),' ',GRID.Zdim])
        end
    end
    
    %aspect ratio of subplots
    GRID.aspectRatio(1) = abs(max(GRID.X_3D(:))-min(GRID.X_3D(:))) / abs(max(GRID.Z_3D(:))-min(GRID.Z_3D(:)));
    GRID.aspectRatio(2) = abs(max(GRID.Y_3D(:))-min(GRID.Y_3D(:))) / abs(max(GRID.Z_3D(:))-min(GRID.Z_3D(:)));
    if SWITCH.setAxisLimit;  GRID.aspectRatio(1) = (SWITCH.axisLimit(1,2)-SWITCH.axisLimit(1,1))/(SWITCH.axisLimit(1,4)-SWITCH.axisLimit(1,3)); end %if manual axis extent
    if GRID.aspectRatio(1)==0; GRID.aspectRatio(1) = 1; end %has to be positive and finite
    if GRID.aspectRatio(2)==0; GRID.aspectRatio(2) = 1; end %has to be positive and finite
    GRID.rcmb = READ.rcmb;
    
    %% ERROR CHECKS
    if ( max(z2d(:)) > 10*max(x2d(:)) )
        error('z-vector is much larger than x-vector: did you adjust the dimensionalisation parameters? check this!!!')
    end
    if SWITCH.PlotInPlot
        if strcmp(GRID.Dim,'3-D'); error('SWITCH.PlotInPlot cannot be used with 3-D data!'); end
        if SAVE.LastFile && ~isfield(SAVE,'AllFilesTitleString'); error('SWITCH.PlotInPlot needs to plot multiple time steps!'); end
    end
    if SWITCH.GraphVsTimePlot
        if strcmp(GRID.Dim,'3-D'); error('SWITCH.GraphVsTimePlot cannot be used with 3-D data!'); end
        if SAVE.LastFile && ~isfield(SAVE,'graphTime'); error('SWITCH.GraphVsTimePlot needs to plot multiple time steps!'); end
    end
    if strcmp(GRID.Type,'yinyang')
        if SWITCH.plotDifference; error('SWITCH.plotDifference not implemented yet for YinYang geometry.'); end
        if PLOT.zoom; PLOT.zoom = false; warning('Yinyang mode: set PLOT.zoom = false'); end %zoom plot not possible in yinyang mode
        if SWITCH.trackC; SWITCH.trackC = false; warning('Yinyang mode: set SWITCH.trackC = false'); end %Compositional tracking not implemented yet for yinyang mode
    end

    %% SET UP COLORBAR RANGE
    if  SWITCH.dim || SWITCH.dimensional_input;
        dimensional = true;
    else
        dimensional = false;
    end
    [CB] = f_cbRange(IN,dimensional,loop_case);
    
    %% VARIABLE TRANSITIONS
    PLOT.multipleCBMinMax   = CB.multipleMinMax;
    PLOT.nrPlots            = nrPlots;
    SWITCH.fname_vector     = IN.fname_vector;
    FIELD.save              = SAVE.field;
    
    %% SET UP FIELD VARIABLES
    %  	1                       2                       3                   4                   5                   6           7           8               9               10
    %  	plot                    name                    symbol              dim                 varscale            colormap    cmap_flip   cColorbarMIN    cColorbarMAX    logarithmic
    FIELD_M = {
        IN.plotPlateSketch      'tectonics'             '-'                 GRID.Zdim           GRID.dimFactor      'default'   'noflip'	0             	1               false
        IN.plotTimeGraph        'time graph'        	'-'                 PLOT.time2plotDim   PLOT.timeConvert 	'default'   'noflip'    CB.vel_min      CB.vel_max      false
        IN.plotTopo             'topography'            'z_{topo}'          GRID.Zdim           GRID.dimFactor      'bwr'       'noflip'    CB.topo_min     CB.topo_max     CB.topo_log
        IN.plotDynTopo          'dyn. topography'       'z_{dyntopo}'       GRID.Zdim           GRID.dimFactor   	'bwr'       'noflip'    CB.dyntopo_min  CB.dyntopo_max	CB.dyntopo_log
        IN.plotIsolineTopo      'isoline topography'    'z_{topo}'          GRID.Zdim           GRID.dimFactor    	'default'   'noflip'    CB.isotopo_min  CB.isotopo_max	CB.isotopo_log
        IN.plotPlateVh          'plate velocity'        'v_h'             	'cm/a'              SETUP.Vscale       	'default'   'noflip'    -CB.vel_max     CB.vel_max    	CB.vel_log
        IN.plotHeatFlux         'heat flux'             '\phi'              'mW/m^2'            SETUP.HFscale     	'default'   'noflip'    0               1               false
        IN.plotComposition      'composition'           'C'                 ''                  1                   'default'   'noflip'   	0               4               false
        IN.plotAir              'air'                   'C'                 ''                  1                   'default'   'noflip'   	0               1               false
        IN.plotTemperature      'temperature'           'T'                 'K'                 SETUP.Tscale        'wgr'       'noflip' 	CB.T_min        CB.T_max        CB.T_log
        IN.plotResTemperature   'residual temperature'  'T_{res}'           'K'                 SETUP.Tscale      	'bwr'       'noflip'    CB.Tres_min     CB.Tres_max     CB.Tres_log
        IN.plotDensity          'density'               '\rho'           	'kg/m^{3}'       	SETUP.rhoscale    	'wgr'       'noflip'  	CB.rho_min      CB.rho_max      CB.rho_log
        IN.plotViscosity        'viscosity'         	'\eta'              'Pa s'              SETUP.etascale     	'blWbr'     'noflip'  	CB.eta_min    	CB.eta_max      CB.eta_log
        IN.plotStress           'stress'                '\sigma'            'MPa'               SETUP.stressscale 	'wblry'     'noflip'  	CB.str_min     	CB.str_max    	CB.str_log
        IN.plotEdot             'strain rate'           'UCvarepsilondot'   's^{-1}'          	SETUP.edotscale    	'wblry'     'noflip'	CB.edot_min     CB.edot_max     CB.edot_log
        IN.plotVelocity         'velocity'              'v'                 'cm/a'              SETUP.Vscale       	'bwr'       'noflip'	CB.vel_min      CB.vel_max      CB.vel_log
        IN.plotVelocityX        'horizontal velocity'   'v_x'               'cm/a'              SETUP.Vscale       	'blWgr'     'noflip'	-CB.vel_max     CB.vel_max      CB.vel_log
        IN.plotVelocityZ        'radial velocity'       'v_z'               'cm/a'              SETUP.Vscale      	'blWgr'     'noflip'	-CB.vel_max     CB.vel_max      CB.vel_log
        IN.plotPressure         'pressure'              'P'                 'GPa'               SETUP.Pscale      	'default'   'noflip'  	CB.P_min        CB.P_max        CB.P_log
        IN.plotToroidal         'toroidal'              'v_{tor}'           ''                  1                   'bwr'     	'noflip'    0               1               false
        IN.plotPoloidal         'poloidal'              'v_{pol}'         	''                  1                   'bwr'       'noflip'    0               1               false
        IN.plotStreamfun        'streamfunction'        '\psi'              ''                  1                   'blWgr'     'noflip'    -150            150             false
        IN.plotPrimordial       'primordial'            'C_{prim}'         	''                  1                   'wbr'       'noflip'	0               1               false
        IN.plotDefMechanism     'deformation mechanism' 'M_{def}'           'mechanism'      	1                   'default'   'noflip'  	1               4               false
        IN.plotGeoid            'geoid'                 'g'                 GRID.Zdim        	GRID.dimFactor    	'default'   'noflip'   	CB.geoid_min    CB.geoid_max    CB.geoid_log
        IN.plotNormalStress     'zz-stress component'   '\sigma_{zz}'       'MPa'               SETUP.stressscale  	'bwr'       'noflip'    CB.nstr_min     CB.nstr_max     false
        };
    % %     FIELD_M.colormap  	= { 'default'    'default'       'default'       'default'       'default'              'default'           'default'       'default'       'default'  	'wgr'       'bwr'     	    'wgr'           'blgw'         'wblry'     'wblry'         'bwr'           'blWgr'         'blWgr'         'default'      'bwr'            'bwr'           'blWgr'         'wbr'               'default'          	'default'   	'bwr'};
    
    %% UNICODE VARIABLES
    %use the following character sequence to add unicode variables:
    %UCvarepsilondot => char(941)
    %UCvarepsilon => char(949)
    FIELD_M(:,3) = strrep(FIELD_M(:,3),'UCvarepsilondot',{char(941)}); %does only work if string consists ONLY of unicode character
    FIELD_M(:,3) = strrep(FIELD_M(:,3),'UCvarepsilon',{char(949)}); %does only work if string consists ONLY of unicode character
    
    %% WAITBAR SWITCH
    if strcmp(GRID.Type,'yinyang') && logical(0) %switch on waitbar
        SWITCH.waitbar = true;
        display('   ...reading')
        if isfield(PLOT,'wb'); PLOT.wb = waitbar(0,PLOT.wb,'reading...'); else PLOT.wb = waitbar(0,'reading...'); end
    else
        SWITCH.waitbar = false;
    end
    
    %% VARIABLE CONVERSION AND CLEARANCE
    SWITCH.Colorbar     = [ SWITCH.Colorbar    IN.constantColorbar ];
    clearvars READ CB X_3D Y_3D Z_3D x2d y2d z2d
    
    %% INITIALISE VARIABLES
    TOPO.varScale = FIELD_M{strcmp(FIELD_M(:,2),'topography'),5};
    
    PLOT.loop_field = 0; FILE.loop_field = PLOT.loop_field;
    if ~isfield(SAVE,'graphPlotHandles'); SAVE.graphPlotHandles = []; end
    if ~isfield(SAVE,'PlotHandles'); SAVE.PlotHandles = []; end
    
    %% LOOP PARAMETER FIELDS
    for field_loop=1:size(FIELD_M,1)
        if SWITCH.waitbar; waitbar(field_loop/size(FIELD_M,1)*0.4,PLOT.wb); end
        if FIELD_M{field_loop,1}  %check if plotting current field
            FIELD.name          = FIELD_M{field_loop,2};
            FIELD.symbol        = FIELD_M{field_loop,3};
            FIELD.dim           = FIELD_M{field_loop,4};
            FIELD.varScale      = FIELD_M{field_loop,5};
            if PLOT.multipleColormap; SWITCH.ColormapAll = [FIELD_M(field_loop,6)  FIELD_M(field_loop,7)]; end
            FIELD.cColorbarMIN	= FIELD_M{field_loop,8};
            FIELD.cColorbarMAX	= FIELD_M{field_loop,9};
            FIELD.logarithmic	= FIELD_M{field_loop,10};

            PLOT.loop_plot = PLOT.loop_plot+1; %track no. of PLOTS plots per file
            
            if ( strcmp(FIELD.name,'tectonics') ) %check if tectonics sketch
                if strcmp(GRID.Type,'yinyang'); error('tectonics not yet implemented for YinYang grid.'); end
                [tectonics,PLOT,SAVE] = f_plotPlateSketch(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE);
                %SAVE.tectonics = tectonics;
                if IN.plotPlateSketch; continue; end %jump to next loop
            end
            if ( strcmp(FIELD.name,'time graph') ) %check if temporal graph
                if strcmp(GRID.Type,'yinyang'); error('time graph not yet implemented for YinYang grid.'); end
                [PLOT,SAVE] = f_plotTimeGraph(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE);
                continue %jump to next loop
            end
            if ~exist('topo2d','var') && ( strcmp(FIELD.name,'topography') || TOPO.field ) ...  %check if topography
                || strcmp(FIELD.name,'geoid')  %or geoid
                if ~strcmp(GRID.Type,'yinyang') %ignore that for yy-grid
                    [topo2d,PLOT,SAVE] = f_plotTOPO(TOPO,FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE);
                    TOPO.topo2d = topo2d;
                    if IN.plotTopo; continue; end %jump to next loop
                end
            end
            if ( strcmp(FIELD.name,'dyn. topography') ) %check if dynamic topography
                if strcmp(GRID.Type,'yinyang'); error('not yet implemented for YinYang grid.'); end
                [dyntopo2d,PLOT,SAVE] = f_plotDynTOPO(TOPO,FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE);
                TOPO.dyntopo2d = dyntopo2d;
                if IN.plotDynTopo; continue; end %jump to next loop
            end
            if ( strcmp(FIELD.name,'isoline topography') ) %check if isoline topography
                if strcmp(GRID.Type,'yinyang'); error('isoline topography not yet implemented for YinYang grid.'); end
                [isotopo2d,PLOT,SAVE] = f_plotIsoline(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE);
                TOPO.isotopo2d = isotopo2d;
                if IN.plotIsolineTopo; continue; end %jump to next loop
            end
            if ( strcmp(FIELD.name,'plate velocity') ) %check if plate velocity
                if strcmp(GRID.Type,'yinyang'); error('plate velocity not yet implemented for YinYang grid.'); end
                [platevh2d,PLOT,SAVE] = f_plotPlateVel(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE);
                PLATE.platevh2d = platevh2d;
                if IN.plotPlateVh; continue; end %jump to next loop
            end
            if ( strcmp(FIELD.name,'heat flux') )  %check if heat flux
                if strcmp(GRID.Type,'yinyang'); error('heat flux not yet implemented for YinYang grid.'); end
                [field2d,PLOT,SAVE] = f_plot2DField(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE);
                if IN.plotHeatFlux; continue; end %jump to next loop
            end
            
            PLOT.loop_field = PLOT.loop_field +1; FILE.loop_field = PLOT.loop_field; %track no. of PARAMETER FIELDS plots per file
            if ~strcmp(FIELD.name,'velocity') &&...
                    ~strcmp(FIELD.name,'horizontal velocity') &&...
                    ~strcmp(FIELD.name,'radial velocity') &&...
                    ~strcmp(FIELD.name,'pressure') &&...
                    ~strcmp(FIELD.name,'toroidal')  &&...
                    ~strcmp(FIELD.name,'poloidal')  &&...
                    ~strcmp(FIELD.name,'streamfunction')
                
                %% READ SCALAR DATA ---------------------------------------------------
                if strcmp(GRID.Type,'yinyang')
                    [~,~,~,~,VAR_3D_yin,VAR_3D_yang,~,~]     = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, FIELD.name, SWITCH.Precision);                    
                    VAR.var3d_yin   = VAR_3D_yin;
                    VAR.var3d_yang  = VAR_3D_yang;
                                        
                else %all other geometries
                    [~,~,~,~,VAR_3D,~,~]    = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, FIELD.name, SWITCH.Precision);
                
                    if size(VAR_3D,1)==1; %exchange x and y
                        dummy_3D = zeros(size(VAR_3D,2),size(VAR_3D,1),size(VAR_3D,3));
                        dummy_3D(:,1,:) = VAR_3D(1,:,:); VAR_3D = dummy_3D;
                    end
                    if strcmp(FIELD.name,'residual temperature') %FOR HORIZONTAL RESIDUAL-TEMPERATURE
                        for iz=1:size(VAR_3D,3)
                            dummy           = mean2(VAR_3D(:,:,iz)); 	%horizontal mean temperature
                            VAR_3D(:,:,iz)  = VAR_3D(:,:,iz) - dummy;   %residual temperature
                        end
                    end
                    if strcmp(GRID.Dim,'3-D')
                        var2d   = VAR_3D(:,:,:);
                    elseif strcmp(GRID.Dim,'2-D')
                        var2d(:,:)  = VAR_3D(:,1,:);
                    end
                    if strcmp(FIELD.name,'deformation mechanism')
                        if strcmp(GRID.Dim,'3-D')
                            display('WARNING: def.mech. this needs to be adjusted in 3-D plots! 3DXXX')
                        elseif strcmp(GRID.Dim,'2-D')
                            %make sure values are the exact numbers they should be down to 0.00x:
                            var2d(:,:)  = round(var2d*1e3)/1e3;
                            if var2d(2,2)==1 && var2d(3,2)==4 %check for artificial values
                                var2d(2,2) = var2d(4,2);  %and remove them
                                var2d(3,2) = var2d(4,2);
                            end
                        end
                    end
                    if SWITCH.plotDifference && mod(loop_case,2) %only for odd cases
                        if loop_case>2; error('more than 1 field not yet implemented!'); end
                        var2d_A = var2d;
                        continue
                    elseif SWITCH.plotDifference && ~mod(loop_case,2) %only for even cases
                        VAR.var2d = var2d_A-var2d;  %take difference
                        clearvars var2d_A
                    else
                        VAR.var2d = var2d;
                    end
                end                
                
                [PLOT,SAVE] =  f_plotFIELDS( VAR,FIELD,FIELD_M,GRID,SETUP,SWITCH,PLOT,TOPO,FILE,STYLE,SAVE );
                clearvars VAR var2d VAR_3D VAR_3D_yin VAR_3D_yang
                
            else
                %% READ VECTOR DATA ---------------------------------------------------
                % Read pressure & velocity information
                if strcmp(GRID.Type,'yinyang')
                    if strcmp(FIELD.name,'toroidal') || strcmp(FIELD.name,'poloidal')
                        [~,~,~,~,VX_3D_yin,VY_3D_yin,VZ_3D_yin,P_3D_yin,VX_3D_yang,VY_3D_yang,VZ_3D_yang,P_3D_yang,~,~] ...
                            = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,FIELD.name,SWITCH.Precision);
                    else
                        [~,~,~,~,VX_3D_yin,VY_3D_yin,VZ_3D_yin,P_3D_yin,VX_3D_yang,VY_3D_yang,VZ_3D_yang,P_3D_yang,~,~] ...
                            = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,'velocity',SWITCH.Precision);
                    end
                    if strcmp(FIELD.name,'x-velocity'); VAR_3D_yin = VX_3D_yin; VAR_3D_yang = VX_3D_yang;
                    elseif strcmp(FIELD.name,'y-velocity'); VAR_3D_yin = VY_3D_yin; VAR_3D_yang = VY_3D_yang;
                    elseif strcmp(FIELD.name,'z-velocity'); VAR_3D_yin = VZ_3D_yin; VAR_3D_yang = VZ_3D_yang;
                    elseif strcmp(FIELD.name,'pressure'); VAR_3D_yin = P_3D_yin; VAR_3D_yang = P_3D_yang;
                    elseif strcmp(FIELD.name,'velocity') || ...
                            strcmp(FIELD.name,'toroidal') || strcmp(FIELD.name,'poloidal') %combine components
                        VAR_3D_yin = sqrt(VX_3D_yin.^2 +VY_3D_yin.^2 +VZ_3D_yin.^2);
                        VAR_3D_yang = sqrt(VX_3D_yang.^2 +VY_3D_yang.^2 +VZ_3D_yang.^2);
                    elseif strcmp(FIELD.name,'streamfunction') %nothing to do
                    end
                    VAR.var3d_yin   = VAR_3D_yin;
                    VAR.var3d_yang  = VAR_3D_yang;
                    
                else
                    [~,~,~,~,VX_3D,VY_3D,VZ_3D,P_3D,~,~]    = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'velocity', SWITCH.Precision);
                    if size(P_3D,1)==1; %exchange x and y
                        dummy_3D = zeros(size(VX_3D,2),size(VX_3D,1),size(VX_3D,3));
                        dummy_3D(:,1,:)     = VX_3D(1,:,:); VX_3D = dummy_3D;
                        dummy_3D(:,1,:)     = VY_3D(1,:,:); VY_3D = dummy_3D;
                        dummy_3D(:,1,:)     = VZ_3D(1,:,:); VZ_3D = dummy_3D;
                        dummy_3D(:,1,:)     = P_3D(1,:,:); P_3D = dummy_3D;
                        if max(VX_3D(:))==0 %exchange x and y  %if statement might be unnecessary
                            dummy_3D = VX_3D; VX_3D = VY_3D; VY_3D = dummy_3D;
                        elseif max(VX_3D(:))~=0 && max(VY_3D(:))==0
                        else
                            error('both VX_3D and VY_3D appear to be zero: check here!')
                        end
                    end
                    if strcmp(GRID.Dim,'3-D')
                        vx2d = VX_3D(:,:,:);
                        vy2d = VY_3D(:,:,:);
                        vz2d = VZ_3D(:,:,:);
                        p2d  = P_3D(:,:,:);
                    elseif strcmp(GRID.Dim,'2-D')
                        vx2d(:,:) = VX_3D(:,1,:);
                        vy2d(:,:) = VY_3D(:,1,:);
                        vz2d(:,:) = VZ_3D(:,1,:);
                        p2d(:,:)  = P_3D(:,1,:);
                    end
                    v2d = sqrt(vx2d.^2 + vy2d.^2 + vz2d.^2); %absolute velocity
                    if SWITCH.plotDifference; error('plotDifference not yet implemented for vector fields...'); end
                    if strcmp(FIELD.name,'velocity');               VAR.var2d = v2d; end    %IN.plotVelocity
                    if strcmp(FIELD.name,'horizontal velocity');    VAR.var2d = vx2d; end   %IN.plotVelocityX
                    if strcmp(FIELD.name,'radial velocity');        VAR.var2d = vz2d; end   %IN.plotVelocityZ
                    if strcmp(FIELD.name,'pressure');               VAR.var2d = p2d; end    %IN.plotPressure
                    if strcmp(FIELD.name,'streamfunction')
                        vz2d = -vz2d; %reverse y-axis  (1.)
                        vx2d = vx2d*SETUP.Vscale; vz2d = vz2d*SETUP.Vscale; %[cm/a]
                        [phi2d,psi2d] = flowfun(vx2d,vz2d);  % calculate the velocity potential (phi) and streamfunction (psi)
                        if strcmp(PLOT.streamdata,'phi'); stream2d=phi2d; elseif strcmp(PLOT.streamdata,'psi'); stream2d=psi2d; end
                        VAR.var2d = stream2d; %IN.plotStreamfun
                    end
                end
                [PLOT,SAVE] = f_plotFIELDS( VAR,FIELD,FIELD_M,GRID,SETUP,SWITCH,PLOT,TOPO,FILE,STYLE,SAVE);
                clearvars VAR v2d vx2d vy2d vz2d p2d stream2d psi2d phi2d
            end  %velocity field
        end %field plot
    end %field loop
    if isfield(SWITCH,'dimensional_output') && SWITCH.dimensional_output; SWITCH.dim=true; end %set back if dimensional output
    if IN.MILAMINcomparison
        break
    end
    display(' ')
end %loop case

%% PLOT DESIGN ADJUSTMENTS
if SWITCH.FullFigSize
    figure(1)
    set(gca,'position',[0 0 1 1]);  %set axes to figure size
    fpos=get(figure(1),'Position');
    set(figure(1),'Position',[fpos(1,1)   fpos(1,2)   GRID.aspectRatio(1)*fpos(1,4)   fpos(1,4)]);  %aspect ratio=2
end

%% SET UP TIME-EVOLUTION PLOTS (i.e., rectangles between subplots)
if SWITCH.timeEvolution && logical(0)  %this is currently only needed for rectangles
    %FIND AXES POSITION OF ALL SUBPLOTS
    axH_all = findobj(gcf,'type','axes'); 
    cbH_all = findobj(gcf,'tag','Colorbar');
    if ~isempty(cbH_all); axH_all(ismember(axH_all,cbH_all)) = []; end    %remove colorbar handles
    if isfield(PLOT,'zoom') && PLOT.zoom; axH_all(1:2:end) = []; end %remove small zoom plot axes
    axPosition = zeros(size(axH_all,1),4);
    for i=1:size(axH_all,1) %loop through subplots
        axPosition(i,:)   = get(axH_all(i),'Position');  %axes position
    end

    %% INSERT RECTANGLE
    if SWITCH.insertRectangles
        if isfield(SWITCH,'RectangleWidth'); rt_partWidth = SWITCH.RectangleWidth;
        else
            %rt_partWidth  	= 0.7;  %percent of axes width
            %rt_partWidth  	= 0.91;
            rt_partWidth  	= 1.0;
        end
        RT_FillColor    = keyColor;   %color
        
        rtPos = zeros(PLOT.subplotLayout(1,2),4);
        if strcmp(SWITCH.timeDirection,'topbot')
            for i_rt=1:PLOT.subplotLayout(1,2)                
                rtPosX1 = axPosition(i_rt,1)+(1-rt_partWidth)/2*axPosition(i_rt,3);
                rtWidth = axPosition(i_rt,3)-(1-rt_partWidth)*axPosition(i_rt,3);
                
                rtPosY1 = axPosition(i_rt,2)+axPosition(i_rt,4)/2;
                %rtHeight = axPosition((i_rt+PLOT.subplotLayout(1,1)*PLOT.subplotLayout(1,2)-3),2) -axPosition(i_rt,2);
                rtHeight = axPosition(end,2) - axPosition(1,2);
                
                %[X1 Y1 width height]
                rtPos(i_rt,:) = [rtPosX1 rtPosY1 rtWidth rtHeight];
                
                annotation('rectangle',rtPos(i_rt,:),'FaceColor',RT_FillColor,'EdgeColor',RT_FillColor);
            end
            
        elseif strcmp(SWITCH.timeDirection,'leftright')
            for i_rt=1:PLOT.subplotLayout(1,1)
                j_rt = (i_rt-1)*PLOT.subplotLayout(1,2)+1;
                
                rtWidth = axPosition(1,1) -axPosition(PLOT.subplotLayout(1,2),1);
                rtPosX1 = axPosition(j_rt,1)+axPosition(j_rt,3)/2 -rtWidth;
                %rtWidth = axPosition(j_rt,1) -axPosition(j_rt,1);
                
                rtPosY1 = axPosition(j_rt,2)+(1-rt_partWidth)/2*axPosition(j_rt,4);
                rtHeight = axPosition(j_rt,4)-(1-rt_partWidth)*axPosition(j_rt,4);

                %[X1 Y1 width height]
                rtPos(i_rt,:) = [rtPosX1 rtPosY1 rtWidth rtHeight];
                
                annotation('rectangle',rtPos(i_rt,:),'FaceColor',RT_FillColor,'EdgeColor',RT_FillColor);
            end
        end
    end
end

if ~SWITCH.PlotInPlot || SAVE.LastFile %if PlotInPlot then only for last file
    %% SWITCH ADJUSTEMENTS
    if strcmp(GRID.Type,'yinyang')
        SWITCH.styleBackground  = false; %doesn't work yet
        SWITCH.simplify         = false; %doesn't work yet
        if PLOT.yyNumSlices>1 %for multiple slices
            STYLE.cbFactorX = 1.0; 
        else
            STYLE.cbShiftX  = 0.05;
            STYLE.cbFactorY = 0.7; 
        end
    end
    
    %% SIMPLIFY PLOTS
    if SWITCH.simplify
        [SWITCH,PLOT] = f_simplify(SWITCH,PLOT,GRID);
    end
    
    %% STYLE PLOTS
    if SWITCH.stylePlots
        if isfield(PLOT,'titleColor'); STYLE.titleColor = PLOT.titleColor; end
        if SWITCH.styleLegend; STYLE.Legend = true; else STYLE.Legend = false; end
        STYLE.axisLineWidth           = 0.25;  %1.25;
        if ~isfield(STYLE,'titleLocation'); STYLE.titleLocation = 'centered'; if strcmp(SWITCH.timeDirection,'topbot'); STYLE.titleLocation = 'centered'; end; end
        
        pause(0.1) %let the figure time to adjust
        f_figStyle(STYLE);
    end
    
    %% STYLE BACKGROUND
    if SWITCH.styleBackground && ~(strcmp(GRID.Dim,'3-D') && ~SWITCH.plot3Dtopo2D)
        BACK.colorMode = STYLE.colorMode;
        for isp=1:size(SAVE.graphPlotHandles,1) %only for graph plots
            axes(SAVE.graphPlotHandles(isp,1)); %activate current graph axis
            BACK.ApplyTo            = 'current';
            if isp==1; BACK.display = true; else BACK.display = false; end
            f_background(BACK)
        end
    end
    
    %% SET AXES BACK ON TOP (if neccessary)
    if SWITCH.simplify || SWITCH.styleBackground %in case they were altered
        for i=1:size(SAVE.PlotHandles,1) %loop all subplot axes (including zoom plots)
            pause(0.1)
            axes(SAVE.PlotHandles(i,1)); %set back on top
        end
    end
    
    %% INSERT TIME ARROWS
    if SWITCH.timeEvolution
        STYLE.arrowColor = keyColor;
        f_timeArrows(PLOT,SWITCH,STYLE);
    end
    
    %% ANNOTATIONS
    if SWITCH.annotation
        f_annotations(PLOT,STYLE);
    end
    
    milamin_field_string='';
    if IN.MILAMINcomparison
        if IN.plotTemperature; milamin_field_string=[milamin_field_string,'T_']; end
        if IN.plotComposition; milamin_field_string=[milamin_field_string,'c_']; end
        if IN.plotDensity; milamin_field_string=[milamin_field_string,'rho_']; end
        if IN.plotViscosity; milamin_field_string=[milamin_field_string,'eta_']; end
        if IN.plotEdot; milamin_field_string=[milamin_field_string,'edot_']; end
        if IN.plotStress; milamin_field_string=[milamin_field_string,'s_']; end
        if IN.plotVelocityX; milamin_field_string=[milamin_field_string,'vx_']; end
        if IN.plotVelocityZ; milamin_field_string=[milamin_field_string,'vz_']; end
        if IN.plotPressure; milamin_field_string=[milamin_field_string,'p_']; end
    end
    
    %% SAVING FIGURE
    if SAVE.Plot
        if SWITCH.waitbar;
            display('   ...saving')
            PLOT.wb = waitbar(0.9,PLOT.wb,'saving...');
        end
        if strcmp(STYLE.colorMode,'white')
            SAVE.blackBackground        = 0;
        elseif strcmp(STYLE.colorMode,'black')
            SAVE.blackBackground        = 1;
        end
        if strcmp(SAVE.writeDirectory,'auto'); %save to standard folder (.../+im/...)
            SAVE.Directory = [FILE.stem_im,FILE.name,'/'];
        else
            SAVE.Directory = SAVE.writeDirectory;
        end
        %     SAVE.Directory = [FILE.stem_im,FILE.name,'/+mov3d/']; %special save directory
        %     if SWITCH.dim || SWITCH.dimensional_input; stringDIM = 'DIM_'; else stringDIM=''; end
        
        if SWITCH.plotDifference; string0 = 'diff'; else string0 = ''; end
        if size(IN.fname_vector,2)==1
            stringA = [IN.fname_vector{1,1},'(',num2str(IN.number_vector(1,1)),')'];
        else
            stringA = [IN.fname_vector{1,1},'(',num2str(IN.number_vector(1,1)),')_vs_',IN.fname_vector{1,2},'(',num2str(IN.number_vector(1,2)),')'];
        end
        if size(IN.fname_vector,2)>2
            stringB = ['_vs_',IN.fname_vector{1,3},'(',num2str(IN.number_vector(1,3)),')'];
        else
            stringB = '';
        end
        stringC = fieldString;
        stringD = SWITCH.ColormapAll{1,1};
        if strcmp(SWITCH.ColormapAll{1,2},'flip'); stringE = ['_',SWITCH.ColormapAll{1,2}]; else stringE = ''; end
        
        SAVE.FigureName = ['+',string0,milamin_field_string,stringA,stringB,'_',stringC,'_',stringD,stringE];
        
        SAVE.FigureNr               = 1;
        SAVE.keepAspect             = logical(1);
        SAVE.jpgResolution       	= '-r300';
        f_saveFig( SAVE );
        if SWITCH.waitbar; waitbar(1,PLOT.wb); end
    end
end

%% KEEPING DATA
if isfield(PLOT,'topCval'); SAVE.topCval = PLOT.topCval; end %keeping composition tracker data

%% FINISHING UP
if SWITCH.waitbar
    PLOT.wb = waitbar(1,PLOT.wb,'*** FINISHED ***');
    pause(0.5)
    close(PLOT.wb)
end
display(' ')








