
%%                                                           STAGrprof 3.1

%                                                 plots StagYY's rprof.dat
%    . calls f_background
%    . calls f_dimParameter
%    . calls f_figStyle
%    . calls f_importData
%    . calls f_legendStyle
%    . calls f_saveFig
%    . calls f_startup
%                                               12.12.2015  Fabio Crameri

%% UPDATES >1.0
% *implemented into StagLab*
% *more rprof.dat parameters added*
% *now with option for transparent legend background*
% *default variables added*
% *code simplifications*

%% NOTES
% Be careful with dimensionalisation! Might need some further checking.

function [PLOT] = STAGrprof(IN,PLOT,SWITCH,STYLE,SAVE)
if exist('IN','var') %if run from a parfile
    %% DEFAULT VARIABLES
    %...see f_defaultsRprof.m
else
    clear; clf;
    %% INPUT (...use parameter file instead)
    SAVE.StartNum = 1; SAVE.EndNum = 1;
    [IN,PLOT,SWITCH,STYLE,SAVE] = f_defaultsRprof; %get default variables
    IN.fname_vector   	=   {  'test'  'test' };	% filename
    IN.number_vector    =   [   2           3 	];
    IN.parameter_vector =   [   11          11 	];
    IN.folder_vector	=   {   '/work/plotTest/' ...
                                '/work/plotTest/'    };    
end

%% STARTUP PROCEDURE
SAVE.app = 'STAGrprof'; SAVE.appVersion = '3.1';
if ~isfield(SAVE,'count'); SAVE.count = 0; end
[SAVE,SWITCH] = f_startup(PLOT,SAVE,SWITCH);

%% FIGURE SETUP
clf(figure(1));
if strcmp(STYLE.colorMode,'white')
    colordef(figure(1),'white')
elseif strcmp(STYLE.colorMode,'black')
    colordef(figure(1),'black')
end

ymin_old = 1;
h_runs = zeros(size(IN.fname_vector,2),1); h_runsArea = h_runs;
for irun=1:size(IN.fname_vector,2)
    clearvars -except IN SWITCH PLOT STYLE SAVE ...
        irun fname_vector number_vector parameter_vector folder_vector ...
        save_string color_definition save_folder save_name h_runs h_runsArea ymin_old
        
    FILE.name           = IN.fname_vector{irun};
    FILE.number         = IN.number_vector(irun);
    folder              = IN.folder_vector{irun};
    SWITCH.parameter    = IN.parameter_vector(irun);    
    line_color          = PLOT.ColorVector(irun,:);
    
    nr_plots=0;
    if IN.plotTemperature;          nr_plots = nr_plots+1; parameterX(nr_plots)=2;  log_xaxis(nr_plots)=IN.T_logx;      fieldString{nr_plots}='temperature'; end
    if IN.plotHeatflux;             nr_plots = nr_plots+1; parameterX(nr_plots)=NaN;log_xaxis(nr_plots)=IN.HF_logx;     fieldString{nr_plots}='heatflux'; end
    if IN.plotViscosity;            nr_plots = nr_plots+1; parameterX(nr_plots)=14; log_xaxis(nr_plots)=IN.eta_logx;    fieldString{nr_plots}='viscosity'; end
    if IN.plotStress;               nr_plots = nr_plots+1; parameterX(nr_plots)=20; log_xaxis(nr_plots)=IN.str_logx;    fieldString{nr_plots}='stress'; end
    if IN.plotStrainrate;           nr_plots = nr_plots+1; parameterX(nr_plots)=17; log_xaxis(nr_plots)=IN.edot_logx;   fieldString{nr_plots}='strainrate'; end
    if IN.plotCrust;                nr_plots = nr_plots+1; parameterX(nr_plots)=37; log_xaxis(nr_plots)=IN.c_logx;      fieldString{nr_plots}='crust'; end
    if IN.plotAir;               	nr_plots = nr_plots+1; parameterX(nr_plots)=43; log_xaxis(nr_plots)=IN.c_logx;      fieldString{nr_plots}='air'; end
    if IN.plotContCrust;          	nr_plots = nr_plots+1; parameterX(nr_plots)=46; log_xaxis(nr_plots)=IN.c_logx;      fieldString{nr_plots}='cont. crust'; end
    if IN.plotPrimordial;           nr_plots = nr_plots+1; parameterX(nr_plots)=49; log_xaxis(nr_plots)=IN.c_logx;  	fieldString{nr_plots}='primordial'; end
    if IN.plotFluid;                nr_plots = nr_plots+1; parameterX(nr_plots)=52; log_xaxis(nr_plots)=IN.c_logx;      fieldString{nr_plots}='fluid'; end
    if IN.plotMetal;                nr_plots = nr_plots+1; parameterX(nr_plots)=55; log_xaxis(nr_plots)=IN.c_logx;      fieldString{nr_plots}='metal'; end
    if IN.plotVelocity;             nr_plots = nr_plots+1; parameterX(nr_plots)=5;  log_xaxis(nr_plots)=IN.v_logx;      fieldString{nr_plots}='velocity'; end
    if IN.plotVerticalVelocity;     nr_plots = nr_plots+1; parameterX(nr_plots)=8;  log_xaxis(nr_plots)=IN.vz_logx;     fieldString{nr_plots}='vertical_velocity'; end
    if IN.plotHorizontalVelocity;   nr_plots = nr_plots+1; parameterX(nr_plots)=11; log_xaxis(nr_plots)=IN.vh_logx;     fieldString{nr_plots}='horizontal_velocity'; end
    if IN.plotVertVorticity;      	nr_plots = nr_plots+1; parameterX(nr_plots)=23;	log_xaxis(nr_plots)=IN.w_logx;      fieldString{nr_plots}='vert. vorticity'; end
    if IN.plotHorizVorticity;     	nr_plots = nr_plots+1; parameterX(nr_plots)=26;	log_xaxis(nr_plots)=IN.w_logx;      fieldString{nr_plots}='horiz. vorticity'; end
    if IN.plotDivergence;          	nr_plots = nr_plots+1; parameterX(nr_plots)=29;	log_xaxis(nr_plots)=IN.div_logx;   	fieldString{nr_plots}='divergence'; end
    if IN.plotDensity;              nr_plots = nr_plots+1; parameterX(nr_plots)=40; log_xaxis(nr_plots)=IN.rho_logx;    fieldString{nr_plots}='density'; end
    if IN.plotAdvection;            nr_plots = nr_plots+1; parameterX(nr_plots)=32; log_xaxis(nr_plots)=IN.Hadv_logx; 	fieldString{nr_plots}='thermal advection'; end
    if IN.plotDiffusion;            nr_plots = nr_plots+1; parameterX(nr_plots)=33; log_xaxis(nr_plots)=IN.Hdiff_logx;  fieldString{nr_plots}='thermal diffusion'; end
    if IN.plotInternalHeating;      nr_plots = nr_plots+1; parameterX(nr_plots)=34; log_xaxis(nr_plots)=IN.Rh_logx;     fieldString{nr_plots}='internal_heating'; end
    if IN.plotViscDissipation;      nr_plots = nr_plots+1; parameterX(nr_plots)=35; log_xaxis(nr_plots)=IN.vd_logx;     fieldString{nr_plots}='visc. dissipation'; end
    if IN.plotAdiabaticHeating;   	nr_plots = nr_plots+1; parameterX(nr_plots)=36; log_xaxis(nr_plots)=IN.ah_logx;     fieldString{nr_plots}='adiabatic heating'; end

    if IN.plotToroidal;             nr_plots = nr_plots+1; parameterX(nr_plots)=58; log_xaxis(nr_plots)=IN.To_logx;     fieldString{nr_plots}='toroidal'; end
    if IN.plotToroidalRMS;          nr_plots = nr_plots+1; parameterX(nr_plots)=59; log_xaxis(nr_plots)=IN.To_logx;     fieldString{nr_plots}='toroidal_rms'; end
    if IN.plotPoloidal;             nr_plots = nr_plots+1; parameterX(nr_plots)=60; log_xaxis(nr_plots)=IN.Po_logx;     fieldString{nr_plots}='poloidal'; end
    if IN.plotPoloidalRMS;          nr_plots = nr_plots+1; parameterX(nr_plots)=61; log_xaxis(nr_plots)=IN.Po_logx;     fieldString{nr_plots}='poloidal_rms'; end
    if IN.plotMobility;             nr_plots = nr_plots+1; parameterX(nr_plots)=62; log_xaxis(nr_plots)=IN.M_logx;      fieldString{nr_plots}='mobility'; end
    if IN.plotf80;                  nr_plots = nr_plots+1; parameterX(nr_plots)=63; log_xaxis(nr_plots)=IN.f80_logx;    fieldString{nr_plots}='f80'; end
    if IN.plotf90;                  nr_plots = nr_plots+1; parameterX(nr_plots)=64; log_xaxis(nr_plots)=IN.f90_logx;    fieldString{nr_plots}='f90'; end

    %% CHECK FOR DIRECTORY
    folder_op       = strcat(folder,'+op/');
    folder_im       = strcat(folder,'+im/');
    FILE.directory  = [folder_op,FILE.name,'/']; %needed for f_dimParameter
    filestem        = strcat(folder_op,FILE.name,'/',FILE.name,'_rprof.dat');
    if ~exist(filestem,'file')
        display(filestem)
        error('file not found: CHECK FILESTEM!')
    end
    
    %% RPROF.DAT FILE STRUCTURE
    %  1  2 3  4   5  6  7   8    9  10   11  12  13   14   15   16    17 18 19  20 21 22
    %  z,t0,t1,t2, v0,v1,v2, vz0,vz1,vz2, vh0,vh1,vh2, eta0,eta1,eta2, e0,e1,e2, s0,s1,s2,
    
    %  23 24 25 26 27 28  29 30 31  32   33  34    35        36          37 38 39
    %  w0,w1,w2,w3,w4,w5, d0,d1,d2, adv,diff,Rh,visc.diss,adiab.heating, c0,c1,c2
    
    %  56       57  58
    %  heatflux hf2 hf3
    
    %% OPEN FILE and check its length
    data_1 = fopen(filestem,'r');
    %find #entries in one line automatically
    fgets(data_1);              %reads empty line
    fgets(data_1);              %reads header
    line = fgetl(data_1);       %reads first line
    line = str2num(line);       %converts it to number
    numEntries = size(line,2); 	%number of entries
    frewind(data_1);
    %find #lines automatically
    nLines = 0;
    cc = 0;
    while (fgets(data_1) ~= -1),
        nLines = nLines+1;
        seek = fscanf(data_1,'%8c',[1 1]);
        if strcmp(seek,'********')
            cc=cc+1;
            line_nr_set(cc) = nLines;
        end
    end
    frewind(data_1);
    if numel(line_nr_set)==1
        error('needs at least 2 time steps!')
    elseif numel(line_nr_set)==2
        nz = line_nr_set(2)-line_nr_set(1)  -1;  %#data in z-direction
    else
        nz = line_nr_set(3)-line_nr_set(2)  -1;  %#data in z-direction
    end
    
    %% DISPLAY FILE DETAILS
    display(['Name:              ',FILE.name])
    display(['Number:            ',num2str(FILE.number)])
    if SWITCH.me
        % display(['datafile is ',num2str(n),' x ',num2str(nLines)])
        display(['Data Structure:       __',num2str(numEntries),'__>'])
        display('                     |')
        display(['                   ',num2str(nz)])
        display('                     |')
        display('                     V')
    end
    
    %% READING DATA
    %define plotted filenumber
    if FILE.number==9999
        FILE.number=cc;  %max. file number
    else
        FILE.number=FILE.number+1;  %chosen file number
    end
    %skip first line
    num_skip_lines = line_nr_set(FILE.number) ;
    %jump to given line number
    nLines = 0;
%     cc = 0;
    while (fgets(data_1)~=-1)
        nLines = nLines+1;
        if (nLines==num_skip_lines)
            break
        end
    end
    %read header
    line = fscanf(data_1,'%s',[1 1]);
    i_time_step = fscanf(data_1,'%i',[1 1]);   %time step
    line = fscanf(data_1,'%s %s %s',[1 3]);
    time = fscanf(data_1,'%f',[1 1]);   %time
    %read data
    wb = waitbar(0,'Please wait...');
    my_data = zeros(nz,numEntries)*NaN;
    for j=1:nz
        waitbar(j/nz,wb)
        line = fscanf(data_1,'%e',[1 numEntries]);
        my_data(j,:)=line;        
    end
    close(wb)
    fclose(data_1);
    
    %% CHECK DETAILS OF INPUT FILE
    if max(my_data(:,1))>0.5 && max(my_data(:,1))<1.5  %if 0.5<D<1.5 then non-dimensional
        SWITCH.dimensional_input = false; display('Input:             non-dimensional');
    else
        SWITCH.dimensional_input = true; display('Input:             dimensional');
    end
    
    %% GET DIMENSIONAL PARAMETERS
    [SETUP,SWITCH] = f_dimParameter(SWITCH,FILE);
    if SWITCH.dim || SWITCH.dimensional_input
        SETUP.wscale    = SETUP.edotscale *SETUP.secyear*1e6; %[1/s]->[1/Ma]  vorticity scale
        SETUP.divscale 	= SETUP.wscale; %[1/s]->[1/Ma]  divergence scale
    else
        SETUP.wscale    = 1; 
        SETUP.divscale  = 1;
    end
    
    %% GET SUITABLE DEPTH VECTOR DIMENSION
    if SWITCH.dim || SWITCH.dimensional_input
        GRID.dimFactor      = SETUP.lengthscale;	%[m]
        %plotting variables
        if abs(max(my_data(:,1)*SETUP.lengthscale))>1e3 % >1km
            GRID.dimFactor  = GRID.dimFactor /1e3;	%[km]
            GRID.Zdim       = 'km';
        elseif abs(max(my_data(:,1)*SETUP.lengthscale))>1 % >1m
            GRID.dimFactor  = GRID.dimFactor;       %[m]
            GRID.Zdim       = 'm';
        else % <1m
            GRID.dimFactor = GRID.dimFactor *1e2;	%[cm]
            GRID.Zdim       = 'cm';
        end
    else
        GRID.ndFactor       = 1;                    %[nd]
        GRID.dimFactor      = GRID.ndFactor;        %[nd]
        GRID.Zdim           = 'nd';
    end
    
    %% SETUP DEPTH VECTOR
    %setup z-vector for grid cell tops or bottoms (e.g. vertical velocity)  
    %  (is one value too large for rprof data, not sure if top or bottom.........)
    % my_data(1,1)	 => bottom   => z=0
    % my_data(end,1) => surface  => z=1
    dz_prof             = my_data(2:end,1) - my_data(1:end-1,1);
    dz_bot              = (my_data(1,1) - 0)*2;
    dz_top              = (1 - my_data(end,1))*2;
    dz_prof             = [dz_bot; dz_prof; dz_top]; %put additional dz for top and bottom boundary
    z_edge_prof_full    = my_data(:,1) - dz_prof(1:end-1,1)/2; %
    z_edge_prof_full    = [z_edge_prof_full; (z_edge_prof_full(end,1)+dz_prof(end,1))];  %z from 0 to 1
%     z_edge_prof          = z_edge_prof_full(2:end,1);   %z from ~0 to 1 %grid cell interior values, like T and p
   
    %% SET MIN/MAX VARIABLE VALUES
    if SWITCH.dim || SWITCH.dimensional_input
        zmin    = -500;     	zmax    = 3000;
        Tmin    = 0;            Tmax    = 2500;
        etamin  = 1e18;         etamax  = 1e29;
        edotmin = 1e-18;        edotmax = 1e-13;
        rhomin  = 2800;         rhomax  = 3400;
        strmin  = 0;            strmax  = 500;
        vmin    = 0;            vmax    = 3;
        Rhmin   = 0;            Rhmax   = 6e-12;
        hfmin   = 0;            hfmax   = 1000;
    else %non-dim
        zmin    = -0.05;     	zmax    = 0.95;
        Tmin    = 0;            Tmax    = 1;
        etamin  = 1e-4;         etamax  = 1e5;
        edotmin = 0;            edotmax = 7e4;
        rhomin  = -6e4;         rhomax  = 6e4;
        strmin  = 0;            strmax  = 7e4;
        vmin    = 0;            vmax    = 5000;
        Rhmin   = 0;            Rhmax   = 25;
        hfmin   = 0;            hfmax   = 0.5;
    end
    
    %% SETUP DATA DETAILS
    %   1                       2                       3                       4           5           6       
    %  	name                    variable                dim. scale              dimension   min.value   max.value
    FIELD_M      = {
        'depth'                 'z'                     GRID.dimFactor          GRID.Zdim   zmin        zmax        %1
        'temperature'           'T_{mean}'           	SETUP.Tscale            'K'         Tmin      	Tmax        %2
        't1'                    'T_{min}'               SETUP.Tscale            'K'         Tmin      	Tmax        %3
        't2'                    'T_{max}'               SETUP.Tscale            'K'         Tmin      	Tmax        %4
        'velocity'              'v_{mean}'           	SETUP.Vscale            'cm/a'      vmin       	vmax        %5
        'v1'                    'v_{min}'               SETUP.Vscale            'cm/a'      vmin       	vmax        %6
        'v2'                    'v_{max}'               SETUP.Vscale            'cm/a'      vmin       	vmax        %7
        'vertical velocity'     'vz_{mean}'           	SETUP.Vscale            'cm/a'      vmin       	vmax        %8
        'vz1'                   'vz_{min}'            	SETUP.Vscale            'cm/a'      vmin       	vmax        %9
        'vz2'                   'vz_{max}'           	SETUP.Vscale            'cm/a'      vmin       	vmax        %10
        'horizontal velocity'   'vh_{mean}'          	SETUP.Vscale            'cm/a'      vmin       	vmax        %11
        'vh1'                   'vh_{min}'            	SETUP.Vscale            'cm/a'      vmin       	vmax        %12
        'vh2'                   'vh_{max}'              SETUP.Vscale            'cm/a'      vmin       	vmax        %13
        'viscosity'             '\eta_{mean}'           SETUP.etascale        	'Pa s'      etamin      etamax      %14
        'eta1'                  '\eta_{min}'            SETUP.etascale        	'Pa s'      etamin      etamax      %15
        'eta2'                  '\eta_{max}'            SETUP.etascale        	'Pa s'      etamin      etamax      %16
        'strain rate'           'UCvarepsilondot_{mean}' SETUP.edotscale       	's^{-1}'    edotmin     edotmax     %17
        'e1'                    'UCvarepsilondot_{min}' SETUP.edotscale         's^{-1}'    edotmin     edotmax     %18
        'e2'                    'UCvarepsilondot_{max}' SETUP.edotscale         's^{-1}'    edotmin     edotmax     %19
        'stress'                '\sigma_{mean}'         SETUP.stressscale       'MPa'       strmin      strmax      %20
        's1'                    '\sigma_{min}'          SETUP.stressscale       'MPa'       strmin      strmax      %21
        's2'                    '\sigma_{max}'          SETUP.stressscale       'MPa'       strmin      strmax      %22
        'vert. vorticity'    	'w_{h,mean}'           	SETUP.wscale        	'Ma^{-1}' 	0           0.5         %23  ?
        'w1'                   	'w_{h,min}'           	SETUP.wscale        	'Ma^{-1}' 	0           0.5         %24  ?
        'w2'                    'w_{h,max}'            	SETUP.wscale        	'Ma^{-1}' 	0           0.5         %25  ?
        'horiz. vorticity'  	'w_{v,mean}'         	SETUP.wscale            'Ma^{-1}' 	0           0.5         %26  ?
        'w4'                    'w_{v,min}'            	SETUP.wscale            'Ma^{-1}' 	0           0.5         %27  ?
        'w5'                    'w_{v,max}'         	SETUP.wscale            'Ma^{-1}'	0           0.5         %28  ?
        'divergence'          	'div_{mean}'         	SETUP.divscale      	'Ma^{-1}'  	0           1e-2       	%29  ?
        'd1'                    'div_{min}'           	SETUP.divscale          'Ma^{-1}'  	0           1e-2        %30  ?
        'd2'                    'div_{max}'           	SETUP.divscale       	'Ma^{-1}'  	0           1e-2        %31  ?
        'thermal advection'    	'H_{adv}'               SETUP.HRscale        	'K/s'      	0           1           %32
        'thermal diffusion'    	'H_{diff}'              SETUP.HRscale         	'K/s'     	0           1           %33
        'internal heating'      'H_{int}'             	SETUP.Hscale         	'W/kg'      Rhmin       Rhmax       %34
        'viscous dissipation'  	'H_{diss}'           	SETUP.HRscale          	'K/s'   	0           1           %35
        'adiabatic heating'    	'H_{adi}'             	SETUP.HRscale         	'K/s'   	0           1           %36
        'crust'                 'crust_{mean}'        	1                       '-'         0           1           %37
        'c1'                    'c1'                    1                       '-'         0           1           %38
        'c2'                    'c2'                    1                       '-'         0           1           %39
        'density'            	'rho_{mean}'         	SETUP.rhoscale      	'kg/m^3'  	rhomin      rhomax      %40
        'rho1'               	'rho_{min}'             SETUP.rhoscale          'kg/m^3'   	rhomin      rhomax      %41
        'rho2'                 	'rho_{max}'             SETUP.rhoscale        	'kg/m^3'   	rhomin      rhomax      %42
        'air'                 	'air_{mean}'         	1                       '-'       	0           1         	%43
        'air1'                  'air_{min}'            	1                       '-'      	0           1        	%44
        'air2'                 	'air_{max}'           	1                       '-'      	0           1        	%45
        'primordial'           	'prim_{mean}'       	1                       '-'      	0           1        	%46
        'prim1'                 'prim_{min}'        	1                       '-'      	0           1       	%47
        'prim2'                	'prim_{max}'           	1                       '-'       	0           1           %48
        'cont. crust'        	'cc_{mean}'         	1                       '-'      	0           1         	%49
        'cc1'                   'cc_{min}'            	1                       '-'      	0           1        	%50
        'cc2'                 	'cc_{max}'           	1                       '-'       	0           1        	%51
        'fluids'               	'f_{mean}'              1                       '-'     	0           1        	%52
        'f1'                    'f_{min}'               1                       '-'       	0           1       	%53
        'f2'                	'f_{max}'           	1                       '-'      	0           1           %54
        'metal'               	'metal_{mean}'       	1                       '-'      	0           1        	%55
        'metal1'              	'metal_{min}'        	1                       '-'       	0           1       	%56
        'metal2'            	'metal_{max}'        	1                       '-'       	0           1           %57
        ... %THIS IS OPTIONAL IN STAGYY
        'toroidal prof'         'to'                    SETUP.Vscale            'cm/a'      vmin       	vmax        %58
        'toroidal rms'          'to_{rms}'              SETUP.Vscale            'cm/a'      vmin       	vmax        %59
        'poloidal prof'         'po'                    SETUP.Vscale            'cm/a'      vmin       	vmax        %60
        'poloidal rms'        	'po_{rms}'              SETUP.Vscale            'cm/a'      vmin       	vmax        %61
        'mobility (vrms)'       'm'                     1                       '-'         0           1           %62
        'plateness (f80)'       'f80'                   1                       '-'         0           1           %63
        'plateness (f90)'     	'f90'                   1                       '-'         0           1           %64
        ... %THIS IS CALCULATED LOCALLY IN STAGrprof
        'heat flux'             'hf_{mean}'             1                       'W/m'       hfmin       hfmax       %end-2
        'hf1'                   'hf_{min}'              1                       'W/m'       hfmin       hfmax       %end-1
        'hf2'                   'hf_{max}'              1                       'W/m'       hfmin       hfmax       %end
        };

    %% UNICODE VARIABLES
    %use the following character sequence to add unicode variables:
    %UCvarepsilondot => char(941)
    %UCvarepsilon => char(949)
    FIELD_M(:,2) = strrep(FIELD_M(:,2),'UCvarepsilondot',{char(941)}); %does only work if string consists ONLY of unicode character
    FIELD_M(:,2) = strrep(FIELD_M(:,2),'UCvarepsilon',{char(949)}); %does only work if string consists ONLY of unicode character

%     zg(1,iz),(tprof(j,iz),j=1,3),(vprof(j,iz),j=1,3),(vzprof(j,iz),j=1,3),&
%                       (vhprof(j,iz),j=1,3),(etaprof(j,iz),j=1,3),(eprof(j,iz),j=1,3)
%                  write(1,'(38(1pe12.4))') (sprof(j,iz),j=1,3),((wprof(j,iz,k),j=1,3),k=1,2), &
%                       (dprof(j,iz),j=1,3),(enprof(j,iz),j=1,5),(cprof(j,iz),j=1,3),(denprof(j,iz),j=1,3), &
%                       (airprof(j,iz),j=1,3),(primprof(j,iz),j=1,3),(ccprof(j,iz),j=1,3),(fprof(j,iz),j=1,3), &
%                       (metalprof(j,iz),j=1,3)
    
    % FIELD ADJUSTMENTS
    if ~SWITCH.dim && ~SWITCH.dimensional_input
        FIELD_M(:,4) = {'nd'};
    end 

    % SET AND INDICATE TIME
    PLOT.time       = time;     %[nd] or [dim]
    PLOT.time_dim   = time*SETUP.timescale/SETUP.secyear;  %get dimensional time [a]
    if PLOT.time_dim/1e6>100
        PLOT.time2plot = PLOT.time_dim/1e9; PLOT.time2plotDim = 'Ga'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e9;
    elseif PLOT.time_dim/1e6<1e-7 %0.0000001
        PLOT.time2plot = PLOT.time_dim*SETUP.secyear; PLOT.time2plotDim = 's'; PLOT.timeConvert = SETUP.timescale;
    elseif PLOT.time_dim/1e6<1e-4 %0.0001
        PLOT.time2plot = PLOT.time_dim; PLOT.time2plotDim = 'a'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear;
    elseif PLOT.time_dim/1e6<1e-1 %0.1
        PLOT.time2plot = PLOT.time_dim/1e3; PLOT.time2plotDim = 'ka'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e3;
    else
        PLOT.time2plot = PLOT.time_dim/1e6; PLOT.time2plotDim = 'Ma'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e6;
    end
    if ~SWITCH.dim && ~SWITCH.dimensional_input; PLOT.time2plot = PLOT.time; PLOT.time2plotDim = 'nd'; PLOT.timeConvert = 1; end
    display(['Time (non-dim):    ',num2str(PLOT.time,3)])
    display(['Time (dim):        ',num2str(PLOT.time2plot,3),' ',PLOT.time2plotDim])
    
    %% CALCULATE HEATFLUX FROM T-PROFILE
    if IN.plotHeatflux
        %adjust parameters calculated locally
        parameterX(1,ismember(fieldString(:),'heatflux')) = size(FIELD_M,1)-2;   %heatflux is 3rd last entry
    
        z_vector                    = my_data(:,1);  %*dim_scale(IN.plotParameterY);
        z_vector_gradient           = z_vector(2:end) - ( z_vector(2:end)-z_vector(1:end-1) )/2;  % z_new = z_old + dz/2
        z_vector_gradient(end+1)    = NaN; %max(z_vector_gradient);
        
        T_prof          = my_data(:,2)*FIELD_M{2,3};
        T_prof_min      = my_data(:,3)*FIELD_M{2,3};
        T_prof_max      = my_data(:,4)*FIELD_M{2,3};
        
        HF_prof         = SETUP.tcond_dimensional * ( T_prof(1:end-1) - T_prof(2:end) ); %calculate heat flux from temperature: Q = k*[T(z+1)-T(z)]  [W/m]  (upward positive)
        HF_prof_min     = SETUP.tcond_dimensional * ( T_prof_min(1:end-1) - T_prof_min(2:end) );
        HF_prof_max     = SETUP.tcond_dimensional * ( T_prof_max(1:end-1) - T_prof_max(2:end) );
        
        my_data(1:end-1,parameterX(strcmp(fieldString,'heatflux'))) = HF_prof;          my_data(end,parameterX(strcmp(fieldString,'heatflux'))) = NaN;
        my_data(1:end-1,parameterX(strcmp(fieldString,'heatflux'))+1) = HF_prof_min;    my_data(end,parameterX(strcmp(fieldString,'heatflux'))+1) = NaN;
        my_data(1:end-1,parameterX(strcmp(fieldString,'heatflux'))+2) = HF_prof_max;    my_data(end,parameterX(strcmp(fieldString,'heatflux'))+2) = NaN;
    end
    
    %% REVERSE Z-AXIS
    if IN.reverseYaxis
        if SWITCH.dimensional_input
            max_z = SETUP.D;
        else
            max_z = 1.0;
        end
        my_data(:,1)    = max_z-my_data(:,1);    
%         z_edge_prof     = max_z-z_edge_prof; %need to take max_z for all z-data! %grid cell interior values, like T and p
        if IN.plotHeatflux; z_vector_gradient = max_z-z_vector_gradient; end
        my_data(:,1) = my_data(:,1)-SETUP.d_air;  %set actual depth, i.e., z=0 to rock-air interface
%         z_edge_prof = z_edge_prof-SETUP.d_air;   %set z=0 to real surface %grid cell interior values, like T and p
        if IN.plotHeatflux; z_vector_gradient(:,1) = z_vector_gradient(:,1)-SETUP.d_air; end
    end
    
    %% PLOTTING
    num_subplot=0;
    hax = zeros(nr_plots,1);
    for iloop=1:nr_plots
        plotParameterX      = parameterX(iloop);
        plot_log_xaxis      = log_xaxis(iloop);
        
        %check for separate min/max variables
        if plotParameterX<=31 || (plotParameterX>=37 && plotParameterX<=57) %separate min/max values available
            minmaxAvailable = true;
        else
            minmaxAvailable = false;
        end
        
        %choose appropriate z_vector:
        if strcmp(fieldString(iloop),'heatflux') 
            plot_z_vector   = z_vector_gradient;  %for heat flux
        else
%             if strcmp(fieldString(nr_loop),'vertical_velocity')
%                 plot_z_vector = z_edge_prof; %grid cell interior values, like T and p
%             else
            plot_z_vector = my_data(:,IN.plotParameterY); %everything else
%             end
        end
        
        %% SETUP FIGURE
        figure(1); hold on
        
        %% SETUP SUBPLOT
        if nr_plots>1
            num_subplot=num_subplot+1;
            if nr_plots>4
                if mod(nr_plots,2)
                    hax(iloop,1) = subplot(2,(nr_plots+1)/2,num_subplot);
                else
                    hax(iloop,1) = subplot(2,nr_plots/2,num_subplot);
                end
            else
                hax(iloop,1) = subplot(1,nr_plots,num_subplot);
            end
        else
            hax(iloop,1) = gca;
        end
        
        %% SETUP PLOT APPEARANCE
        if iloop==1; IN.LineWidth_plot = IN.LineWidth_plot+0.1; end %wider first line
        
        %% DIMENSIONALISATION        
        zData       = plot_z_vector *FIELD_M{IN.plotParameterY,3};
        rmsData     = my_data(:,plotParameterX) *FIELD_M{plotParameterX,3};
        
        %% PLOT RMS LINE (and min/max lines)
        colourMax = [0.81 0.33 0.2];
        colourMin = [0.4 0.64 0.18];
        if plot_log_xaxis %LOGARITHMIC x_axis
            if PLOT.parameter_range && minmaxAvailable
                minData = my_data(:,plotParameterX+1)*FIELD_M{plotParameterX,3};
                maxData = my_data(:,plotParameterX+2)*FIELD_M{plotParameterX,3};
                if PLOT.rangeAsArea
                    %logarithmic min/max area
                    edgecolor = 'none';
                    areaAlpha = 0.2;
                    hold on
                    pp4 = fill([maxData' fliplr(minData')],[zData' fliplr(zData')],line_color,'EdgeColor',edgecolor,'EdgeAlpha',areaAlpha,'FaceAlpha',areaAlpha);
                else
                    %logarithmic min/max lines
                    hold on
                    pp2 = semilogx(minData,zData,'Color',colourMin);
                    hold on
                    pp3 = semilogx(maxData,zData,'Color',colourMax);
                end
            end
            pp1 = semilogx(rmsData,zData,'Color',line_color,'LineWidth',IN.LineWidth_plot);
            
        else %NORMAL x_axis
            if PLOT.parameter_range && minmaxAvailable
                minData = my_data(:,plotParameterX+1)*FIELD_M{plotParameterX,3};
                maxData = my_data(:,plotParameterX+2)*FIELD_M{plotParameterX,3};
                if PLOT.rangeAsArea
                    %min-max area
                    edgecolor = 'none';
                    areaAlpha = 0.2;
                    hold on
                    pp4 = fill([maxData' fliplr(minData')],[zData' fliplr(zData')],...
                        line_color,'EdgeColor',edgecolor,'EdgeAlpha',areaAlpha,'FaceAlpha',areaAlpha);
                else
                    %min/max lines
                    hold on
                    pp2=plot(minData,zData,'Color',colourMin);
                    hold on
                    pp3=plot(maxData,zData,'Color',colourMax);
                end
            end
            pp1 = plot(rmsData,zData,'Color',line_color,'LineWidth',IN.LineWidth_plot);
        end

        %% INDIVIDUAL LEGENDS
        if PLOT.parameter_range && minmaxAvailable
            if PLOT.rangeAsArea
                h_runsArea(irun,1) = pp4;
                if IN.show_legend
                    legend([pp1,pp4],[FIELD_M(plotParameterX,2),'Min-Max Area'],'Location','Best');
                end
            else %plot min/max as lines
                if IN.show_legend
                    legend([pp1,pp2,pp3],[FIELD_M(plotParameterX,2),FIELD_M(plotParameterX+1,2),FIELD_M(plotParameterX+2,2)],'Location','Best');
                end
            end
        else
            if IN.show_legend
                legend(pp1,FIELD_M(plotParameterX,2),'Location','Best');
            end
        end
        h_runs(irun,1) = pp1;
        
        %% AXIS LABELLING
        xlabel([FIELD_M{plotParameterX,1},' [',FIELD_M{plotParameterX,4},']'])
        ylabel([FIELD_M{IN.plotParameterY,1},' [',FIELD_M{IN.plotParameterY,4},']'])
        
        %% AXIS SETTINGS
        grid on
        if IN.reverseYaxis
            axis ij
            ymin = min(plot_z_vector*FIELD_M{IN.plotParameterY,3});
            ymax = max(plot_z_vector*FIELD_M{IN.plotParameterY,3});
            if ymin<ymin_old
                set(gca,'YLim',[ymin ymax])
                if iloop==nr_plots; ymin_old = ymin; end
            end
        end
        %constant axes
        if IN.constant_axis
            axis([FIELD_M{plotParameterX,5} FIELD_M{plotParameterX,6} zmin zmax]);
        else
            %check for sensible x-axis values - preventing 0.00001 values
            xMinMax = get(gca,'xlim');
            xminNearInt = round(xMinMax(1,1));
            xminDiffNearInt = abs(xMinMax(1,1)-xminNearInt);
            if xminDiffNearInt~=0 && xminDiffNearInt<(xMinMax(1,2)-xMinMax(1,1))/100 %100 is an arbitrary value
                set(gca,'xlim',round(get(gca,'xlim')))
            end
        end
        
        %% DISPLAY PARAMETER INFO
        if iloop==1; display('Maximum Values:'); end
        tabLength       = 20;
        lengthString    = size(fieldString{1,iloop},2);
        whiteSpace(1,1:max(1,tabLength-lengthString)) = ' ';
        if minmaxAvailable %separate min/max values available
            display(['    ',fieldString{1,iloop},whiteSpace,' = ',num2str(max(my_data(:,plotParameterX+2)*FIELD_M{plotParameterX,3}),3),' ',FIELD_M{plotParameterX,4}])
        else %no separate min/max values available
            display(['    ',fieldString{1,iloop},whiteSpace,' = ',num2str(max(my_data(:,plotParameterX)*FIELD_M{plotParameterX,3}),3),' ',FIELD_M{plotParameterX,4}])
        end
        clearvars whiteSpace tabLength lengthString

        %% ADDITIONAL POSTPROCESSING
        if SWITCH.d_eta && iloop==2
            yyy     = my_data(:,IN.plotParameterY)*FIELD_M{IN.plotParameterY,3};
            xxx     = my_data(:,plotParameterX+1)*FIELD_M{plotParameterX,3};
            ind_y   = min(yyy(find(yyy>500)));
            ind_x   = xxx(max(find(yyy>500)));
            ind2_y  = max(yyy(find(yyy<2500)));
            ind2_x  = xxx(min(find(yyy<2500)));
            hold on
            plot([ind_x ind2_x],[ind_y ind2_y],'o','MarkerEdgeColor',[0.0 0.0 1.0])
            
            delta_visc      = ind2_x-ind_x;
            delta_d         = ind2_y-ind_y;
            gradient_eta    = delta_visc/delta_d*1000;
            
            text(2e20,2800,['\Delta\eta = ',num2str(gradient_eta,3),' [(Pa s)/1000km]'],'Color','w','backgroundcolor','b');
        end
        %pause(0.5)
    end %loop
    
    %% GENERAL LABELLING
    %figure title
    if SWITCH.title
        figure(1); hold on
        axes('position',[0 0 1 1],'visible','off')
        text(0.5,0.97,['file number = ',num2str(FILE.number-1),'; time step = ',num2str(i_time_step),'; time = ',num2str(PLOT.time,3),' ',PLOT.time2plotDim],'HorizontalAlignment','center')
    end
    
    %% LOOP OUTPUT
%     save_string = ([IN.save_string,FILE.name,'_',num2str(FILE.number-1),'_']);
    %pause(0.5)
    display(' ')
end

%% LEGEND
if isfield(PLOT,'titleString'); legendANN = PLOT.titleString'; else legendANN = IN.fname_vector'; end
for ientry=1:size(legendANN,1);
    dummy = ['RMS',' ',legendANN{ientry,1}];
    legendANN_full(1,ientry) = cellstr(dummy);
end

if PLOT.parameter_range && PLOT.rangeAsArea && h_runsArea(1,1)~=0
    for ientry=1:size(legendANN,1);
        dummy = ['Range',' ',legendANN{ientry,1}];
        legendANNrange(1,ientry) = cellstr(dummy);
    end
    dummy = [legendANN_full; legendANNrange];
    legendANN_combined = dummy(:)';
    dummy = [h_runs'; h_runsArea'];
    h_runs_combined = dummy(:)';
    hl = legend(h_runs_combined',legendANN_combined{:,:},'Location',PLOT.LegendLocation);
else
    hl = legend(h_runs,legendANN_full{:,:},'Location',PLOT.LegendLocation);
end
set(hl,'Interpreter','none');

%% STYLING
if SWITCH.stylePlots
    if SWITCH.styleLegend; STYLE.Legend = true; else STYLE.Legend = false; end
    f_figStyle(STYLE);
end
if SWITCH.styleBackground
    BACK.ApplyTo    = 'all';          %'current', 'all'
    BACK.colorMode  = STYLE.colorMode;
    f_background(BACK) %set plot background of each subplot
end

%% ANNOTATION
if SWITCH.annotation
%     pause(0.5);
    f_annotations(PLOT,STYLE);
end

%% SAVING PLOTS
if SAVE.Plot
    SAVE.Directory = strcat(folder_im,FILE.name,'/');
    if strcmp(STYLE.colorMode,'white')
        SAVE.blackBackground=0;
    elseif strcmp(IN.color_definition,'black')
        SAVE.blackBackground=1;
    end
    if strcmp(STYLE.colorMode,'black'); endix='_black'; else endix=''; end
    SAVE.FigureName = strcat(IN.save_string,endix);   %file name
    if SWITCH.dim
        SAVE.FigureName = strcat(SAVE.FigureName,'_DIM');
    end
    
    SAVE.FigureNr               = 1;
    SAVE.keepAspect             = logical(1);
    SAVE.jpgResolution       	= '-r500';
    
    f_saveFig( SAVE )
end

%% FINISHING UP
display(' ')
display('                      FINISHED.')











