
%% SET MIN & MAX COLORBAR PARAMETERS

% Fabio Crameri, 30.07.2014

function [CB] = f_cbRange(IN,dimensional,loop_case)

%% DEFAULT VALUES
CB.multipleMinMax = false;
if dimensional
    CB.topo_min     = -9;           CB.topo_max     = 7;
    CB.dyntopo_min  = -2;           CB.dyntopo_max  = 2;
    CB.isotopo_min  = -10;          CB.isotopo_max  = 10;
    CB.T_min        = 300;          CB.T_max        = 2500;
    CB.Tres_min     = -400;         CB.Tres_max     = 400;
    CB.str_max      = 1000;         CB.str_min      = 0;
    CB.nstr_max     = 800;          CB.nstr_min     = -800;
    CB.edot_max     = 1e-14;        CB.edot_min     = 0;
    CB.eta_min      = 10^(18.8);    CB.eta_max      = 10^(27.8);
    CB.vel_min      = 0;            CB.vel_max      = 5;
    CB.rho_min      = 3200;         CB.rho_max      = 3450;
    CB.P_min        = 0;            CB.P_max        = 140;
    CB.geoid_min    = -50;          CB.geoid_max    = 50;
else
    CB.topo_min     = -0.05;        CB.topo_max     = 0.05;
    CB.dyntopo_min  = -0.05;        CB.dyntopo_max  = 0.05;
    CB.isotopo_min  = -0.1;         CB.isotopo_max  = 0.1;
    CB.T_min        = 0;            CB.T_max        = 1;
    CB.Tres_min     = -0.4;         CB.Tres_max     = 0.4;
    CB.str_max      = 1e5;          CB.str_min      = 0;
    CB.nstr_max     = 1e4;          CB.nstr_min     = -1e4;
    CB.edot_max     = 1e-14;        CB.edot_min     = 0;  %????????? is that also the appropriate non-dim value?
    CB.eta_min      = 1e-4;         CB.eta_max      = 1e5;
    CB.vel_min      = 0;            CB.vel_max      = 400;
    CB.rho_min      = 0.9697;     	CB.rho_max      = 1.0455;
    CB.P_min        = 0;            CB.P_max        = 2e2;
    CB.geoid_min    = -0.05;       	CB.geoid_max    = 0.05;
end
CB.topo_log 	= false;
CB.dyntopo_log  = false;
CB.isotopo_log  = false;
CB.T_log        = false;
CB.Tres_log     = false;
CB.str_log      = false;
CB.nstr_log     = false;
CB.edot_log     = false;
CB.eta_log      = true;
CB.vel_log      = false;
CB.rho_log      = false;
CB.P_log        = false;
CB.geoid_log    = false;


%% CHECK FOR LOG(10) & ANY INPUT VALUES
name = {'topo' 'dyntopo' 'T' 'Tres' 'str' 'nstr' 'edot' 'eta' 'vel' 'rho' 'P'};

for ind = 1:length(name)
    %check for input
    if isfield(IN,[name{ind},'_min'])
        if size(IN.([name{ind},'_min']),2)>1 %vector
            CB.([name{ind},'_min']) = IN.([name{ind},'_min'])(1,loop_case);
            CB.multipleMinMax = true;
        else %single value
            CB.([name{ind},'_min']) = IN.([name{ind},'_min']);
        end
    end
    if isfield(IN,[name{ind},'_max'])
        if size(IN.([name{ind},'_max']),2)>1 %vector
            CB.([name{ind},'_max']) = IN.([name{ind},'_max'])(1,loop_case);
            CB.multipleMinMax = true;
        else %single value
            CB.([name{ind},'_max']) = IN.([name{ind},'_max']);
        end
    end
    if isfield(IN,[name{ind},'_log'])
        CB.([name{ind},'_log']) = IN.([name{ind},'_log']);
    end
    
    %take the log10
    if CB.([name{ind},'_log'])
        CB.([name{ind},'_max']) = log10(CB.([name{ind},'_max']));
        CB.([name{ind},'_min']) = log10(CB.([name{ind},'_min']));
    end
end


end
