%% READ REFSTAT.DAT FILE

function [PARA] = f_importData(FILE,GRID)

filestem = [FILE.directory,FILE.name,'_refstat.dat'];

%% Initialize variables.
delimiter = ' ';
if nargin<=2
    startRow    = 3;
    endRow      = startRow+GRID.nz;    %%% NEEDS CHECK IF THAT IS THE SIZE OF REFSTAT data column AS WELL...
end

%% Format string for each line of text:
%   column1: double (%f)
%	column2: double (%f)
%   column3: double (%f)
%	column4: double (%f)
%   column5: double (%f)
%	column6: double (%f)
%   column7: double (%f)
% For more information, see the TEXTSCAN documentation.
formatSpec = '%f%f%f%f%f%f%f%*s%[^\n\r]';

%% Open the text file.
fileID = fopen(filestem,'r');

%% Read columns of data according to format string.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false);
for block=2:length(startRow)
    frewind(fileID);
    dataArrayBlock = textscan(fileID, formatSpec, endRow(block)-startRow(block)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'HeaderLines', startRow(block)-1, 'ReturnOnError', false);
    for col=1:length(dataArray)
        dataArray{col} = [dataArray{col};dataArrayBlock{col}];
    end
end

%% Close the text file.
fclose(fileID);

%% Post processing for unimportable data.
% No unimportable data rules were applied during the import, so no post
% processing code is included. To generate code which works for
% unimportable data, select unimportable cells in a file and regenerate the
% script.

%% Allocate imported array to column variable names
PARA.z          = dataArray{:, 1};
PARA.Tref       = dataArray{:, 2};
PARA.rho        = dataArray{:, 3};
PARA.expan      = dataArray{:, 4};
PARA.Cp         = dataArray{:, 5};
PARA.Tkappa     = dataArray{:, 6};
PARA.Tcond      = dataArray{:, 7};


