
%INPUT:
% DATA.filename
% DATA.startRow  (optional)
% DATA.endRow    (optional)

function [DATA] = f_importTimedat(DATA)
%IMPORTFILE Import numeric data from a text file as column vectors.
%  Reads data from rows STARTROW
%   through ENDROW of text file FILENAME.


%% Initialize variables.
delimiter = ' ';
DATA.TitleStartRow = 1;
DATA.TitleEndRow = 1;
if nargin<=2  %if no further function input, set standard variables
    DATA.startRow = 2;
    DATA.endRow = inf;
end

%% Format string for each line of text:
% For more information, see the TEXTSCAN documentation.
formatSpecTitle = '%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s';
formatSpec = '%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%[^\n\r]';

%% Open the text file.
fileID = fopen(DATA.filename,'r');


%% Read columns of title according to format string.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
titleArray = textscan(fileID, formatSpecTitle, DATA.TitleEndRow(1)-DATA.TitleStartRow(1)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'ReturnOnError', false);

% Title comparison check
if strcmp(DATA.title(1,end),titleArray{1,end}) && ...
        size(titleArray,2)==size(DATA.title,2)
else
    warning('!!! check new format of data file !!!');
end

%% Read columns of data according to format string.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
DATA.Array = textscan(fileID, formatSpec, DATA.endRow(1)-DATA.startRow(1)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'HeaderLines', DATA.startRow(1)-1, 'ReturnOnError', false);
for block=2:length(DATA.startRow)
    frewind(fileID);
    DATA.ArrayBlock = textscan(fileID, formatSpec, DATA.endRow(block)-DATA.startRow(block)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'HeaderLines', DATA.startRow(block)-1, 'ReturnOnError', false);
    for col=1:length(DATA.Array)
        DATA.Array{col} = [DATA.Array{col};DATA.ArrayBlock{col}];
    end
end

%% Close the text file.
fclose(fileID);

%% Post processing for unimportable data.
% No unimportable data rules were applied during the import, so no post
% processing code is included. To generate code which works for
% unimportable data, select unimportable cells in a file and regenerate the
% script.

%% Allocate imported array to column variable names
% istep = DATA.Array{:, 1};
% time = DATA.Array{:, 2};
% F_top = DATA.Array{:, 3};
% F_bot = DATA.Array{:, 4};
% Tmin = DATA.Array{:, 5};
% Tmean = DATA.Array{:, 6};
% Tmax = DATA.Array{:, 7};
% Vmin = DATA.Array{:, 8};
% Vrms = DATA.Array{:, 9};
% Vmax = DATA.Array{:, 10};
% eta_min = DATA.Array{:, 11};
% eta_mean = DATA.Array{:, 12};
% eta_max = DATA.Array{:, 13};
% ra_eff = DATA.Array{:, 14};
% Nu_top = DATA.Array{:, 15};
% Nu_bot = DATA.Array{:, 16};
% C_min = DATA.Array{:, 17};
% C_mean = DATA.Array{:, 18};
% C_max = DATA.Array{:, 19};
% F_mean = DATA.Array{:, 20};
% F_max = DATA.Array{:, 21};
% erupt_rate = DATA.Array{:, 22};
% erupta = DATA.Array{:, 23};
% erupt_heatflux = DATA.Array{:, 24};
% entrainment = DATA.Array{:, 25};
% Cmass_error = DATA.Array{:, 26};
% H_int = DATA.Array{:, 27};


%% Extract data needed
% checkIndivRange = [0 DATA.individual_range(1,:) 0];
% % maybe more efficient using this structure & using intercept: DATA.Array{strcmp(DATA.title,'time')}(2,1);
% for i=1:size(DATA.title,2)
%     if ~max(strcmp(DATA.title(1,i),DATA.string))==1 && ~strcmp(DATA.title(1,i),'time') && ...
%             ~checkIndivRange(1,i+2) && ~checkIndivRange(1,i)  %check if not min or max data
%         
%         %delete unused rows
%         DATA.Array{:,i} = [];
%     end
% end

%adjust DATA.Array length  (not sure why this is needed...) ???????
% DATA.Array(28) = [];









