%
%% plot 2-D fields of STAGYY
%________________________________
% Fabio Crameri

% currently used only for heat flux

%check if heat flux dimension is right, e.g., mW/m^2...........

function [field2d,PLOT,SAVE] = f_plot2DField(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE)

%Variables to add later to f_defaults:
FIELD2D.saveData = logical(0);
FIELD2D.areaFill = 'none';
%XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

fname       = FILE.name;
number      = FILE.number;
directory   = FILE.directory;

if strcmp(FIELD.name,'heat flux')
    plotCMB     = false; %1st index is cmb
    plotSURF    = true; %2nd index is top surface
    Tfieldname  = 'heat flux';
else
    error('fc: unknown Tfieldname')
end

% READ 2-D FIELD ---------------------------------------------------
[~,X_3D,Y_3D,~,FIELD_3D,time,~]  = f_ReadStagYY(directory,fname,number,Tfieldname,SWITCH.Precision);
if PLOT.YZ_2Dcartesian; %exchange x and y
    dummy_3D = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
    dummy_3Dx = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
    dummy_3D(:,1,:)     = FIELD_3D(1,:,:); FIELD_3D = dummy_3D;
    dummy_3Dx(:,1,:)    = X_3D(1,:,:);
    dummy_3D(:,1,:)     = Y_3D(1,:,:); Y_3D = dummy_3Dx; X_3D = dummy_3D;
end
if strcmp(GRID.Type,'cartesian')
    if strcmp(GRID.Dim,'2-D')
        x2d = X_3D(:,1,1);
        y2d = Y_3D(1,:,1)';
        field2d(:,:) = FIELD_3D(:,1,:);
    elseif strcmp(GRID.Dim,'3-D')
        x2d(:,:) = X_3D(:,1,1);
        y2d(:,:) = Y_3D(1,:,1)';
        field2d(:,:,:) = FIELD_3D(:,:,:);
    end
elseif strcmp(GRID.Type,'cylindrical')
    x2d = Y_3D(1,:,1)';
    y2d = X_3D(:,1,1);
    field2d(:,:) = FIELD_3D(1,:,:);
end

nloopComp = 1;
if SWITCH.plotDifference
    error('This has not been implemented yet with heat flux routine: CHECK THIS PART IF IT RUNS CORRECTLY!!!');
    if ~isfield(PLOT,'field2d_A') %for odd cases/snapshots
        PLOT.field2d_A = field2d;
        return  %end execution of function here
    else
        if strcmp(FIELD2D.difference,'diff')
            field2d_diff = PLOT.field2d_A - field2d;
            field2d = field2d_diff;
            clearvars field2d_diff
            PLOT = rmfield(PLOT,'field2d_A');
        elseif strcmp(FIELD2D.difference,'comp')
            nloopComp = 2;
        else
            error(['FIELD2D.difference = ',FIELD2D.difference,' not available!'])
        end
    end
end

for iloopComp = 1:nloopComp
    if SWITCH.plotDifference && strcmp(FIELD2D.difference,'comp')
        if iloopComp==1
            PLOT.field2d_B = field2d;
            field2d = PLOT.field2d_A;
        else
            field2d = PLOT.field2d_B;
        end
    end
    field_smooth_2 = zeros(size(field2d));
    field_smooth_1 = field2d;

    %% SMOOTHING
    if strcmp(GRID.Dim,'2-D')
        %------------------------
        % SMOOTHING 2-D
        %------------------------
        smoothingMethod = 3;
        if smoothingMethod==1 %DOESN'T WORK FOR 2-D YET!!!!!!!!! FIELD2D BECOMES SMALL!?
            filterSize = 5; %has to be an odd number!!!!
            %F = [.05 .1 .05; .1 .4 .1; .05 .1 .05]; %filter
            %F = [1/9 1/9 1/9; 1/9 1/9 1/9; 1/9 1/9 1/9]; %like 2-D filter - with one loop!
            F = fspecial('gaussian',filterSize); %filterSize is the size of matrix
            F = F(:,ceil(end/2)); %convert for 2D
            
            %add ghost points to prevent side effects from smoothing
            dummy = field_smooth_1; %surf and cmb
            for ii=1:filterSize
                dummy = [dummy(1,:); dummy; dummy(end,:)];
            end
            field_smooth_2 = zeros(size(dummy));
            %smoothing
            for jj=1:17
                field_smooth_2(:,1) = conv(dummy(:,1),F,'same');
                field_smooth_2(:,2) = conv(dummy(:,2),F,'same');
                dummy = field_smooth_2;
            end
            %remove ghostpoints
            field_smooth_2 = dummy(filterSize+1:end-filterSize,:);
            
        elseif smoothingMethod==2
            for jj=1:2
                field_smooth_2(:,1) = smooth(field_smooth_1(:,1),5,'loess');
                field_smooth_2(:,2) = smooth(field_smooth_1(:,2),5,'loess');
                field_smooth_1 = field_smooth_2;
            end
        elseif smoothingMethod==3
            for jj=1:2
                field_smooth_2(:,1) = smooth(field_smooth_1(:,1),5,'moving');
                field_smooth_2(:,2) = smooth(field_smooth_1(:,2),5,'moving');
                field_smooth_1 = field_smooth_2;
            end
        end
        field_smooth = field_smooth_2;
        %------------------------
        if (plotCMB && plotSURF)
            % nothing to be done
        elseif (plotCMB)
            field2d(:,2)=[];
            field_smooth(:,2)=[];
        elseif (plotSURF)
            field2d(:,1)=[];
            field_smooth(:,1)=[];
        end
        
    elseif strcmp(GRID.Dim,'3-D')
        if (plotCMB && plotSURF)
            display('only one field plot available at once!! -fc')
            field_PLOT = field2d(:,:,2); %surf field
        elseif (plotCMB)
            field_PLOT = field2d(:,:,1); %cmb field
        elseif (plotSURF)
            field_PLOT = field2d(:,:,2); %surf field
        end
        if SWITCH.plotFIELDsmooth
            %------------------------
            % SMOOTHING 3-D
            %------------------------
            smoothingMethod = 1;
            if smoothingMethod==1
                filterSize = 5;
                %F = [.05 .1 .05; .1 .4 .1; .05 .1 .05]; %filter
                %F = [1/9 1/9 1/9; 1/9 1/9 1/9; 1/9 1/9 1/9]; %like 2-D filter - with one loop!
                F = fspecial('gaussian',filterSize); %filterSize is the size of matrix
                %F = fspecial('gaussian');
                
                %add ghost points to prevent side effects from smoothing
                dummy = field_PLOT;
                for ii=1:filterSize
                    dummy = [dummy(1,:); dummy; dummy(end,:)];
                    dummy = [dummy(:,1), dummy, dummy(:,end)];
                end
                %smoothing
                for jj=1:17
                    field_PLOTsmooth = conv2(dummy,F,'same');
                    dummy = field_PLOTsmooth;
                end
                %remove ghostpoints
                field_PLOTsmooth = dummy(filterSize+1:end-filterSize,filterSize+1:end-filterSize);
                
            elseif smoothingMethod==2 
                %according to smooth2a
                Nr = 3; %rows
                Nc = 3; %colums
                % You end up replacing element "i" by the mean of a (2*Nr+1)-by-
                % (2*Nc+1) rectangle centered on element "i".
                [row,col] = size(field_PLOT);
                eL = spdiags(ones(row,2*Nr+1),(-Nr:Nr),row,row);
                eR = spdiags(ones(col,2*Nc+1),(-Nc:Nc),col,col);
                % Setting all "NaN" elements of "matrixIn" to zero so that these will not
                % affect the summation.  (If this isn't done, any sum that includes a NaN
                % will also become NaN.)
                A = isnan(field_PLOT);
                field_PLOT(A) = 0;
                % For each element, we have to count how many non-NaN elements went into
                % the sums.  This is so we can divide by that number to get a mean.  We use
                % the same matrices to do this (ie, "eL" and "eR").
                nrmlize = eL*(~A)*eR;
                nrmlize(A) = NaN;
                % Actually taking the mean.
                field_PLOTsmooth = eL*field_PLOT*eR;
                field_PLOTsmooth = field_PLOTsmooth./nrmlize;
            end
        end
    end
     
    %% DIMENSIONALISATION
    if strcmp(GRID.Dim,'2-D')
        x_PLOT          = x2d(:,1)      *GRID.dimFactor;
        field_PLOT      = field2d       *FIELD.varScale;
        fieldSmooth_PLOT= field_smooth  *FIELD.varScale;
    else
        x_PLOT          = x2d(:,1)      *GRID.dimFactor;
        y_PLOT          = y2d(:,1)      *GRID.dimFactor;
        field_PLOT      = field_PLOT  	*FIELD.varScale;
        field_PLOTsmooth= field_PLOTsmooth *FIELD.varScale;
    end
    
    if strcmp(FIELD.name,'heat flux')
        %% COUNT SUBPLOTS
        if iloopComp==1 
            PLOT.nr_subplot = PLOT.nr_subplot+1;
            nr_subplot = PLOT.nr_subplot; 
        end
        
        %% TITLE STRING & TIME
        fieldString1 = 'heat flux @ '; if PLOT.titleOnlyTime; fieldString1 = ''; end
        if SWITCH.dim || SWITCH.dimensional_input
            title_plot  = [fieldString1,num2str(PLOT.time2plot,3),' ',PLOT.time2plotDim];
        else
            title_plot  = [fieldString1,num2str(time,3),' '];
        end
        if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
        if ~isfield(SAVE,'AllFilesTitleString');
            SAVE.AllFilesTitleString = title_plot;
        else
            SAVE.AllFilesTitleString = [SAVE.AllFilesTitleString, {title_plot}];
        end
        
        %% FIGURE...
        figure(1)
        
        %% SUBPLOT LAYOUT...
        if iloopComp==1;
            if isfield(PLOT,'subplotLayout') %manual arrangement
                sub_current=[PLOT.subplotLayout(1,1),PLOT.subplotLayout(1,2),nr_subplot];
            else
                if PLOT.nrPlots>=4
                    if mod(PLOT.nrPlots,2)
                        sub_current=[(PLOT.nrPlots+1)/2 2 nr_subplot];
                    else
                        sub_current=[PLOT.nrPlots/2 2 nr_subplot];
                    end
                else
                    sub_current=[PLOT.nrPlots 1 nr_subplot];
                end
            end
            if PLOT.reverseLayout %top-down plotting
                if ~isfield(PLOT,'layoutNum')
                    PLOT.layoutNum = zeros(sub_current(1,1),sub_current(1,2));
                    idx = 0;
                    for ii=1:size(PLOT.layoutNum,1)
                        for jj=1:size(PLOT.layoutNum,2)
                            idx = idx+1;
                            PLOT.layoutNum(ii,jj) = idx;
                        end
                    end
                    idx = 0; PLOT.layoutNumTransposed = PLOT.layoutNum;
                    for jj=1:size(PLOT.layoutNum,2)
                        for ii=1:size(PLOT.layoutNum,1)
                            idx = idx+1;
                            PLOT.layoutNumTransposed(ii,jj) = idx; %transposed layout
                        end
                    end
                end
                %UPDATE TO NEW LAYOUT
                %       while PLOT.nr_subplot is still setup the old way!
                nr_subplot = PLOT.layoutNum(PLOT.layoutNumTransposed==nr_subplot);
                sub_current(1,3) = nr_subplot;
            end
            %% SUBPLOT
            if SWITCH.PlotInPlot && isfield(SAVE,'PlotInPlot_FIELD2D_hax')
                SAVE.PlotInPlot_FIELD2D_hax %needed to prevent erasing subplot
                hold on
            else
                subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3));
            end
            
            %% CURRENT AXIS
            AXcurrent = gca; %save current axes handle
        end
        
        %% SETUP PLOTTING VARIABLES
        if strcmp(GRID.Dim,'2-D')   % 2-D
%             x_PLOT          = x2d(:,1)*GRID.dimFactor;
%             field_PLOT       = field2d*GRID.dimFactor;
%             fieldSmooth_PLOT = field_smooth*GRID.dimFactor;
            if iloopComp==1;
                fieldCOLOUR0    = STYLE.keyLineColor;
                fieldCOLOUR     = STYLE.keyLineColor;
                fieldOPACITY    = 0.7;
            else
                fieldCOLOUR0    = [0.7 0.2 0.2];
                fieldCOLOUR     = [0.7 0.2 0.2];
                fieldOPACITY    = 0.4;
            end
            if SWITCH.PlotInPlot
                fieldCOLOUR0    = PLOT.gradColor4File;
                fieldCOLOUR     = PLOT.gradColor4File;
            end
            
            %% SAVING FIELD ------------------------
            if FIELD2D.saveData
                error('not adjusted for heat flux yet!');
                SAVE.Directory              = FILE.directory;
                SAVE.DataName               = [FILE.name,'_heatflux',num2str(FILE.number)];
                SAVE.data                   = [x_PLOT, field_PLOT, fieldSmooth_PLOT]; %[x, field, field_smooth]
                SAVE.dat                    = logical(0);
                SAVE.txt                    = logical(0);
                SAVE.mat                    = logical(1);
                SAVE.write2existing         = logical(0);
                f_saveDat( SAVE )
            end
            
            %% PLOTTING FIELD ----------------------------------------------
            if SWITCH.plotFIELDtrue; i_start=1; else i_start=2; end
            if SWITCH.plotFIELDsmooth; i_end=2; else i_end=1; end
            
            %plot field
            for i_field=i_start:i_end
                if i_field==1 %plot true field
                    field2plot = field_PLOT;
                    color2plot = fieldCOLOUR0;
                elseif i_field==2 %plot smooth field
                    field2plot = fieldSmooth_PLOT;
                    color2plot = fieldCOLOUR;
                end

                if ~SWITCH.GraphVsTimePlot %plot field graph
                    
                    PLOT.FIELD2DhLine = plot(x_PLOT,field2plot,'Color',color2plot,'LineWidth',STYLE.keyLineWidth);
                    hold on
                                
                elseif SWITCH.GraphVsTimePlot %remember x and field for graph vs. time plot
                    if SAVE.LastFile; SAVE.graphX = x_PLOT'; end
                    if ~isfield(SAVE,'graphField2d'); 
                        SAVE.graphField2d = field2plot'; 
                        SAVE.graphTime	= PLOT.time;
                    else
                        SAVE.graphField2d  = [SAVE.graphField2d; field2plot'];
                        SAVE.graphTime	= [SAVE.graphTime; PLOT.time]; %non-dimensional time
                    end
                    if SAVE.LastFile
                        SAVE.graphTime = SAVE.graphTime.*PLOT.timeConvert; %make dimensional according to last automatic time dimension
                        contourf(SAVE.graphX,SAVE.graphTime,SAVE.graphField2d,PLOT.numContours,'LineColor','none');
                        cb=colorbar;
                        if SWITCH.Colorbar(1,2); set(gca,'clim',[-max(abs(SAVE.graphField2d(:))),max(abs(SAVE.graphField2d(:)))]); end %constant cb
                        if SWITCH.dim || SWITCH.dimensional_input; title(cb,['heat flux [',FIELD.dim,']']); else title(cb,'heat flux [nd]'); end
                    end
                end
                
                if ~strcmp(FIELD2D.areaFill,'none')
                    xpoints = x_PLOT;
                    upper = field2plot;
                    if strcmp(FIELD2D.areaFill,'down')
                        color = color2plot;
                        lower = zeros(size(upper))+(min(upper)-1/10*(max(upper)-min(upper)));
                        if FIELD2D.both; PLOT.FIELD2DLOWval = lower(1,1); lower = zeros(size(upper))-50; end %set very low to be deeper than dynamic FIELD2D low
                        if SWITCH.Colorbar(1,2); lower = zeros(size(upper))+FIELD.cColorbarMIN; end %constant axis min/max
                        if SWITCH.plotDifference && strcmp(FIELD2D.difference,'diff'); lower = lower*0; end %in relation to 0 FIELD2Dgraphy
                    
                    elseif strcmp(FIELD2D.areaFill,'updown')
                        color = color2plot;
                        lower = zeros(size(upper));
                    else
                        error(['FIELD2D.areaFill mode ',FIELD2D.areaFill,'not recognised!'])
                    end
                    
                    PLOT.FIELD2DhArea(iloopComp,1) = fill([min(xpoints); xpoints; max(xpoints)],[min(lower); upper; min(lower)],color,'EdgeColor','none','FaceAlpha',fieldOPACITY);
                end
            end
            
            %------------------------------------------------------------------
            %% ANNOTATIONS
            if iloopComp==1;
                xlabel(['width [',GRID.Xdim,']']); 
                if SWITCH.dim || SWITCH.dimensional_input; ylabel(['heat flux [',FIELD.dim,']']); else ylabel('heat flux [nd]'); end 
                if SWITCH.GraphVsTimePlot
                    if SWITCH.dim || SWITCH.dimensional_input; ylabel(['time [',PLOT.time2plotDim,']']);
                    else ylabel('time [nd]'); end
                end
                if SWITCH.title
                    if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
                    if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
                        htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
                    else
                        htitle = title(title_plot); %centered
                    end
                    if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.nr_subplot,:)); end
                end
                axis tight
                if SWITCH.Colorbar(1,2) && ~SWITCH.GraphVsTimePlot; ylim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
                if SWITCH.setAxisLimit
                    if size(SWITCH.axisLimit,1)>1  %more than one axis-zoom value
                        xlim(SWITCH.axisLimit(PLOT.loop_case,1:2));
                    else
                        xlim(SWITCH.axisLimit(1,1:2));
                    end
                end             
%                 set(AXcurrent,'YGrid','on') %only horizontal grid
                if ~SWITCH.GraphVsTimePlot; grid on; end
                box on
                %set tickmarks out- or inside
                set(gca,'TickDir',SWITCH.tickDir)
                
                if SWITCH.texting
                    text(min(xlim),max(ylim),['min val: ',num2str(min(field_PLOT(:)),2),'   (',num2str(min(fieldSmooth_PLOT(:)),2),')'],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
                    text(max(xlim),max(ylim),['max val: ',num2str(max(field_PLOT(:)),2),'   (',num2str(max(fieldSmooth_PLOT(:)),2),')'],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
                    display(['   max.heatflux: ',num2str(max(field_PLOT)),' / min.heatflux: ',num2str(min(field_PLOT))])
                    % ...and smooth
                    display(['   max.field_smooth: ',num2str(max(fieldSmooth_PLOT)),' / min.field_smooth: ',num2str(min(fieldSmooth_PLOT))])
                end
                
                if SWITCH.plotDifference && iloopComp==nloopComp %only for difference plot
                    error('this is not yet implemented for heat flux plot')
                    if isfield(PLOT,'titleString')
                        legend(PLOT.FIELD2DhArea,PLOT.titleString{1,:},'Location','southeast','Interpreter','none') %area
                    else
                        legend(PLOT.FIELD2DhArea,SWITCH.fname_vector,'Location','southeast','Interpreter','none') %area
                    end
                    
                elseif SWITCH.PlotInPlot && ~SWITCH.GraphVsTimePlot %only for plot in plot
                    error('this is not yet implemented for heat flux plot')
                    SAVE.PlotInPlot_FIELD2D_hax = gca; %needed for next file plot to find the subplot
                    if ~isfield(SAVE,'AllFilesFIELD2DhLine');
                        SAVE.AllFilesFIELD2DhLine = PLOT.FIELD2DhLine; %Remember FIELD2D handles for all individual files
                    else
                        SAVE.AllFilesFIELD2DhLine = [SAVE.AllFilesFIELD2DhLine, PLOT.FIELD2DhLine]; %Remember FIELD2D handles for all individual files
                    end
                    if SAVE.LastFile
                        if isfield(PLOT,'titleString') %only for last one
                            legend(SAVE.AllFilesFIELD2DhLine,PLOT.titleString{1,:},'Location','southeast')
                        else
                            if size(SAVE.AllFilesTitleString,2)>4
                                legString = [SAVE.AllFilesTitleString(1,1), SAVE.AllFilesTitleString(1,end)];
                                legHandle = [SAVE.AllFilesFIELD2DhLine(1,1), SAVE.AllFilesFIELD2DhLine(1,end)];
                            else
                                legString = SAVE.AllFilesTitleString; legHandle = SAVE.AllFilesFIELD2DhLine;
                            end
                            legend(legHandle,legString,'Location','southeast')
                        end
                    end
                end
            end
            
        elseif strcmp(GRID.Dim,'3-D') 
            %% 3-D
            if SWITCH.plotFIELDtrue && SWITCH.plotFIELDsmooth
                n_start     = 1;
                n_end       = 2;
            elseif SWITCH.plotFIELDtrue
                n_start     = 1;
                n_end       = 1;
            elseif SWITCH.plotFIELDsmooth
                n_start     = 2;
                n_end       = 2;
            end
            for i_field=n_start:n_end
                if SWITCH.plotFIELDtrue && SWITCH.plotFIELDsmooth
                    subplot(2,1,i_field)
                end
                if i_field==1 %plot field
                    field2plot = field_PLOT;
                elseif i_field==2 %plot field smooth
                    field2plot = field_PLOTsmooth;
                end
                if SWITCH.plot3Dfield2D %2-D plot
                    contourf(x_PLOT,y_PLOT,field2plot',PLOT.numContours,'EdgeColor','none')
                
                else %3-D field plot
                    surf(y_PLOT,x_PLOT,field2plot,'EdgeColor','none')
                    % contour(xi,yi,zi)
                    set(gca,'ztick',[]); %remove z ticks
                    %set camera position
                    campos(PLOT.cameraPosition.*[1 1 -1]) %z-axis is not flipped
                    %set perspective mode
                    camproj(PLOT.camProjection)
                    % zlabel(['heat flux ',FIELD.dim]);
                end
                axis tight
                axis equal
                box on
                title(title_plot) %TITLE
                xlabel(['y-width [',GRID.Xdim,']']); 
                ylabel(['x-width [',GRID.Ydim,']']);
                
                %INPUT here:
                plotFieldProfiles = logical(0); xprofLoc = []; yprofLoc = [140, 20]; %[50, 206] %in [#gridpoints]
                %-----------
                if plotFieldProfiles
                    colors4Profiles = [[0 0 0]; [0.5 0.5 0.5]; [0.3 0.3 1.0]; [1 0.3 0.3]; [0.6 0.6 0.3]; [0.3 1 0.3]; [0.5 0.5 0.5]];
                    % add profile lines to previous plots
                    hold on
                    if ~isempty(xprofLoc)
                        numProfx = size(xprofLoc,2);
                        profx = y_PLOT';
                        for iprof=1:numProfx
                            profx(1+iprof,:) = field2plot(xprofLoc(1,iprof),:);
                            if SWITCH.plot3Dfield2D %2-D plot
                                plot(y_PLOT*0+x_PLOT(xprofLoc(1,iprof),1),y_PLOT,'Color',colors4Profiles(iprof,:))
                            else
                                plot3(y_PLOT,y_PLOT*0+x_PLOT(xprofLoc(1,iprof),1),field2plot(xprofLoc(1,iprof),:),'Color',colors4Profiles(iprof,:))
                            end
                        end
                    end
                    if ~isempty(yprofLoc)
                        numProfy = size(yprofLoc,2);
                        profy = x_PLOT';
                        for iprof=1:numProfy
                            profy(1+iprof,:) = field2plot(:,yprofLoc(1,iprof));
                            if SWITCH.plot3Dfield2D %2-D plot
                                plot(x_PLOT,x_PLOT*0+y_PLOT(yprofLoc(1,iprof),1),'Color',colors4Profiles(iprof,:))
                            else
                                plot3(x_PLOT*0+y_PLOT(yprofLoc(1,iprof),1),x_PLOT,field2plot(:,yprofLoc(1,iprof)),'Color',colors4Profiles(iprof,:))
                            end
                        end
                    end
                    %new figure with actual profiles
                    figure(2)
                    SwitchPlotSeparately = logical(1); %plot separately for each file
                    if SwitchPlotSeparately; clf; end
                    set(gcf,'Position',[47 1 685 300]);
                    if exist('profx','var')
                        if exist('profy','var'); subplot(1,2,1); end
                        for iprof=2:size(profx,1)
                            hpr(iprof-1) = plot(profx(1,:),profx(iprof,:),'-','Color',colors4Profiles(iprof-1,:));
                            if iprof-1==1; dummy=1.25; else dummy=0.75; end
                            set(hpr(iprof-1),'LineWidth',dummy)
                            hold on
                        end
                    end
                    if exist('profy','var')
                        if exist('profx','var'); subplot(1,2,2); end
                        for iprof=2:size(profy,1)
                            hpr(iprof-1) = plot(profy(1,:),profy(iprof,:),'-','Color',colors4Profiles(iprof-1,:));
                            if iprof-1==1; dummy=1.25; else dummy=0.75; end
                            set(hpr(iprof-1),'LineWidth',dummy)
                            hold on
                        end
% %                         to save profile data:
%                         FIELD2D1.x = profy(1,:)
%                         FIELD2D1.y = profy(iprof,:)
%                         FIELD2D1.yLoc = y_PLOT(yprofLoc(1))
%                         save('~/Desktop/FIELD2D1.mat','FIELD2D1')
                    end
                    if SwitchPlotSeparately || SAVE.LastFile
                        axis tight
                        ylim([-8 5])
                        grid on
                        box on
                        xlabel('x-width [km]')
                        ylabel('heat flux [mW/m^2]')
                        %legend(hpr,'thin UP-plate part','thick UP-plate part')
                        legend(hpr,['y = ',num2str(y_PLOT(yprofLoc(1)),4),' km'],['y = ',num2str(y_PLOT(yprofLoc(2)),4),' km'])
                        %STYLE FIGURE
                        f_figStyle(STYLE);
                        if logical(1) %SWITCH.fBackground
                            BACK.ApplyTo = 'current';          %'current', 'all'
                            f_plotBackground(BACK) %set plot background of each subplot
                        end
                        %SAVE FIGURE
                        if SAVE.Plot; SAVE.FigureNr=2; f_saveFig(SAVE); end
                    end
                    figure(1) %back to fig. 1
                end
            end
            if SWITCH.Colorbar(1,1) %colorbar switch
                cb=colorbar;
                if SWITCH.Colorbar(1,2) %constant colorbar
                    set(gca,'clim',[FIELD.cColorbarMIN,FIELD.cColorbarMAX])
                else
                    if SWITCH.MversionSupported; set(gca,'clim',cb.Limits); end
                end
                title(cb,['heat flux [',FIELD.dim,']']); %on top
                %ylabel(cb,CBtitle_plot); %on left hand side
            end
%             if SWITCH.Colorbar(1,2) %constant colorbar
%                 if SWITCH.plot3Dfield2D
%                     cb=colorbar;
%                     if SWITCH.Colorbar(1,2); set(gca,'clim',[-max(abs(SAVE.graphFIELD2D(:))),max(abs(SAVE.graphFIELD2D(:)))]); end %constant cb
%                     title(cb,['heat flux ',FIELD.dim]);
%                 else
%                     zlim([FIELD.cColorbarMIN FIELD.cColorbarMAX]);
%                 end
%             end
            clearvars low high tix tiy
        end %3-D
        
        if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else nr_hax = 1; end
        %for function output:
        PLOT.hax(nr_hax,1)  = AXcurrent;
        
        %% FIGURE SIZE & POSITION ==================================
        figure(1)
        hold on
        
        %% COLORBAR ==================================
        if strcmp(GRID.Dim,'3-D') || SWITCH.GraphVsTimePlot && SAVE.LastFile
            %% SPECIFY COLORMAP FOR CURRENT AXES
            AXhandles(1) = AXcurrent;  %big plot axis handle
            if exist('haxZ','var');
                AXhandles(2) = haxZ; %zoom plot axis handle
                loop_zoom = 2;
            else
                loop_zoom = 1;
            end
            if ~exist('cb','var'); cb = colorbar; end
            PLOT.cb      = cb;      % colorbar handle
            for izoom=1:loop_zoom
                if ~PLOT.multipleColormap && izoom>1; continue; end
                PLOT.hax = AXhandles(izoom);
                [SWITCH] = f_colormap(SWITCH,PLOT);
            end
        else
            colorbar;   %define dummy colorbar
            cb = NaN; 	%this is a flag if no colorbar is used
        end
        
        %% SIMPLIFY FIGURE ==================================
        if SWITCH.simplify
            if strcmp(GRID.Dim,'2-D')
                %SET AXES ASPECT RATIO ----
                XaxisAR = GRID.aspectRatio(1);
                YaxisAR = GRID.aspectRatio(2);
                ZaxisAR = 1;
                set(gca,'PlotBoxAspectRatio',[XaxisAR YaxisAR ZaxisAR])
                %--------------------------
            end
            
            %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
            PLOT.spcurrent          = sub_current;
            PLOT.sp_chax            = AXcurrent;
            if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else PLOT.sp_chaxz = NaN; end
            PLOT.sp_ccb             = cb;   %colorbar handle
            PLOT.title              = title_plot;  	%title string
            
            [PLOT] = f_splayout(SWITCH,PLOT,GRID,FIELD);
        end
    end

end

%% adjust for function output
field2d = field_PLOT;

if strcmp(FIELD.name,'heat flux') %indicate axis handle as graph subplot
    SAVE.graphPlotHandles = [SAVE.graphPlotHandles; AXcurrent];
    SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent];
end

    

