
%%   PLOT DYNAMIC TOPOGRAPHY

% Fabio Crameri, November 2015

%% NOTES
% maybe try to calculate mean density of the overburden for rho here ......
% check if the zz-stress from stag is actually the zz- component..... should be fine.

function [dynTopo2d,PLOT,SAVE] = f_plotDynTOPO(TOPO,FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE)

TOPO.plotLineWidth  = STYLE.keyLineWidth;
scaleByViscosity    = logical(0);   %scale normal (i.e., sigma_zz) by viscosity
useActualPlateETA   = logical(0);   %use actual plate (surface/core) viscosity for scaling zz-stress values
useActualPlateRHO   = logical(1);   %use actual plate (surface/core) density for calculating dynamic topography

%% READ TEMPERATURE ---------------------------------------------------
% Read temperature field information
[~, ~, ~, ~,T_3D, ~, ~]     = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'temperature', SWITCH.Precision);
if PLOT.YZ_2Dcartesian; %exchange x and y
    dummy_3D = zeros(size(T_3D,2),size(T_3D,1),size(T_3D,3));
    dummy_3D(:,1,:)     = T_3D(1,:,:); T_3D = dummy_3D;
end

%% READ VISCOSITY ---------------------------------------------------
% Read viscosity field information
[~, ~, ~, ~,ETA_3D, ~, ~]     = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'viscosity', SWITCH.Precision);
if PLOT.YZ_2Dcartesian; %exchange x and y
    dummy_3D = zeros(size(ETA_3D,2),size(ETA_3D,1),size(ETA_3D,3));
    dummy_3D(:,1,:)     = ETA_3D(1,:,:); ETA_3D = dummy_3D;
end

%% READ DENSITY ---------------------------------------------------
% Read density field information
[~, ~, ~, ~,RHO_3D, ~, ~]     = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'density', SWITCH.Precision);
if PLOT.YZ_2Dcartesian; %exchange x and y
    dummy_3D = zeros(size(RHO_3D,2),size(RHO_3D,1),size(RHO_3D,3));
    dummy_3D(:,1,:)     = RHO_3D(1,:,:); RHO_3D = dummy_3D;
end

%% READ zz-stress component ---------------------------------------------------
% Read zz-stress component information
[~,~,~,~,NSTRESS_3D,time,~]     = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'zz-stress component', SWITCH.Precision);
if PLOT.YZ_2Dcartesian; %exchange x and y
    dummy_3D = zeros(size(NSTRESS_3D,2),size(NSTRESS_3D,1),size(NSTRESS_3D,3));
    dummy_3D(:,1,:)     = NSTRESS_3D(1,:,:); NSTRESS_3D = dummy_3D;
end

x2d(:,:,:)	= GRID.X_3D(:,:,:);   %in [m]
y2d(:,:,:) 	= GRID.Y_3D(:,:,:);   %in [m]
z2d(:,:,:) 	= GRID.Z_3D(:,:,:);   %in [m]

%--------------------------------
%% ERROR CHECKS
% only implemented for dimensional mode
if ~SWITCH.dim
   error('dynamic topography routine only works in dimensional mode (i.e., SWITCH.dim = true)!') 
end
% this needs actual depth switched on
if SWITCH.actualDepth || strcmp(SETUP.topBC,'free-slip') %nothing to be done
else
    error('this needs actual depth switched on!')
end
%--------------------------------

%% DIMENSIONALIZATION
NSTRESS_3D  = NSTRESS_3D * SETUP.stressscale;  %[MPa]
T_3D        = T_3D * SETUP.Tscale; %in [K]
ETA_3D      = ETA_3D * SETUP.eta0; %in [Pa s]
RHO_3D      = RHO_3D * SETUP.rhoscale; %in [Pa s]
x2d         = x2d/1e3;    %in [km]
y2d         = y2d/1e3;    %in [km]
z2d         = z2d/1e3;    %depth in [km]

if useActualPlateETA || useActualPlateRHO
    % define lithosphere (near) surface values
    deltaTsurface   = 0.08; %0.03: surface, 0.15: core  %fraction of Tmax
    T_surfacePlate  = min(T_3D(:))+deltaTsurface*max(T_3D(:));
    % derive lithosphere (near) surface by T contour
    LITHO.Tisovalue     = T_surfacePlate;  %Temperature isovalue
    LITHO.zmax          = PLOT.lithoThickness(1,2); %depth in [km]
    LITHO.gridpoints    = NaN; %define to switch on gridpoints output
    [LITHO] = f_lithoThickness(T_3D,z2d,LITHO);
    plateSurfaceIdxs    = LITHO.gridpoints; %only used for this
end

% derive lithosphere thickness by T contour
LITHO.Tisovalue     = PLOT.lithoThickness(1,1);  %Temperature isovalue
LITHO.zmax          = PLOT.lithoThickness(1,2); %depth in [km]
LITHO.gridpoints    = NaN; %define to switch on gridpoints output
[LITHO] = f_lithoThickness(T_3D,z2d,LITHO);

% get zz-stress component at these depths
nstressLithoBase    = zeros(size(LITHO.gridpoints,1),size(LITHO.gridpoints,2),1)*NaN;
etaLithoBase        = nstressLithoBase;
if useActualPlateETA; etaLithoTop = nstressLithoBase; end
rhoLithoBase        = nstressLithoBase;
if useActualPlateRHO; rhoLithoTop = nstressLithoBase; end
x2d_nstress         = nstressLithoBase;
y2d_nstress         = nstressLithoBase;
z2d_nstress         = nstressLithoBase;
for ivalx=1:size(LITHO.gridpoints,1)
    for ivaly=1:size(LITHO.gridpoints,2)
        if isnan(LITHO.gridpoints(ivalx,ivaly))
            nstressLithoBase(ivalx,ivaly) = NaN;
            etaLithoBase(ivalx,ivaly)     = NaN;
            rhoLithoBase(ivalx,ivaly)     = NaN;
            x2d_nstress(ivalx,ivaly)      = NaN; %with NaN values
            y2d_nstress(ivalx,ivaly)      = NaN; %with NaN values
            z2d_nstress(ivalx,ivaly)      = NaN; %with NaN values
            continue
        end
        nstressLithoBase(ivalx,ivaly) = NSTRESS_3D(ivalx,ivaly,LITHO.gridpoints(ivalx,ivaly));
        etaLithoBase(ivalx,ivaly)     = ETA_3D(ivalx,ivaly,LITHO.gridpoints(ivalx,ivaly));
        if useActualPlateETA
            etaLithoTop(ivalx,ivaly)      = ETA_3D(ivalx,ivaly,plateSurfaceIdxs(ivalx,ivaly));
        end
        rhoLithoBase(ivalx,ivaly)     = RHO_3D(ivalx,ivaly,LITHO.gridpoints(ivalx,ivaly));
        if useActualPlateRHO
            rhoLithoTop(ivalx,ivaly)      = RHO_3D(ivalx,ivaly,plateSurfaceIdxs(ivalx,ivaly));
        end
        x2d_nstress(ivalx,ivaly)      = x2d(ivalx,ivaly,LITHO.gridpoints(ivalx,ivaly)); %with NaN values
        y2d_nstress(ivalx,ivaly)      = y2d(ivalx,ivaly,LITHO.gridpoints(ivalx,ivaly)); %with NaN values
        z2d_nstress(ivalx,ivaly)      = z2d(ivalx,ivaly,LITHO.gridpoints(ivalx,ivaly)); %with NaN values
    end
end
    
% calculate dyn. topography from zz-stress component
% sigma_zz = rho*g*h        -->	h_0 = sigma_zz/(rho*g)
%                               h_dyn = h_0-z_measurementEFFECT


% sigma_normal: stress at the base of the lithosphere (i.e., nstressLithoBase)
% sigma_eff: stress at the base of the lithosphere (= nstressLithoBase ???)
% rho: from density field or just characteristic value
% h: depth of isoline
if useActualPlateRHO
    rho_plate_base 	= rhoLithoBase; %smooth(rhoLithoBase,20,'moving')'; %[kg/m^3]
    rho_plate_top  	= rhoLithoTop; %smooth(rhoLithoTop,20,'moving')'; %[kg/m^3]
    rho_plate       = (rho_plate_top+rho_plate_base)/2; %[kg/m^3] mean value between plate top and bot
else
    rho_plate       = SETUP.rho0;   %[kg/m^3]
end
g                   = SETUP.g;      %[m/s^2]
nstressLithoBase    = nstressLithoBase*1e6; %[MPa]->[Pa]

% scale sigma_zz by viscosity (sigma = 2*eta*epsilon)
% use viscosity difference to plate
% *************************
if useActualPlateETA
    %eta_plate       = etaLithoTop; 
    eta_plate       = smooth(etaLithoTop,20,'moving')';
else
    eta_plate           = 1e23; %[Pa s] <<<<<<<<<<<<<<<<<<<<<<<<< MIGHT ADJUST PLATE VISCOSITY VALUE HERE
    % eta_plate       = mean(etaLithoBase(:));
end
% *************************
if scaleByViscosity
    eta_diff2plate      = eta_plate ./ etaLithoBase;
    nstressLithoBase    = nstressLithoBase .* eta_diff2plate;
end

% figure(2)
% plot(x2d_nstress,nstressLithoBase)

% calculate dyn. topography from zz-stress component
% sigma_normal = rho*g*h    -->	h_0 = sigma_normal/(rho*g)
dynTopo2d           = -nstressLithoBase./(rho_plate.*g);  %[m]
dynTopo2d           = dynTopo2d./1e3; %[km]
NanLocations = find(isnan(dynTopo2d));

%------------------------
% SMOOTHING
%------------------------
if strcmp(GRID.Dim,'2-D') && TOPO.dynTOPOsmooth
    topo_smooth_1 = dynTopo2d;
    for jj=1:2
        topo_smooth_2(:,1) = smooth(topo_smooth_1(:,1),5,'moving');
        topo_smooth_1 = topo_smooth_2;
    end
    dynTopo2d = topo_smooth_2;
end
%re-insert NaN values
dynTopo2d(NanLocations) = NaN;
%------------------------

nloopComp = 1;
if SWITCH.plotDifference
    if strcmp(GRID.Dim,'3-D'); error('Difference plot not implemented for 3-D!'); end
    if ~isfield(PLOT,'dynTopo2d_A') %for odd cases/snapshots
        PLOT.dynTopo2d_A = dynTopo2d;
        PLOT.dynx2d_nstress_A = x2d_nstress;
        return %end execution of function here
    else
        if strcmp(TOPO.difference,'diff')
            dynTopo2d_diff = PLOT.dynTopo2d_A - dynTopo2d;
            dynTopo2d = dynTopo2d_diff;
            x2d_nstress(1,find(isnan(PLOT.dynx2d_nstress_A))) = NaN; %combine all NaN values 
            clearvars dynTopo2d_diff
            PLOT = rmfield(PLOT,'dynTopo2d_A'); PLOT = rmfield(PLOT,'dynx2d_nstress_A');
        elseif strcmp(TOPO.difference,'comp')
            nloopComp = 2;
        else
            error(['TOPO.difference = ',TOPO.difference,' not available!'])
        end
    end
end

for iloopComp = 1:nloopComp
    if SWITCH.plotDifference && strcmp(TOPO.difference,'comp')
        if iloopComp==1
            PLOT.dynTopo2d_B = dynTopo2d; PLOT.dynx2d_nstress_B = x2d_nstress;
            dynTopo2d = PLOT.dynTopo2d_A; x2d_nstress = PLOT.dynx2d_nstress_A;
        else
            dynTopo2d = PLOT.dynTopo2d_B; x2d_nstress = PLOT.dynx2d_nstress_B;
        end
    end
    
    if iloopComp==1;
        %% COUNT SUBPLOTS
        if ~TOPO.both
            PLOT.nr_subplot = PLOT.nr_subplot+1;
        end
        nr_subplot = PLOT.nr_subplot; 
    end
    
    
    % PLOT DYN. TOPOGRAPHY ---------------------------------------------------
    if strcmp(GRID.Dim,'2-D')   % 2-D
        %% figure...
        figure(1)
        %% subplot...
        if iloopComp==1;
            if isfield(PLOT,'subplotLayout') %manual arrangement
                sub_current=[PLOT.subplotLayout(1,1),PLOT.subplotLayout(1,2),nr_subplot];
            else
                if PLOT.nrPlots>=4
                    if mod(PLOT.nrPlots,2)
                        sub_current=[(PLOT.nrPlots+1)/2 2 nr_subplot];
                    else
                        sub_current=[PLOT.nrPlots/2 2 nr_subplot];
                    end
                else
                    sub_current=[PLOT.nrPlots 1 nr_subplot];
                end
            end
            if PLOT.reverseLayout %top-down plotting
                if ~isfield(PLOT,'layoutNum')
                    PLOT.layoutNum = zeros(sub_current(1,1),sub_current(1,2));
                    idx = 0;
                    for ii=1:size(PLOT.layoutNum,1)
                        for jj=1:size(PLOT.layoutNum,2)
                            idx = idx+1;
                            PLOT.layoutNum(ii,jj) = idx;
                        end
                    end
                    idx = 0; PLOT.layoutNumTransposed = PLOT.layoutNum;
                    for jj=1:size(PLOT.layoutNum,2)
                        for ii=1:size(PLOT.layoutNum,1)
                            idx = idx+1;
                            PLOT.layoutNumTransposed(ii,jj) = idx; %transposed layout
                        end
                    end
                end
                %UPDATE TO NEW LAYOUT
                %       while PLOT.nr_subplot is still setup the old way!
                nr_subplot = PLOT.layoutNum(PLOT.layoutNumTransposed==nr_subplot);
                sub_current(1,3) = nr_subplot;
            end
            %% SUBPLOT
            if ~TOPO.both; subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3)); end
            %% CURRENT AXIS
            AXcurrent = gca; %save current axes handle
        end
        if iloopComp==1;
            topoCOLOURline  = STYLE.keyLineColor;
            %topoCOLOUR0 = [0     0.44706     0.74118]; %Color dynamic topography
            topoCOLOUR0     = [0.5 0.5 0.5]; %Color dynamic topography
            topoOPACITY     = 0.5;
        else
            topoCOLOURline  = [0.2 0.2 0.2];
            topoCOLOUR0     = [0.2 0.2 0.2]; %Color dynamic topography
            topoOPACITY     = 0.5;
        end
        
        %PLOTTING TOPOGRAPHY ----------------------------------------------
        hold on
        TOPO.hLineDyn = plot(x2d_nstress,dynTopo2d,'Color',topoCOLOURline,'LineWidth',TOPO.plotLineWidth);
        hold on
        
        xpoints = x2d_nstress;
        upper = dynTopo2d;
        if ~strcmp(TOPO.areaFill,'none')
            if strcmp(TOPO.areaFill,'down')
                color = topoCOLOUR0;
                lower = zeros(size(upper))+(min(upper)-1/10*(max(upper)-min(upper)));
                if TOPO.both && PLOT.topoLOWval<lower(1,1);
                    lower = zeros(size(upper))+PLOT.topoLOWval;
                end
                if SWITCH.Colorbar(1,2); lower = zeros(size(upper))+FIELD.cColorbarMIN; end %constant colorbar
                if SWITCH.plotDifference && strcmp(TOPO.difference,'diff'); lower = lower*0; end %in relation to 0 topography
            
            elseif strcmp(TOPO.areaFill,'updown')
                color = topoCOLOUR0;
                lower = zeros(size(upper));
            else
                error(['TOPO.areaFill mode ',TOPO.areaFill,'not recognised!'])
            end
        end 
        if TOPO.water && ~strcmp(TOPO.areaFill,'updown') %add water layer
            colorWater = [0.4 0.6 0.7]; alphaWater = 0.2;
            if strcmp(STYLE.colorMode,'black');
                colorWater = [0.4 0.6 0.7]; alphaWater = 0.7;
            end
            topoNegative = upper;
            topoNegative(upper>=0) = NaN; %remove positive topo values
            if max(isnan(topoNegative))==1 %if there are NaNs
                %seperate the two lines
                NanLocations = find(isnan(topoNegative));
                NanLocations = [0; NanLocations; size(topoNegative,2)+1]; %add start and end point
                nLineSegment = size(NanLocations,1)-1;
                for iLineSegment=1:nLineSegment
                    startLoc = NanLocations(iLineSegment,1) +1;
                    endLoc = NanLocations(iLineSegment+1,1) -1;
                    if endLoc<=startLoc+1; continue; end %skip this one: no line in between
                    
                    S_xpoints = xpoints(startLoc:endLoc,1);
                    S_upper = topoNegative(startLoc:endLoc,1);
                    S_lower = zeros(size(S_upper));
                    
                    fill([min(S_xpoints); S_xpoints; max(S_xpoints)],[min(S_lower); S_upper; min(S_lower)],...
                        colorWater,'EdgeColor','none','FaceAlpha',alphaWater);
                    hold on
                end
            end
        end
        
        if ~strcmp(TOPO.areaFill,'none')
            if max(isnan(upper))==1 %if there are NaNs
                %seperate the two lines
                NanLocations = find(isnan(upper));
                NanLocations = [0; NanLocations; size(upper,2)+1]; %add start and end point
                
                nLineSegment = size(NanLocations,1)-1;
                
                for iLineSegment=1:nLineSegment
                    startLoc = NanLocations(iLineSegment,1) +1;
                    endLoc = NanLocations(iLineSegment+1,1) -1;
                    if endLoc<=startLoc+1; continue; end %skip this one: no line in between
                    
                    S_xpoints = xpoints(startLoc:endLoc,1);
                    S_upper = upper(startLoc:endLoc,1);
                    S_lower = zeros(size(S_upper))+(min(upper)-1/10*(max(upper)-min(upper)));
                    if TOPO.both && PLOT.topoLOWval<S_lower(1,1);
                        S_lower = zeros(size(S_upper))+PLOT.topoLOWval;
                    end
                    if SWITCH.Colorbar(1,2); S_lower = zeros(size(S_upper))+FIELD.cColorbarMIN; end %constant colorbar
                    if SWITCH.plotDifference && strcmp(TOPO.difference,'diff'); S_lower = S_lower*0; end %in relation to 0 topography
                    
                    TOPO.hAreaDyn(iloopComp,1) = fill([min(S_xpoints); S_xpoints'; max(S_xpoints)],[min(S_lower); S_upper'; min(S_lower)],...
                        color,'EdgeColor','none','FaceAlpha',topoOPACITY);
                    hold on
                end
            else
                TOPO.hAreaDyn(iloopComp,1) = fill([min(xpoints); xpoints; max(xpoints)],[min(lower); upper; min(lower)],...
                    color,'EdgeColor','none','FaceAlpha',topoOPACITY);
            end
        end
        
        %------------------------------------------------------------------
        if iloopComp==1;
            if TOPO.both; startix='eff. vs. '; else startix=''; end
            fieldString1 = [startix,'dyn. topography @ ']; if PLOT.titleOnlyTime; fieldString1 = ''; end
            xlabel(['width [',GRID.Xdim,']']);
            if SWITCH.dim
                title_plot  = [fieldString1,num2str(PLOT.time2plot,3),' ',PLOT.time2plotDim];
                ylabel('dyn. topography [km]')
                if TOPO.both; ylabel('topography [km]'); end
            else
                %not implemented here
            end
            if SWITCH.title
                if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
                if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
                    htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
                else
                    htitle = title(title_plot); %centered
                end
                if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.nr_subplot,:)); end
            end
            axis tight
            if TOPO.both
                ygap = 1/10*((max(dynTopo2d(:)))-min(dynTopo2d(:)));
                axis([min(x2d_nstress(:)) max(x2d_nstress(:)) min(dynTopo2d(:))-ygap max(dynTopo2d(:))+ygap]);
            end
            if SWITCH.Colorbar(1,2); ylim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
            if SWITCH.setAxisLimit
                if size(SWITCH.axisLimit,1)>1  %more than one axis-zoom value
                    xlim(SWITCH.axisLimit(PLOT.loop_case,1:2));
                else
                    xlim(SWITCH.axisLimit(1,1:2));
                end
            end
%             set(AXcurrent,'YGrid','on') %only horizontal grid
            grid on
            box on
            %set tickmarks out- or inside
            set(gca,'TickDir',SWITCH.tickDir)
            
            if TOPO.both
                %         legend([PLOT.TOPOhLine TOPO.hLineDyn],'Effective Topography','Dynamic Topography','Location','southeast') %line
                legend([PLOT.TOPOhArea(1,1) TOPO.hAreaDyn(1,1)],'Effective Topography','Dynamic Topography','Location','southeast') %area
            end
            
            if SWITCH.texting
                if SWITCH.dim
                    text(min(xlim),max(ylim),['min val: ',num2str(min(dynTopo2d(:)),2)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
                    text(max(xlim),max(ylim),['max val: ',num2str(max(dynTopo2d(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
                    display(['   max.topo: ',num2str(max(dynTopo2d)),' / min.topo: ',num2str(min(dynTopo2d))])
                else
                end
            end

            % FIGURE SIZE & POSITION ==================================
            figure(1)
            hold on
            
            % COLORBAR ==================================
            colorbar;   %define dummy colorbar
            cb = NaN; 	%this is a flag if no colorbar is used
            
            %SIMPLIFY FIGURE ==================================
            if SWITCH.simplify
                %SET AXES ASPECT RATIO ----
                XaxisAR = GRID.aspectRatio(1);
                YaxisAR = 1;
                ZaxisAR = 1;
                set(gca,'PlotBoxAspectRatio',[XaxisAR YaxisAR ZaxisAR])
                %--------------------------
                
                %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
                PLOT.spcurrent          = sub_current;
                PLOT.sp_chax            = AXcurrent;
                if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else PLOT.sp_chaxz = NaN; end
                PLOT.sp_ccb             = cb;   %colorbar handle
                PLOT.title              = title_plot;  	%title string

                [PLOT] = f_splayout(SWITCH,PLOT,GRID,FIELD);
            end
        end
        if SWITCH.plotDifference && iloopComp==nloopComp %only for difference plot
            if isfield(PLOT,'titleString')
                legend(TOPO.hAreaDyn,PLOT.titleString{1,:},'Location','southeast','Interpreter','none') %area
            else
                legend(TOPO.hAreaDyn,SWITCH.fname_vector,'Location','southeast','Interpreter','none') %area
            end
        end
        
    elseif strcmp(GRID.Dim,'3-D')
        AXcurrent = gca; %just to be defined
        
        if SWITCH.plotTOPOtrue && SWITCH.plotTOPOsmooth
            n_start     = 1;
            n_end       = 2;
        elseif SWITCH.plotTOPOtrue
            n_start     = 1;
            n_end       = 1;
        elseif SWITCH.plotTOPOsmooth
            n_start     = 2;
            n_end       = 2;
        end
%         if SWITCH.dim; varScale2 = FIELD.varScale; else varScale2 = 1; end
        for i_field=n_start:n_end
            if SWITCH.plotTOPOtrue && SWITCH.plotTOPOsmooth
                subplot(2,1,i_field)
            end
            
            xi_plot = x2d_nstress(:,1,1);  %*varScale2; %[km]
            yi_plot = y2d_nstress(1,:,1);  %*varScale2; %[km]
            zi_plot = dynTopo2d;  %*varScale2; %[km]
            if i_field==2 %plot topo smooth ==========================
                F = [.05 .1 .05; .1 .4 .1; .05 .1 .05];
                for jj=1:20 %smoothing
                    ZC = conv2(zi_plot,F,'same');
                    zi_plot=ZC;
                end
            end %plot topo smooth ==========================
            
            surf(yi_plot,xi_plot,zi_plot,'EdgeColor','none')
            % contour(xi,yi,zi)
            if ~TOPO.ascii
                axis ij
            end
            axis tight
            if SWITCH.dim
                xlabel('width [km]')
                ylabel('width [km]')
                zlabel('topography [km]')
            else
                xlabel('x')
                ylabel('y')
                zlabel('z')
            end
        end
        if SWITCH.Colorbar(1,2); zlim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
        
        clearvars low high tix tiy
    end
end


if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else nr_hax = 1; end

%% FUNCTION OUTPUT
PLOT.hax(nr_hax,1)  = AXcurrent;

SAVE.graphPlotHandles = [SAVE.graphPlotHandles; AXcurrent]; %indicate axis handle as graph subplot
SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent];


    

