
%%                                                  Plot Fields STAGYY 8.0


%                                                            Fabio Crameri
%grid is flipped (x and y) in 3-D plots......

function [PLOT,SAVE] = f_plotFIELDS(VAR,FIELD,FIELD_M,GRID,SETUP,SWITCH,PLOT,TOPO,FILE,STYLE,SAVE)                          

if SWITCH.waitbar
    display('   ...processing')
    PLOT.wb = waitbar(0.4,PLOT.wb,'processing...');
end

PLOT.nr_subplot = PLOT.nr_subplot+1; %count subplot
nr_subplot      = PLOT.nr_subplot;

if isfield(PLOT,'quiver3Dplates') && PLOT.quiver3Dplates
    plate_velocity = logical(1);  %for 3-D velocity arrows
else
    plate_velocity = logical(0);  %for 3-D velocity arrows
end

%% VARIABLE CONVERSIONS
if strcmp(GRID.Type,'yinyang')
    VARyin = VAR.var3d_yin;      VARyang = VAR.var3d_yang;
else %everything else
    var2d = VAR.var2d;
end
field_string    = FIELD.name;
dim_string      = FIELD.dim;

keyColor        = STYLE.keyColor; if strcmp(STYLE.colorMode,'black'); keyColor = 1-keyColor; end
ColorbarMIN     = FIELD.cColorbarMIN;       ColorbarMAX = FIELD.cColorbarMAX;

rcmb    = GRID.rcmb/1e3; %[km]
x2d     = GRID.x2dp; 	y2d     = GRID.y2dp;    z2d     = GRID.z2dp; %already reversed if Cartesian, dim
x2d_nd  = GRID.x2d_nd;  y2d_nd  = GRID.y2d_nd;  z2d_nd  = GRID.z2d_nd;  %[nd]
x2d_plot= GRID.x2dp;    y2d_plot= GRID.y2dp;    z2d_plot= GRID.z2dp; %already reversed if Cartesian, dim
nx      = GRID.nx;    	ny      = GRID.ny;   	nz      = GRID.nz;

d_air   = SETUP.d_air;

constColorbar = SWITCH.Colorbar(1,2);
%SWITCH.actualDepth  SWITCH.axis_off  SWITCH.Colorbar(1,1) SWITCH.plotgrid
%SWITCH.ColormapAll  SWITCH.flipCB    SWITCH.texting       SWITCH.title
%SWITCH.ReduceSize

% PLOT.Style    PLOT.numContours    PLOT.nrPlots

quiver_plot         = PLOT.quiverM(1,1);
quiver_T            = PLOT.quiverM(1,2);
quiver_eta          = PLOT.quiverM(1,3);
quiver_str          = PLOT.quiverM(1,4);
quiver_numDel     	= PLOT.quiverM(1,5);
scale               = PLOT.quiverM(1,6);
quiver_psi          = PLOT.quiverM(1,7);
quiver_rho          = PLOT.quiverM(1,8);
quiver_nstr         = PLOT.quiverM(1,9);
quiver_edot         = PLOT.quiverM(1,10);

% streamfun_plot  = PLOT.streamfun(1,1);
streamfun_T         = PLOT.streamfun(1,2);
streamfun_eta       = PLOT.streamfun(1,3);
streamfun_str       = PLOT.streamfun(1,4);
stream_numContours  = PLOT.streamfun(1,5);
streamfun_rho       = PLOT.streamfun(1,6);
streamfun_v         = PLOT.streamfun(1,7);
streamfun_edot      = PLOT.streamfun(1,8);
stream_data         = PLOT.streamdata;

streamline_plot     = PLOT.streamline(1,1);
streamline_T        = PLOT.streamline(1,2);
streamline_eta      = PLOT.streamline(1,3);
streamline_str      = PLOT.streamline(1,4);
startline           = PLOT.stream_startline; sx2d=startline(1,:); sy2d=startline(2,:); sz2d=startline(3,:);

defmech_T           = PLOT.defmech(1,1);
defmech_eta         = PLOT.defmech(1,2);
defmech_str         = PLOT.defmech(1,3);
defmech_edot        = PLOT.defmech(1,4);
defmech_contours    = PLOT.defmech(1,5:end);

lithoThickness_isoVal= PLOT.lithoThickness(1,1);
lithoThickness_zmax = PLOT.lithoThickness(1,2);
lithoThickness_T    = PLOT.lithoThickness(1,3);
lithoThickness_eta  = PLOT.lithoThickness(1,4);
lithoThickness_field= PLOT.LTfieldContour;
lithoThickness_nstr = PLOT.lithoThickness(1,5);

fieldContour_isoVal = PLOT.fieldContour(1,1);
fieldContour_T      = PLOT.fieldContour(1,2);
fieldContour_eta    = PLOT.fieldContour(1,3);
fieldContour_nstr   = PLOT.fieldContour(1,4);
fieldContour_vx     = PLOT.fieldContour(1,5);
fieldContour_str    = PLOT.fieldContour(1,6);
fieldContour_edot   = PLOT.fieldContour(1,7);


%% ERROR CHECKS
if isfield(VAR,'var2d') && isfield(VAR,'var3d_yin'); error('It is not clear wheter to plot var2d or var2d_yin: check here!'); end


%% SETUP ANNOTATION STRINGS
if FIELD.logarithmic
    fieldString1 = ['log_{10}(',field_string,') @ '];
    if SWITCH.Colorbar(1,1)
        if SWITCH.dim || SWITCH.dimensional_input; CBtitle_plot = ['log_{10}({\it',FIELD.symbol,'}/',dim_string,')']; else CBtitle_plot = 'nd'; end
    end
else
    fieldString1 = [field_string,' @ '];
    if SWITCH.Colorbar(1,1)
        if SWITCH.dim || SWITCH.dimensional_input; CBtitle_plot = dim_string; else CBtitle_plot = 'nd'; end
    end
end
if PLOT.titleOnlyTime; fieldString1 = ''; end
if SWITCH.dim || SWITCH.dimensional_input
    title_plot  = [fieldString1,num2str(PLOT.time2plot,3),' ',PLOT.time2plotDim];
else
    title_plot  = [fieldString1,num2str(PLOT.time,3),' '];
end
if isfield(PLOT,'titleString'); time_plotX = title_plot; title_plot = PLOT.titleString(1,PLOT.nr_subplot); end

%axis labelling...
xlabel_plot = ['width [',GRID.Xdim,']']; xlabel_3Dplot = ['y-width [',GRID.Ydim,']'];
ylabel_plot = ['depth [',GRID.Zdim,']']; ylabel_3Dplot = ['x-width [',GRID.Xdim,']'];  zlabel_3Dplot = ['z-depth [',GRID.Zdim,']'];


%% FIGURE LAYOUT
%figure...
figure(1)

%subplot layout...
if isfield(PLOT,'subplotLayout') %manual arrangement
    sub_current=[PLOT.subplotLayout(1,1),PLOT.subplotLayout(1,2),nr_subplot];
else
    if PLOT.nrPlots>=4
        if mod(PLOT.nrPlots,2)
            sub_current=[(PLOT.nrPlots+1)/2 2 nr_subplot];
        else
            sub_current=[PLOT.nrPlots/2 2 nr_subplot];
        end
    else
        sub_current=[PLOT.nrPlots 1 nr_subplot];
    end
end
if PLOT.reverseLayout %top-down plotting
    if ~isfield(PLOT,'layoutNum')
        PLOT.layoutNum = zeros(sub_current(1,1),sub_current(1,2));
        idx = 0;
        for ii=1:size(PLOT.layoutNum,1)
            for jj=1:size(PLOT.layoutNum,2)
                idx = idx+1;
                PLOT.layoutNum(ii,jj) = idx;
            end
        end
        idx = 0; PLOT.layoutNumTransposed = PLOT.layoutNum;
        for jj=1:size(PLOT.layoutNum,2)
            for ii=1:size(PLOT.layoutNum,1)
                idx = idx+1;
                PLOT.layoutNumTransposed(ii,jj) = idx; %transposed layout
            end
        end
    end
    %UPDATE TO NEW LAYOUT
    %       while PLOT.nr_subplot is still setup the old way!
    nr_subplot = PLOT.layoutNum(PLOT.layoutNumTransposed==nr_subplot);
    sub_current(1,3) = nr_subplot;
end
%subplot...
subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3));

%% CURRENT AXIS
AXcurrent = gca; %save current axes handle

%% DIMENSIONALISATION
if strcmp(GRID.Type,'yinyang')
    VARyin      = VARyin .* FIELD.varScale;
    VARyang     = VARyang .* FIELD.varScale;
    if FIELD.logarithmic; 
        VARyin   = log10(VARyin); 
        VARyang  = log10(VARyang); 
    end
else %everything else
    var2d       = var2d .* FIELD.varScale;
    if FIELD.logarithmic
        var2d = log10(var2d); 
    end
end




if strcmp(GRID.Type,'cartesian')
    %% CARTESIAN 3-D PLOT ******************************************************************
    if strcmp(GRID.Dim,'3-D')   % 3-D
        AXorig  = gca;
        if ~isfield(PLOT,'isoVal'); PLOT.isoVal = [0.45 0.2 0.7 0.1 0.9]; end
        if constColorbar
            max_val = ColorbarMAX;
            min_val = ColorbarMIN;
        else
            max_val = max(var2d(:));
            min_val = min(var2d(:));
        end
        range_val = max_val-min_val;
        PLOT.isoVal_dim     = min_val+PLOT.isoVal.*range_val;
        PLOT.isoVal_special_dim = min_val+PLOT.isoVal_special.*range_val;
        clearvars max_val min_val range_val
                
        if SWITCH.ReduceSize
            wb = waitbar(0,'Slimming Matrix...');
            %reduce size of matrix
            max_gridpoints = 300;   %<--------------------------=================
            nx_eff = nx;
            ny_eff = ny;
            nz_eff = nz;
            while (nx_eff+ny_eff+nz_eff)>max_gridpoints  
                waitbar(max_gridpoints/(nx_eff+ny_eff+nz_eff),wb)
                for i=(nx_eff-2):-2:2
                    x2d_plot(i,:)       = [];
                    var2d(i,:,:)   = [];
                end
                for j=(ny_eff-2):-2:2
                    y2d_plot(:,j)       = [];
                    var2d(:,j,:)   = [];
                end
                for k=(nz_eff-2):-2:2
                    z2d_plot(:,:,k)   	= [];
                    var2d(:,:,k)   = [];
                end
                x2d_plot(4,:)       = [];
                var2d(4,:,:)   = [];
                y2d_plot(:,4)       = [];
                var2d(:,4,:)   = [];
                z2d_plot(:,:,4)   	= [];
                var2d(:,:,4)   = [];
                
                nx_eff = size(x2d_plot,1);
                ny_eff = size(y2d_plot,2);
                nz_eff = size(z2d_plot,3);
            end
            display(['Size of plotted matrix decreased to ',num2str(size(var2d))])
            clearvars nx_eff ny_eff nz_eff max_gridpoints
            close(wb)
        end
                
        % set up grid box...
        if SWITCH.axisEqual; axis equal; end
        %it seems that isosurface needs the order: (y,x,z,var)...
        axis([min(y2d_plot) max(y2d_plot) min(x2d_plot) max(x2d_plot) min(z2d_plot) max(z2d_plot)])
        box on
        grid on
%         L(1) = light; %original lighting 
        %---------------------
        set(gca,'ZDir','reverse')
        %---------------------
        %set camera position
        if PLOT.cameraPosBotView
            campos(PLOT.cameraPosition.*[1 1 -1]) %flipped upside down
        else
            campos(PLOT.cameraPosition) %standard
        end
        %set perspective mode
        camproj(PLOT.camProjection)
        
        % plotting...
        %isosurface
        if isfield(PLOT,'isoVal') && ~isempty(PLOT.isoVal)
            for iplot_iso=1:size(PLOT.isoVal,2)
                %it seems that isosurface needs the order: (y,x,z,var)...
                %isosurface(x2d_plot,y2d_plot,z2d_plot,var2d_plot,PLOT.isoVal_dim(1,iplot_iso),'noshare');
                isosurface(y2d_plot,x2d_plot,z2d_plot,var2d,PLOT.isoVal_dim(1,iplot_iso),'noshare');
                if iplot_iso<(size(PLOT.isoVal,2)-PLOT.opacity(1,2)+1); alpha(PLOT.opacity(1,1)); end %make last isosurface opaque
%                 camlight(PLOT.camlight); lighting(PLOT.lighting); %needed for every surface - I think
                hold on
            end
        end
        %special isosurface
        if isfield(PLOT,'isoVal_special') && ~isempty(PLOT.isoVal_special)
            %it seems that isosurface needs the order: (y,x,z,var)...
%             hspecial = patch(isosurface(x2d_plot,y2d_plot,z2d_plot,var2d_plot,PLOT.isoVal_special_dim(1,1),'noshare'));
            hspecial = patch(isosurface(y2d_plot,x2d_plot,z2d_plot,var2d,PLOT.isoVal_special_dim(1,1),'noshare'));
            isonormals(y2d_plot,x2d_plot,z2d_plot,var2d,hspecial);
            set(hspecial,'FaceAlpha',PLOT.opacity_special(1,1),'FaceColor',PLOT.isoColor_special,'EdgeColor','none');
%             drawnow
%             camlight(PLOT.camlight); lighting(PLOT.lighting); %needed for every surface - I think
            hold on
        end
        %saving field to file
        if FIELD.save || logical(0) %save current field
            SAVE.Directory = FILE.directory;
            f_saveField(x2d_plot,y2d_plot,z2d_plot,var2d,FIELD,FILE,SAVE);
        end
        
        %LIGHTING
        L(1) = light; %original lighting
        set(L(1),'pos',[-1 0 -1]); %adjust lighting to reverse axis
        camlight(PLOT.camlight); lighting(PLOT.lighting); %needed for every surface - I think

        %warning('transparency and lighting do only work with the opengl renderer, which is a bit buggy at times... add error checks to prevent using both, ie. possible problems.')
                
        %% slices
        if PLOT.Slices    
% if IN.plotStreamfun; IN.plotLineColor=streamColor; else  IN.plotLineColor='none'; end

            %adjust the grid for slicing...
            [y2d_plot2,x2d_plot2,z2d_plot2] = meshgrid(y2d_plot,x2d_plot,z2d_plot);
            %PLOT MAIN FIELD SLICE...
            hold on
            sp1 = slice(y2d_plot2,x2d_plot2,z2d_plot2,var2d,PLOT.slice_y,PLOT.slice_x,PLOT.slice_z);
            set(sp1,'edgecolor','none');
            set(sp1,'FaceColor','interp')
            alpha(sp1,PLOT.SliceOpacity);
            
            %saving slice field to file
            if logical(0)  %FIELD.save || logical(0) %save current field for a 2-D slice
                var2d_save = zeros(size(var2d,1),size(var2d,3));
                %---------------------------------------------
                var2d_save(:,:) = var2d(:,end/2,:); %<<<<adjust here which slice
                %---------------------------------------------
                z2d_save = zeros(size(z2d_plot,3),1); z2d_save(:,1) = z2d_plot(1,1,:);
                f_saveField( x2d_plot,1,z2d_save,var2d_save,FIELD,FILE,SAVE );
                %and time data
                if PLOT.loop_field==1
                    SAVE.Directory              = ['~/Desktop/',FILE.name,'/'];
                    SAVE.DataName               = ['time_',num2str(FILE.number)];
                    SAVE.data                   = [PLOT.time, PLOT.time_dim*SETUP.secyear,PLOT.time_dim]; %[nd, seconds, years]
                    SAVE.dat                    = logical(0);
                    SAVE.txt                    = logical(0);
                    SAVE.mat                    = logical(1);
                    SAVE.write2existing         = logical(0);
                    
                    f_saveDat( SAVE )
                end
            end
            %PLOT SPECIAL SLICE...
            if PLOT.SliceSpecial
                hold on
                sp2 = slice(y2d_plot2,x2d_plot2,z2d_plot2,var2d,PLOT.slice_yS,PLOT.slice_xS,PLOT.slice_zS);
                set(sp2,'edgecolor','none');
                set(sp2,'FaceColor','interp')
                alpha(sp2,PLOT.SliceOpacity);
            end
            %ADD QUIVER SLICES...
            if PLOT.sliceAddQuiver  %adjust this to work also with multiple fields and only plot for certain fields
                % Read pressure & velocity information
                [~,~,~,~,VX_3D,VY_3D,VZ_3D,~,~] = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,'velocity',SWITCH.Precision);
                if PLOT.YZ_2Dcartesian; %exchange x and y
                    dummy_3D = zeros(size(VY_3D,2),size(VY_3D,1),size(VY_3D,3));
                    dummy_3Dx = zeros(size(VY_3D,2),size(VY_3D,1),size(VY_3D,3));
                    dummy_3D(:,1,:)     = VZ_3D(1,:,:); VZ_3D = dummy_3D;
                    dummy_3Dx(:,1,:)    = VX_3D(1,:,:);
                    dummy_3D(:,1,:)     = VY_3D(1,:,:); VY_3D = dummy_3Dx; VX_3D = dummy_3D;
                end
                VZ_3D   = -VZ_3D; % for reverse z-axis  (1.)
                X_3D_V  = zeros(size(GRID.X_3D))*NaN;
                Y_3D_V  = X_3D_V;
                Z_3D_V  = X_3D_V;
                VX_3D_V = X_3D_V;
                VY_3D_V = X_3D_V;
                VZ_3D_V = X_3D_V;
                slice_xgp_V = [];
                slice_ygp_V = [];
                slice_zgp_V = [];
                % Extract slices close to desired values & reduce data size
                sNrWrite = PLOT.sliceNrWrite;
                %find closest x-value to desired slice
                for ii=1:size(PLOT.slice_x_V,2)
                    tmp = abs((GRID.X_3Dp(:,1,1))-PLOT.slice_x_V(1,ii));
                    [minx idx] = min(tmp); %index of closest value
                    slice_xgp_V = [slice_xgp_V idx];
                end
                if ~isempty(slice_xgp_V)
                    X_3D_V(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end) = GRID.X_3Dp(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end);
                    Y_3D_V(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end) = GRID.Y_3Dp(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end);
                    Z_3D_V(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end) = GRID.Z_3Dp(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end);
                    VX_3D_V(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end) = VX_3D(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end);
                    VY_3D_V(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end) = VY_3D(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end);
                    VZ_3D_V(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end) = VZ_3D(slice_xgp_V,1:sNrWrite:end,1:sNrWrite:end);
                end
                %find closest y-value to desired slice
                for ii=1:size(PLOT.slice_y_V,2)
                    tmp = abs((GRID.Y_3Dp(1,:,1))-PLOT.slice_y_V(1,ii));
                    [minx idx] = min(tmp); %index of closest value
                    slice_ygp_V = [slice_ygp_V idx];
                end
                if ~isempty(slice_ygp_V)
                    X_3D_V(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end) = GRID.X_3Dp(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end);
                    Y_3D_V(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end) = GRID.Y_3Dp(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end);
                    Z_3D_V(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end) = GRID.Z_3Dp(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end);
                    VX_3D_V(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end) = VX_3D(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end);
                    VY_3D_V(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end) = VY_3D(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end);
                    VZ_3D_V(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end) = VZ_3D(1:sNrWrite:end,slice_ygp_V,1:sNrWrite:end);
                end
                %find closest z-value to desired slice
                for ii=1:size(PLOT.slice_z_V,2)
                    tmp = abs((GRID.Z_3Dp(1,1,:))-PLOT.slice_z_V(1,ii));
                    [minx idx] = min(tmp); %index of closest value
                    slice_zgp_V = [slice_zgp_V idx];
                end
                if ~isempty(slice_zgp_V)
                    X_3D_V(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V) = GRID.X_3Dp(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V);
                    Y_3D_V(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V) = GRID.Y_3Dp(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V);
                    Z_3D_V(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V) = GRID.Z_3Dp(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V);
                    VX_3D_V(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V) = VX_3D(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V);
                    VY_3D_V(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V) = VY_3D(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V);
                    VZ_3D_V(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V) = VZ_3D(1:sNrWrite:end,1:sNrWrite:end,slice_zgp_V);
                end
                % Plot quiver
                hold on
                q1 = quiver3(Y_3D_V,X_3D_V,Z_3D_V,VX_3D_V,VY_3D_V,VZ_3D_V,scale);
                warning('check if VX_3D and VY_3D need to be switched here!')
                set(q1,'Color',PLOT.quiverColor,'LineWidth',PLOT.quiverWidth)
            end
        
% if IN.add_streamline
%     hold on
%     [phi2,theta2] = meshgrid(phi_V,theta_V);
%     %             [s1,s2] = meshgrid( phi2(:,10),theta2(:,10));     %starting points
%     s1=phi2(5,10);
%     s2=theta2(5,10);
%     [sx,sy]=meshgrid(s1,s2);
%     streamline(x2d_V,y2d_V,VX_map(:,:,nr_subplot),VY_map(:,:,nr_subplot),sx,sy)
% end

            %PLOT TOPOGRAPHY SLICE ON TOP...
            if PLOT.SliceAddTopo
                if TOPO.cmb; startT=1; else startT=2; end
                for iT=startT:2
                    colorbar('hide')
                    freezeColors %freeze previous colormap
                    hold on
                    %TOPO COLORMAP
                    %if self-made colorbar:
                    if exist([SWITCH.ColormapAllT{1,1},'.mat'],'file')==2
                        load([SWITCH.ColormapAllT{1,1},'.mat']); SWITCH.ColormapAllTnum{1,1}=eval( sprintf(SWITCH.ColormapAllT{1,1}) ); %load colorbar
                    end
                    % else predefined colorbars:
                    if strcmp(SWITCH.ColormapAllT{1,2},'flip')
                        colormap(SWITCH.ColormapAllTnum{1,1})
                        colormap(flipud(colormap));
                    elseif strcmp(SWITCH.ColormapAllT{1,2},'noflip')
                        colormap(SWITCH.ColormapAllTnum{1,1})
                    else
                        error('Unknown Colormap option: Flip or no flip?')
                    end
                    TOPO.directory = FILE.directory; TOPO.fname = FILE.name; TOPO.fname_number = FILE.number;
                    TOPO.varScale = SETUP.D_dim; %km
                    
                    [TOPO] = f_readTopo3D(TOPO,SWITCH,GRID); %read topography
                    
                    %adjust plotting values--
                    TOPO.z_surf         = -TOPO.z_surf;  %flip due to depth plot
                    TOPO.z_cmb          = -TOPO.z_cmb;
                    %dimensionalise ADJUST HERE IF NECESSARY (CHECK TOPO3D FUNCTION)!
%                     TOPO.z_surf         = TOPO.z_surf;
%                     TOPO.z_cmb          = TOPO.z_cmb;
                    
                    TOPO.z_surf_plot    = TOPO.z_surf*TOPO.exagFactor;  %flip due to depth plot %TOPO.z_surf+2*(TOPO.z_surf-mean(mean(TOPO.z_surf)));
                    TOPO.z_cmb_plot     = TOPO.z_cmb*TOPO.exagFactor;
                    colormap(flipud(colormap));
                    %------------------------
                    if iT==1
                        topoZ1 = TOPO.z_cmb; topoZ2 = TOPO.z_cmb+1*D_act/conversian_factor; meanT=mean(mean(topoZ2)); %plot at the bottom;
                        topoZ2_plot = TOPO.z_cmb_plot+1*D_act/conversian_factor; meanT_plot=mean(mean(topoZ2_plot)); %plot at the bottom;
                    elseif iT==2
                        topoZ1 = TOPO.z_surf; topoZ2 = topoZ1; meanT=0;
                        topoZ2_plot = TOPO.z_surf_plot; meanT_plot=0;
                    end
                    if iT==2 && ~TOPO.surf
                    else
                        %TOPO PLOTTING
                        TOPO.slice = false;
                        if TOPO.slice
                            error('this is not yet adjusted for use in STAGplot')
                            topoDUMMY3D = ones(size(X_3D));
                            for iz=1:size(X_3D,3)
                                topoDUMMY3D(:,:,iz) = topoZ1;
                            end
                            sptopo = slice(Y_3D,Z_3D,Z_3D,topoDUMMY3D,IN.slice_yT,IN.slice_xT,IN.slice_zT);
                        else
                            sptopo = surf(GRID.y2dp,GRID.x2dp,topoZ2_plot); %actual plot
                            camlight(PLOT.camlight); lighting(PLOT.lighting); %needed for every surface - I think
                            hold on
                            sptopo2 = surf(GRID.y2dp,GRID.x2dp,topoZ2);  %for manipulating colorbar; will be deleted later
                        end
                        set(sptopo,'edgecolor','none');
                        set(sptopo,'FaceColor','interp')
                        alpha(sptopo,PLOT.SliceOpacityT);
                        hold on
                    end
                    if iT==1 && TOPO.surf && TOPO.cmb;
                        topoLIM1 = max(abs(min(min(TOPO.z_surf))), abs(max(max(TOPO.z_surf))));
                        topoLIM2 = max(abs(min(min(TOPO.z_cmb))), abs(max(max(TOPO.z_cmb))));
                        topoLIM = max(topoLIM1,topoLIM2);
                        if SWITCH.me
                            display(['  surface topography: max=',num2str(max(max(TOPO.z_surf)),3),', min=',num2str(min(min(TOPO.z_surf)),3)])
                            display(['  CMB topography:     max=',num2str(max(max(TOPO.z_cmb)),3),', min=',num2str(min(min(TOPO.z_cmb)),3)])
                        end
                    elseif iT==2 && TOPO.surf && ~TOPO.cmb; topoLIM = max(abs(min(min(TOPO.z_surf))), abs(max(max(TOPO.z_surf))));
                        if SWITCH.me; display(['  surface topography: max=',num2str(max(max(TOPO.z_surf)),3),', min=',num2str(min(min(TOPO.z_surf)),3)]); end
                    elseif iT==1 && TOPO.cmb; topoLIM = max(abs(min(min(TOPO.z_cmb))), abs(max(max(TOPO.z_cmb))));
                        if SWITCH.me; display(['  CMB topography:     max=',num2str(max(max(TOPO.z_cmb)),3),', min=',num2str(min(min(TOPO.z_cmb)),3)]); end
                    end
                    %for manipulating colorbar--
                    topoLIM_plot = topoLIM*TOPO.exagFactor;
                    if exist('sptopo2','var'); set(sptopo2,'edgecolor','none'); end
                    if SWITCH.constantColorbarT; set(gca,'clim',[meanT_plot-topoLIM_plot,meanT_plot+topoLIM_plot]); end
                    freezeColors %freeze previous colormap
                    set(sptopo,'edgecolor','none');
                    colormap(flipud(colormap));
                    %---------------------------
                    if SWITCH.constantColorbarT; set(gca,'clim',[meanT-topoLIM,meanT+topoLIM]); end
                    SWITCH.positionColorbar = 3; %1: bottom  2: right  3: south-east
                    if SWITCH.positionColorbar==1 %bottom
                        cbT=colorbar('horiz');
                        set(cbT,'Position',[0.4 0.04 0.2 0.017]);
                    elseif SWITCH.positionColorbar==2 %right
                        cbT=colorbar;
                        set(cbT,'Position',[0.9 axPos(1,2) 0.017 axPos(1,4)]);
                    elseif SWITCH.positionColorbar==3 %south-east
                        cbT=colorbar('horiz');
                        %set(cbT,'Position',[0.73 0.77 0.17 0.014]); %top
                        set(cbT,'Position',[0.73 0.12 0.17 0.014]); %bottom
                    end
                    %         set( cbT, 'XDir', 'reverse' );
                    if SWITCH.positionColorbar==2 %right
                        if SWITCH.dim || SWITCH.dimensional_input
                            ylabel(cbT,'topography [km]','FontWeight','bold');
                        else
                            ylabel(cbT,'topography [nd]','FontWeight','bold');
                        end
                    else %south-east
                        if SWITCH.dim || SWITCH.dimensional_input
                            title(cbT,'topography [km]','FontWeight','bold');
                        else
                            title(cbT,'topography [nd]','FontWeight','bold');
                        end
                    end
                    if exist('sptopo2','var') && iT==1; set(sptopo2,'Visible','off'); end
                end
                if TOPO.exagFactor~=1 && SWITCH.me
                    display(['  topo exaggeration factor: ',num2str(TOPO.exagFactor)]);
                end
                delete(sptopo2);
            end
        end
        
        % colorbar...
        if SWITCH.Colorbar(1,1)
            cb=colorbar;
            if constColorbar
                set(gca,'clim',[ColorbarMIN,ColorbarMAX])
            else
                if SWITCH.MversionSupported; set(gca,'clim',cb.Limits); end
            end
            if strcmp(FIELD.name,'deformation mechanism');
                set(cb,'Ticks',[1,2,3,4],'TickLabels',{'diff. creep','disl. creep','plasticity','cut-off'});
            else
                title(cb,CBtitle_plot); %on top
                %ylabel(cb,CBtitle_plot); %on left hand side
            end
        end
        % texting...
        if SWITCH.title
            htitle = title(title_plot);
            if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.loop_case,:)); end
        end
        xlabel(xlabel_3Dplot); ylabel(ylabel_3Dplot); zlabel(zlabel_3Dplot);
        if SWITCH.texting
            text(max(xlim),min(ylim),['max val: ',num2str(max(var2d(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8);
            text(min(xlim),min(ylim),[num2str(nx),'x',num2str(ny),'x',num2str(nz)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8);
            display(['   ',FIELD.name,' variation: ',num2str(min(var2d(:)),4),' <-> ',num2str(max(var2d(:)),4),' ',FIELD.dim])
        else
            % text(min(xlim),min(ylim),[num2str(nx),'x',num2str(ny),'x',num2str(nz)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
        end
                
        
    elseif strcmp(GRID.Dim,'2-D')
        %% CARTESIAN 2-D PLOT ******************************************************************
        if SWITCH.ReduceSize
            wb = waitbar(0,'Slimming Matrix...');
            %reduce size of matrix
            max_gridpoints = 30000;   %<--------------------------=================
            nx_eff = nx;
            nz_eff = nz;
            while (nx_eff*nz_eff)>max_gridpoints  
                waitbar(max_gridpoints/(nx_eff+nz_eff),wb)
                for i=(nx_eff-2):-2:2
                    x2d_plot(i,:)       = [];
                    z2d_plot(i,:)   	= [];
                    var2d(i,:)     = [];
                end
                for k=(nz_eff-2):-2:2
                    x2d_plot(:,k)       = [];
                    z2d_plot(:,k)   	= [];
                    var2d(:,k)     = [];
                end
                x2d_plot(4,:)       = [];
                z2d_plot(4,:)       = [];
                var2d(4,:)     = [];
                x2d_plot(:,4)   	= [];
                z2d_plot(:,4)   	= [];
                var2d(:,4)     = [];
                nx_eff = size(x2d_plot,1);
                nz_eff = size(x2d_plot,2);
            end
            display(['Size of plotted matrix decreased to ',num2str(size(var2d))])
            clearvars nx_eff ny_eff nz_eff max_gridpoints
            close(wb)
        end        
        loop_zoom = 1;
        if isfield(PLOT,'zoom') && PLOT.zoom
            loop_zoom = 2; 
        end
        %loop for zoom plot
        for izoom=1:loop_zoom
            AXorig  = gca;
            if izoom==2  %ZOOM PLOT
                AXpos   = get(gca,'Position'); %get current axes position
                xsizing = 0.5; %change size by this value
                ysizing = 0.7;
                if strcmp(PLOT.zoomPos,'northwest')
                    xtrans  = 0.72*AXpos(1,3);  %translate
                    ytrans  = 0.2*AXpos(1,4);
%                 xtrans  = AXpos(1,3);  %translate
%                 ytrans  = 0.2*AXpos(1,4);
                elseif strcmp(PLOT.zoomPos,'southwest')
                    xtrans  = 0.72*AXpos(1,3);  %translate
                    ytrans  = -0.2*AXpos(1,4);
                elseif strcmp(PLOT.zoomPos,'west')
                    xtrans  = 0.72*AXpos(1,3);  %translate
                    ytrans  = 0;
%                 elseif strcmp(PLOT.zoomPos,'northeast')
%                 elseif strcmp(PLOT.zoomPos,'southeast')
                else
                    error(['PLOT.zoomPos ',PLOT.zoomPos,' not recognised!'])
                end
                haxZ = axes('Position', [AXpos(1,1)+xtrans ...
                                        AXpos(1,2)+ytrans ...
                                        AXpos(1,3)*xsizing ...
                                        AXpos(1,4)*ysizing ]); %set new zoom axis position
            end
            if isfield(PLOT,'saveProfile') && PLOT.saveProfile
                %skip plotting fields if plotting/saving profiles switched on
                display(['             ',time_plotX])
            else
                if strcmp(PLOT.Style,'contour')
                    if strcmp(FIELD.name,'streamfunction'); plotLineColor=PLOT.streamColor; else plotLineColor='none'; end
                    [C,h]=contourf(x2d_plot,z2d_plot,var2d,PLOT.numContours,'LineColor',plotLineColor);
                elseif strcmp(PLOT.Style,'pcolor')
                    sp=pcolor(x2d_plot,z2d_plot,var2d); set(sp,'edgecolor','none');
                    shading interp
                else
                    error('Unknown plotting style!')
                end
                %.........
                drawnow  %actually only needed if topo or other graph plot is included (axis change otherwise)
                %.........
                %saving field to file
                if FIELD.save || logical(0) %save current field
                    f_saveField(x2d_plot,1,z2d_plot,var2d,FIELD,FILE,SAVE);
                end
                if izoom==1 %main plot
                    % colorbar...
                    if SWITCH.Colorbar(1,1)
                        cb=colorbar;
                        if constColorbar
                            set(gca,'clim',[ColorbarMIN,ColorbarMAX])
                        else
                            if SWITCH.MversionSupported; set(gca,'clim',cb.Limits); end %only for newer versions
                        end
                        %label colorbar ticks if needed:
                        if strcmp(FIELD.name,'deformation mechanism'); 
                            set(cb,'Ticks',[1,2,3,4],'TickLabels',{'diff. creep','disl. creep','plasticity','cut-off'}); 
                        else
                            title(cb,CBtitle_plot); %on top
                            %ylabel(cb,CBtitle_plot); %on left hand side
                        end                     
                    end
                    % texting...
                    if SWITCH.title
                        if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
                            htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
                        else
                            htitle = title(title_plot); %centered
                        end
                        if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.loop_case,:)); end
                    end
                    xlabel(xlabel_plot)
                    ylabel(ylabel_plot)
                    if SWITCH.texting
                        %             text(max(xlim),min(ylim),['max val: ',num2str(max(var2d(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
                        text(max(xlim),min(ylim),['min val: ',num2str(min(var2d(:)),2),'; max val: ',num2str(max(var2d(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8);
                        text(min(xlim),min(ylim),[num2str(nx),'x',num2str(nz)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8);
                        display(['   ',FIELD.name,' variation: ',num2str(min(var2d(:)),4),' <-> ',num2str(max(var2d(:)),4),' ',FIELD.dim])
                    else
                        % text(min(xlim),min(ylim),[num2str(nx),'x',num2str(nz)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8);
                    end
                    % axes...
                    if SWITCH.axisEqual; axis equal; end
                    axis tight
                    if SWITCH.axis_off; axis off; end
                    
                else %zoom plot
                    if constColorbar
                        set(gca,'clim',[ColorbarMIN,ColorbarMAX])
                    else
                        set(gca,'clim',cb.Limits)
                    end
                    set(gca,'XTick',[])
                    set(gca,'YTick',[])
                    %lineColor = [0.9 0.9 0.9]; %white-ish
                    % axes...
                    if SWITCH.axisEqual; axis equal; end
                    axis tight
                    %set(gca,'XColor',lineColor,'YColor',lineColor,'LineWidth',1)
                    axis(PLOT.zoomVal(PLOT.loop_case,:))
                end
                %---------------------
                axis ij  % reverse axis (2.)
                %---------------------
            end
            
            % EXTRACT Z-PROFILE
            if isfield(PLOT,'zProfile')
                if PLOT.zProfile
                    aspect_ratio = nx/nz;
                    factor_xprof = aspect_ratio/2;
                    x_prof = PLOT.x_prof*factor_xprof; %make sure it works simultaneously with different aspect ratios (standard is 2:1)
                    x_prof = round( size(z2d_plot,2)*x_prof );
                    if isfield(PLOT,'z_prof'); z_prof = round( size(x2d_plot,2)*PLOT.z_prof ); end %horizontal profile
                    hold on %black indication line
                    if isfield(PLOT,'z_prof')   %horizontal profile
                        plot([min(x2d_plot(:,1)) max(x2d_plot(:,1))],[z2d_plot(1,z_prof) z2d_plot(1,z_prof)],'w')
                        plot([min(x2d_plot(:,1)) max(x2d_plot(:,1))],[z2d_plot(1,z_prof) z2d_plot(1,z_prof)],'--k')
                    else                        %vertical profile
                        plot([x2d_plot(x_prof,1) x2d_plot(x_prof,1)],[min(z2d_plot(1,:)) max(z2d_plot(1,:))],'w')
                        plot([x2d_plot(x_prof,1) x2d_plot(x_prof,1)],[min(z2d_plot(1,:)) max(z2d_plot(1,:))],'--k')
                    end
                    figure(21) %profile
                    if PLOT.loop_case==1; clf; end
                    hold on
                    if isfield(PLOT,'z_prof')   %horizontal profile
                        PLOT.hprof(PLOT.loop_case,1) = plot(x2d_plot(:,z_prof),var2d(:,z_prof),...
                            'Color',PLOT.caseColor(PLOT.loop_case,:),'LineStyle',PLOT.lineStyle{1,PLOT.loop_case},...
                            'LineWidth',PLOT.lineWidth(1,PLOT.loop_case));
                        if isfield(PLOT,'saveProfile') && PLOT.saveProfile
                            %SAVE PROFILES
                            PLOT.prof_xzdata(:,PLOT.loop_case,PLOT.timestep_profile)    = x2d_plot(:,z_prof);
                            PLOT.prof_vardata(:,PLOT.loop_case,PLOT.timestep_profile)   = var2d(:,z_prof);
                        end
                    else                        %vertical profile
                        PLOT.hprof(PLOT.loop_case,1) = plot(var2d(x_prof,:),z2d_plot(x_prof,:),...
                            'Color',PLOT.caseColor(PLOT.loop_case,:),'LineStyle',PLOT.lineStyle{1,PLOT.loop_case},...
                            'LineWidth',PLOT.lineWidth(1,PLOT.loop_case));
                        if isfield(PLOT,'saveProfile') && PLOT.saveProfile
                            %SAVE PROFILES
                            PLOT.prof_xzdata(:,PLOT.loop_case,PLOT.timestep_profile)    = z2d_plot(x_prof,:)';
                            PLOT.prof_vardata(:,PLOT.loop_case,PLOT.timestep_profile)   = var2d(x_prof,:)';
                        end
                    end
                    axis tight; box on; grid on
                    if isfield(PLOT,'z_prof')   %horizontal profile
                        title(['profile at z = ',num2str(z2d_plot(1,z_prof),3)])
                        ylabel([num2str(field_string),' [',num2str(CBtitle_plot),']']); xlabel(xlabel_plot)
                    else
                        axis ij
                        title(['profile at x = ',num2str(x2d_plot(x_prof,1),3)])
                        xlabel([num2str(field_string),' [',num2str(CBtitle_plot),']']); ylabel(ylabel_plot)
                    end
                    if isfield(PLOT,'titleString'); annot_profiles = PLOT.titleString(1,1:PLOT.loop_case);
                    else annot_profiles = [field_string,' @ ',num2str(PLOT.time,3),' ']; end
                    legend(PLOT.hprof(1:PLOT.loop_case,1),annot_profiles);
                    if nr_subplot~=PLOT.loop_case; error('check this here! is wrong due to incorrect PLOT.loop_case'); end
                    if SWITCH.stylePlots && PLOT.loop_plot==PLOT.nrPlots
                        f_figStyle;
                    end
                end
            end
            if izoom==2; axes(AXorig); end %activate current axis
        end %zoom loop
    end %2-D/3-D

    
    
    
elseif strcmp(GRID.Type,'cylindrical')
    %% CYLINDRICAL PLOT ******************************************************************
    plotCylCart = logical(0);
    AXorig  = gca;
    %---- cylindrical-cartesian plot -----------------------------------
    %set up cylindrical-cartesian figure...
    if plotCylCart || SWITCH.me
        figure(2)
        if nr_subplot==1; clf(figure(2)); end
        subplot(PLOT.nrPlots,1,nr_subplot)
        %setup grid...
        x2d_C = x2d_plot;
        z2d_C = z2d_plot;
        %plotting...
        if strcmp(PLOT.Style,'contour')
            if strcmp(FIELD.name,'streamfunction'); plotLineColor=PLOT.streamColor; else plotLineColor='none'; end
            contourf(x2d_C,z2d_C,var2d,PLOT.numContours,'LineColor',plotLineColor)
            
        elseif strcmp(PLOT.Style,'pcolor')
            sp=pcolor(x2d_C,z2d_C,var2d); set(sp,'edgecolor','none');
            shading interp
        else
            error('Unknown plotting style!')
        end
        %axes...
        if SWITCH.axis_off
            axis off
        end
        if SWITCH.axisEqual; axis equal; end
        axis tight
        axis ij  % reverse axis (2.)
        % colorbar...
        if SWITCH.Colorbar(1,1)
            cb=colorbar;
            if constColorbar
                set(gca,'clim',[ColorbarMIN,ColorbarMAX])
            else
                set(gca,'clim',cb.Limits)
            end
            if strcmp(FIELD.name,'deformation mechanism');
                set(cb,'Ticks',[1,2,3,4],'TickLabels',{'diff. creep','disl. creep','plasticity','cut-off'});
            else
                title(cb,CBtitle_plot); %on top
                %ylabel(cb,CBtitle_plot); %on left hand side
            end
        end
        % texting...
        if SWITCH.title
            if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
                htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
            else
                htitle = title(title_plot); %centered
            end
            if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.loop_case,:)); end
        end
        xlabel(xlabel_plot)
        ylabel(ylabel_plot)
    end
    
    % ---- cylindrical-cylindrical plot ---------------------------------
    z2d_nd(:,:)  = GRID.Z_3Dndnf(:,1,:);
    var2d_S = var2d;
    addOneRow = logical(1);  % add one row for nicer visualization
    if addOneRow
        x2d_nd(end+1,:)     = x2d_nd(1,:);
        y2d_nd(end+1,:)     = y2d_nd(1,:);
        z2d_nd(end+1,:)     = z2d_nd(1,:);
        var2d_S(end+1,:)    = var2d_S(1,:);
    end
    % Transform coordinates for cylindrical grid
    % This needs to be in non-dimensional form (i.e., 0-1)
    R       = z2d_nd+GRID.rcmb_nd; %[nd]
    x2d_S   = R.*-sin(x2d_nd); %.*cos(y2d_nd);
    %         y2d_S   = R.*cos(x2d_nd).*sin(y2d_nd);
    z2d_S   = R.*-cos(x2d_nd);
    if addOneRow %remove it again
        x2d_nd(end,:)     = [];
        y2d_nd(end,:)     = [];
        z2d_nd(end,:)     = [];
    end
    %Dimensionalisation
    x2d_S 	= x2d_S.*GRID.dimFactor;
    %y2d_S   = y2d_S.*GRID.dimFactor;
    z2d_S 	= z2d_S.*GRID.dimFactor;

    figure(1)
    axes(AXcurrent);
    xlabel_plot = ['x [',GRID.Xdim,']'];
    ylabel_plot = ['z [',GRID.Zdim,']'];
    %plotting...
    if strcmp(PLOT.Style,'contour')
        if strcmp(FIELD.name,'streamfunction'); plotLineColor=PLOT.streamColor; else plotLineColor='none'; end
        contourf(x2d_S,z2d_S,var2d_S,PLOT.numContours,'LineColor',plotLineColor)
    elseif strcmp(PLOT.Style,'pcolor')
        sp=pcolor(x2d_S,z2d_S,var2d_S); set(sp,'edgecolor','none');
        shading interp
    end
    if FIELD.save || logical(0) %save current field
        f_saveField(x2d_S,1,z2d_S,var2d_S,FIELD,FILE,SAVE);
    end
    %plot bot CMB and top air line
    hold on
    hcmb = plot(x2d_S(:,1,end),z2d_S(:,1,end),'Color',keyColor,'LineWidth',0.25);
    hold on
    hair = plot(x2d_S(:,1,1),z2d_S(:,1,1),'Color',keyColor,'LineWidth',0.25);
    %axes...
    if SWITCH.axisEqual; axis equal; end
    axis tight
    set(gca,'color','none') %remove background color
    if SWITCH.axis_off
        axis off
    end
    % colorbar...
    if SWITCH.Colorbar(1,1)
        cb=colorbar;
        if constColorbar
            set(gca,'clim',[ColorbarMIN,ColorbarMAX])
        else
            set(gca,'clim',cb.Limits)
        end
        if strcmp(FIELD.name,'deformation mechanism');
            set(cb,'Ticks',[1,2,3,4],'TickLabels',{'diff. creep','disl. creep','plasticity','cut-off'});
        else
            title(cb,CBtitle_plot); %on top
            %ylabel(cb,CBtitle_plot); %on left hand side
        end
    end
    % texting...
    if SWITCH.title
        if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
            htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
        else
            htitle = title(title_plot); %centered
        end
        if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.loop_case,:)); end
    end
    xlabel(xlabel_plot); ylabel(ylabel_plot);
    text(0.0,0.0,[num2str(nx),'x',num2str(nz)],'Color',keyColor,'FontName',STYLE.AllFontName,...
        'HorizontalAlignment','center')
    
    if SWITCH.texting %display min/max values
        display(['   ',FIELD.name,' variation: ',num2str(min(var2d_S(:)),4),' <-> ',num2str(max(var2d_S(:)),4),' ',FIELD.dim])
    end
    
    
elseif strcmp(GRID.Type,'yinyang')
    
    add_streamline = logical(0); %not tested yet...................
    
    trackPlumes = SWITCH.trackPlumes;
    AXorig  = gca; %axis of big plot (needs to be changed later on for yy)
    
    if strcmp(SWITCH.yyPlotMode,'mapOnSphere')
        PLOT.yyNumSlices = 1; %multiple slices not possible with spherical plot
    end
    
    %% GET SLICING DEPTH-LEVELS
    gp_z    = size(GRID.X_3D,3);         % # grid points in z-direction    
    znumV = zeros(1,size(PLOT.yyZlevelV,2));
    for i_zlevel=1:size(PLOT.yyZlevelV,2)
        [~,idx]                     = min(abs(GRID.Z_3Dnd(1,1,:)-PLOT.yyZlevelV(1,i_zlevel))); %index of closest value
        PLOT.yyZlevelV(1,i_zlevel)	= GRID.Z_3Dnd(1,1,idx); %set to closest grid value
        znumV(1,i_zlevel)           = idx;  %index of z-level
    end
    if strcmp(SWITCH.yyPlotMode,'isosurface') || trackPlumes %read out complete data
        znumVall(1,1:gp_z)   = 1:gp_z;
    end
    
    %% SCALAR FIELDS
    ayy = zeros(size(VARyin,1),size(VARyin,2),2);
    nth = size(ayy,1); nph=nth*3; nthmap=2*nth; nphmap=(4*nph)/3;
    if ~strcmp(field_string,'horizontal velocity') && ~strcmp(field_string,'radial velocity') %scalar field
        if strcmp(field_string,'topography') %TOPOGRAPHY
            if strcmp(SWITCH.yyPlotMode,'isosurface'); error('Topography plot for YY-isosurface not implemented yet!'); end
            if cmb_topo; i_topo=1; else i_topo=2; end
            display(['topo mean: ',num2str(mean(mean(VARyin(:,:,i_topo)))+mean(mean(VARyang(:,:,i_topo))))])
            ayy(:,:,1) = VARyin(:,:,i_topo);
            ayy(:,:,2) = VARyang(:,:,i_topo);
            if topo_smooth
                filterSize = 5;
                %F = [.05 .1 .05; .1 .4 .1; .05 .1 .05]; %filter
                %F = [1/9 1/9 1/9; 1/9 1/9 1/9; 1/9 1/9 1/9]; %like 2-D filter - with one loop!
                F = fspecial('gaussian',filterSize); %filterSize is the size of matrix
                %F = fspecial('gaussian');
                
                %add ghost points to prevent side effects from smoothing
                dummy = ayy;
                for ii=1:filterSize
                    dummy = [dummy(1,:,:); dummy; dummy(end,:,:)]; %CHECK IF CORRECT ..................
                    dummy = [dummy(:,1,:), dummy, dummy(:,end,:)];
                end
                %smoothing
                for jj=1:17
                    ayy_smooth = conv2(dummy(:,:,1),F,'same');
                    dummy(:,:,1) = ayy_smooth(:,:,1);
                    ayy_smooth = conv2(dummy(:,:,2),F,'same');
                    dummy(:,:,2) = ayy_smooth(:,:,2);
                end
                %remove ghostpoints
                ayy_smooth = dummy(filterSize+1:end-filterSize,filterSize+1:end-filterSize,:);
                ayy = ayy_smooth;
            end
            [amap(:,:,1),theta,phi] = f_YYtoMap(ayy);
            
        else %OTHER
            amap = zeros(nthmap,nphmap,size(znumV,2));
            for i_zlevel=1:size(znumV,2)  %loop through the different depth slices
                ayy(:,:,1) = VARyin(:,:,znumV(1,i_zlevel));
                ayy(:,:,2) = VARyang(:,:,znumV(1,i_zlevel));
                [amap(:,:,i_zlevel),theta,phi] = f_YYtoMap(ayy);
                clearvars ayy
            end
            if trackPlumes %convert all the T-data
                ayy = zeros(size(PLOT.T_3Dyin,1),size(PLOT.T_3Dyin,2),2);
                pmap = zeros(nthmap,nphmap,size(znumVall,2));
                for i_zlevel=1:size(znumVall,2)  %loop through the different depth slices
                    ayy(:,:,1) = PLOT.T_3Dyin(:,:,znumVall(1,i_zlevel));
                    ayy(:,:,2) = PLOT.T_3Dyang(:,:,znumVall(1,i_zlevel));
                    [pmap(:,:,i_zlevel),~,~] = f_YYtoMap(ayy);
                    clearvars ayy
                end
            end
            if strcmp(SWITCH.yyPlotMode,'isosurface') %convert all the data
                ayy = zeros(size(VARyin,1),size(VARyin,2),2);
                amap = zeros(nthmap,nphmap,size(znumVall,2));
                for i_zlevel=1:size(znumVall,2)  %loop through the different depth slices
                    ayy(:,:,1) = VARyin(:,:,znumVall(1,i_zlevel));
                    ayy(:,:,2) = VARyang(:,:,znumVall(1,i_zlevel));
                    [amap(:,:,i_zlevel),~,~] = f_YYtoMap(ayy);
                    clearvars ayy
                end
            end
        end
    end
    if SWITCH.waitbar; waitbar(0.5,PLOT.wb); end
    
    %% SETTING SWITCHES
    %quiver switch
    if strcmp(field_string,'temperature')  && quiver_T || ... %for quiver addition
            strcmp(field_string,'viscosity')    && quiver_eta || ...
            strcmp(field_string,'stress')       && quiver_str || ...
            strcmp(field_string,'strain rate')  && quiver_edot || ...
            strcmp(field_string,'density')      && quiver_rho || ...
            strcmp(field_string,'streamfunction') && quiver_psi || ...
            strcmp(field_string,'zz-stress component') && quiver_nstr
        add_quiver = true;
    else
        add_quiver = false;
    end
    %streamfunction switch
    if strcmp(field_string,'temperature')  && streamfun_T || ... %for streamfun addition
            strcmp(field_string,'viscosity')    && streamfun_eta || ...
            strcmp(field_string,'stress')       && streamfun_str || ...
            strcmp(field_string,'strain rate')  && streamfun_edot || ...
            strcmp(field_string,'density')      && streamfun_rho || ...
            (strcmp(field_string,'velocity') || strcmp(field_string,'horizontal velocity') || strcmp(field_string,'radial velocity')) && streamfun_v
        add_streamfun = true;
    else
        add_streamfun = false;
    end
    
    %% VECTOR FIELDS
    if strcmp(field_string,'horizontal velocity') || strcmp(field_string,'radial velocity') || strcmp(field_string,'streamfunction') || ... %VECTOR FIELD
            add_streamfun || add_quiver %or quiver/streamfunction addition
        
        % Transform coordinates for Yin & Yang grids        %<<< MAYBE DO THAT IN STAGplot.m AND SAVE TO GLOBAL GRID VARIABLE.................
        R  = GRID.Z_3Dnd+GRID.rcmb_nd;     lat = pi/4-GRID.X_3Dnd;     lon = GRID.Y_3Dnd-3*pi/4;
        XS_1 = R.*cos(lat).*cos(lon); %Yin
        YS_1 = R.*cos(lat).*sin(lon);
        ZS_1 = R.*sin(lat);
        XS_2 = -XS_1; %Yang
        YS_2 =  ZS_1;
        ZS_2 =  YS_1;
        
        % Transform velocities, if needed
        Vtheta = VX_3D_yin; Vphi = VY_3D_yin; Vr = VZ_3D_yin;            	% on Yin grid
        VX_3D_1 =  Vtheta.*sin(lat).*cos(lon) - Vphi.*sin(lon) + Vr.*cos(lat).*cos(lon);
        VY_3D_1 =  Vtheta.*sin(lat).*sin(lon) + Vphi.*cos(lon) + Vr.*cos(lat).*sin(lon);
        VZ_3D_1 = -Vtheta.*cos(lat)                            + Vr.*sin(lat);
        Vtheta = VX_3D_yang; Vphi = VY_3D_yang; Vr = VZ_3D_yang;        	% on Yang grid
        VX_3D_2 = -( Vtheta.*sin(lat).*cos(lon) - Vphi.*sin(lon) + Vr.*cos(lat).*cos(lon) );
        VZ_3D_2 =  Vtheta.*sin(lat).*sin(lon) + Vphi.*cos(lon) + Vr.*cos(lat).*sin(lon);
        VY_3D_2 = -Vtheta.*cos(lat)                            + Vr.*sin(lat);
        
        %conversion to spherical coordinates
        lat1    = atan2(sqrt(XS_1.^2 + YS_1.^2),ZS_1);  % cos-1 (z/r)
        long1   = atan2(YS_1,XS_1);  % tan-1 (y/x)
        lat2    = atan2(sqrt(XS_2.^2 + YS_2.^2),ZS_2);  % cos-1 (z/r)
        long2   = atan2(YS_2,XS_2);  % tan-1 (y/x)
        
        Vlat1   = VX_3D_1.*(cos(long1).*cos(lat1)) + VY_3D_1.*(sin(long1).*cos(lat1)) - VZ_3D_1.*(sin(lat1));
        Vlong1	= -VX_3D_1.*(sin(long1)) + VY_3D_1.*(cos(long1));
        Vlat2   = VX_3D_2.*(cos(long2).*cos(lat2)) + VY_3D_2.*(sin(long2).*cos(lat2)) - VZ_3D_2.*(sin(lat2));
        Vlong2  = -VX_3D_2.*(sin(long2)) + VY_3D_2.*(cos(long2));
        
        nth = size(VX_3D_yin,1); nph=nth*3; nthmap=2*nth; nphmap=(4*nph)/3;
        Vtheta_map = zeros(nthmap,nphmap,size(znumV,2));
        Vphi_map = Vtheta_map;
        Vr_map = Vtheta_map;
        for i_zlevel=1:size(znumV,2)  %loop through the different depth slices
            VXyy(:,:,1) = Vlat1(:,:,znumV(1,i_zlevel)); % Yin  grid data
            VXyy(:,:,2) = Vlat2(:,:,znumV(1,i_zlevel)); % Yang grid data
            [Vtheta_map(:,:,i_zlevel),~,~ ]   = f_YYtoMap(VXyy);
            
            VYyy(:,:,1) = Vlong1(:,:,znumV(1,i_zlevel)); % Yin  grid data
            VYyy(:,:,2) = Vlong2(:,:,znumV(1,i_zlevel)); % Yang grid data
            %             [Vphi_map(:,:,i_zlevel),~ ,~ ]   = f_YYtoMap(VYyy);
            [Vphi_map(:,:,i_zlevel),~,~ ]   = f_YYtoMap(VYyy); %use this for old matlab version
            
            VZyy(:,:,1) = VZ_3D_1(:,:,znumV(1,i_zlevel)); % Yin  grid data
            VZyy(:,:,2) = VZ_3D_2(:,:,znumV(1,i_zlevel)); % Yang grid data
            %             [Vr_map(:,:,i_zlevel),~ ,~ ]   = f_YYtoMap(VZyy);
            [Vr_map(:,:,i_zlevel),theta,phi ]   = f_YYtoMap(VZyy); %use this for old matlab version
        end
        
        %         Vphi_map is horizontal velocity
        %         Vtheta_map is vertical velocity
        
        if strcmp(field_string,'streamfunction') || add_streamfun %add_streamfunction
            %adjust latitude range
            if SWITCH.yyFlipVertical
                if exist('Vtheta_map','var')
                    Vtheta_mapSTREAM = -Vtheta_map;
                end
            end
            
            phi2d_1 = zeros(size(Vphi_map,1),size(Vphi_map,2),size(znumV,2));
            psi2d_1 = phi2d_1;
            for i_zlevel=1:size(znumV,2)
                [phi2d_1(:,:,i_zlevel),psi2d_1(:,:,i_zlevel)] = flowfun(Vphi_map(:,:,i_zlevel),Vtheta_mapSTREAM(:,:,i_zlevel));  % calculate the velocity potential (phi) and streamfunction (psi)
                %                 [phi2d_2(:,:,i_zlevel),psi2d_2(:,:,i_zlevel)] = flowfun(Vlat2(:,:,z_num_V(1,i_zlevel)),Vlong2(:,:,z_num_V(1,i_zlevel)));
            end
            if strcmp(stream_data,'phi'); stream2d(:,:,:)=phi2d_1;   %phi2d_1;
            elseif strcmp(stream_data,'psi'); stream2d(:,:,:)=psi2d_1; end
            
            if strcmp(field_string,'streamfunction')
                for i_zlevel=1:size(znumV,2)  %loop through the different depth slices
                    %                     ayy(:,:,1) = VAR_3D_yin(:,:,z_num_V(1,i_zlevel));
                    %                     ayy(:,:,2) = VAR_3D_yang(:,:,z_num_V(1,i_zlevel));
                    %                     [amap(:,:,i_zlevel),theta,phi] = f_YYtoMap(ayy);
                    
                    amap(:,:,i_zlevel) = stream2d(:,:,i_zlevel);
                    
                    figure(11),clf
                    subplot(2,2,1)
                    pcolor(Vtheta_mapSTREAM(:,:,i_zlevel))
                    subplot(2,2,2)
                    pcolor(Vphi_map(:,:,i_zlevel))
                    subplot(2,2,4)
                    pcolor(amap(:,:,i_zlevel))
                    figure(1)
                end
            end
        end
    end
    
    %for velocity plots
    if strcmp(field_string,'horizontal velocity') && ~strcmp(field_string,'radial velocity'); Vr_map = 0*Vr_map; end  %zeroing vertical component
    if strcmp(field_string,'horizontal velocity'); amap = Vtheta_map; end
    %     if plotVelocityY; amap = Vphi_map; end
    if strcmp(field_string,'radial velocity'); amap = Vr_map; end
    
    %% calculate RESIDUAL TEMPERATURE FIELD
    if strcmp(field_string,'residual temperature') %FOR HORIZONTAL RESIDUAL TEMPERATURE FIELD
        for z_level2=1:size(amap,3)
            %sumBoth = nansum(nansum( amap(:,:,z_level2) )); %summing up T values
            numNaN = sum(sum(isnan( amap(:,:,z_level2) ))); %count NaN's  (not really needed, just to be sure...)
            %numBoth = (size( amap(:,:,z_level2),1)*size(VAR_3D_yin(:,:,z_level2),2)) - numNaN; %number of T values
            %horizMeanBoth = sumBoth / numBoth;          %horizonatl mean
            
            horizMeanBoth       = mean2(amap(:,:,z_level2));    %horizontal mean temperature
            amap(:,:,z_level2)  = amap(:,:,z_level2) - horizMeanBoth;  %residual temperature
        end
    end
    if trackPlumes  %FOR PLUMES RESIDUAL TEMPERATURE FIELD
        PLUMES = zeros(size(pmap));
        for z_level2=1:size(pmap,3)
            horizMeanBoth       = mean2(pmap(:,:,z_level2));    %horizontal mean temperature
            pmap(:,:,z_level2)  = pmap(:,:,z_level2) - horizMeanBoth;  %residual temperature
            horizMean_Tres      = mean2(pmap(:,:,z_level2));    %horizontal mean Tres
            
            if trackPlumes
                horizMax    = max(max(pmap(:,:,z_level2)));     %horizontal max Tres
                horizMin    = min(min(pmap(:,:,z_level2)));     %horizontal min Tres
                
                thrHot      = horizMean_Tres + PLOT.pHot*(horizMax-horizMean_Tres);     %after Labrosse (EPSL,2002)
                thrCold     = horizMean_Tres + PLOT.pCold*(horizMin-horizMean_Tres);    %after Labrosse (EPSL,2002)
                
                plumes      = zeros(size(pmap(:,:,z_level2)));	%no plumes
                plumes(find(pmap(:,:,z_level2)>thrHot))	= 1;  	%hot plumes
                plumes(find(pmap(:,:,z_level2)<thrCold)) = -1; 	%cold plumes
                
                PLUMES(:,:,z_level2) = plumes;
            end
        end
    end
    
    %% GRID ADJUSTMENTS
    %conversions to degrees
    theta	= rad2deg(theta);
    phi     = rad2deg(phi);
    %adjust latitude range
    if SWITCH.yyFlipVertical
        theta = -theta+90; %convert to -90-90 instead of 0-180  %CORRECT NORTHENING
        if exist('Vtheta_map','var')
            Vtheta_map = -Vtheta_map;
        end
    else
        theta = theta-90; %convert to -90-90 instead of 0-180  %CORRECT NORTHENING
    end
    
    %% TRACK PLUMES
    if trackPlumes
        plot3D_plumes               = logical(1);
        f_INPUT.plotPLUMES      	= plot3D_plumes;%plot comparison of all anomalies and selected plumes
        f_INPUT.addFactor           = 0.25;         %percent of total x-extend that is added at x=1 and x=end  (should be exponent of 2)
        
        f_INPUT.topThreshold_HOT 	= 0.5;          %top threshold; percentage of nz (0: top, 1: bottom)   ...incl. sticky air!
        f_INPUT.botThreshold_HOT	= 0.9;          %top threshold; percentage of nz (0: top, 1: bottom)
        f_INPUT.topThreshold_COLD	= 0.2;          %top threshold; percentage of nz (0: top, 1: bottom)   ...incl. sticky air!
        f_INPUT.botThreshold_COLD	= 0.4;          %top threshold; percentage of nz (0: top, 1: bottom)
        
        [PLUMEShot,PLUMEScold] = f_trackPlumes(PLUMES,f_INPUT);
        figure(1)  %go back to figure(1)
    end
    
    %% REMOVING DATA POINTS
    if strcmp(field_string,'velocity') && add_quiver && ~add_streamline
        theta_V = theta;
        phi_V = phi;
        %remove some data points
        count=0;
        for ir=size(Vtheta_map,1):-1:1
            count = count+1;
            if count==quiver_numDel
                count = 0;
            else
                theta_V(ir,:) = [];
                Vtheta_map(ir,:,:) = [];
                Vphi_map(ir,:,:) = [];
            end
        end
        for jr=size(Vtheta_map,2)-1:-1:2
            count = count+1;
            if count==quiver_numDel
                count = 0;
            else
                phi_V(jr,:) = [];
                Vtheta_map(:,jr,:) = [];
                Vphi_map(:,jr,:) = [];
            end
        end
    end
    if SWITCH.waitbar; waitbar(0.6,PLOT.wb); end
    
    %% PLOTTING
    if strcmp(SWITCH.yyPlotMode,'map') && PLOT.yyNumSlices>1
        figure(1), clf %<<<<<<<<<  ONLY USED FOR MULTIPLE SLICES PER SUBPLOT
    end
    if SWITCH.waitbar
        display('   ...plotting')
        PLOT.wb = waitbar(0.6,PLOT.wb,'plotting...');
    end
    if strcmp(SWITCH.yyPlotMode,'isosurface')
        %CONVERT TO CARTESIAN COORDINATES    
        r           = GRID.Z_3Dndnf+GRID.rcmb_nd;
        r2d(:,1)    = r(1,1,:);
%         phi = phi+abs(min(phi));
%         theta = theta+abs(min(theta));
        [phiM,thetaM,rM]    = meshgrid(deg2rad(phi),deg2rad(theta),r2d); %has to be in radians and from 0:360 and 0:180!!!
        [x,y,z]             = sph2cart(phiM(:),thetaM(:),rM(:));

        amap2       = amap(:);
        
        %reducing data size
        isoval = 1100;
        range = 20;
        dummy = amap2>(isoval+range);
        x(dummy) = [];
        y(dummy) = [];
        amap2(dummy) = [];
        dummy = amap2<(isoval-range);
        x(dummy) = [];
        y(dummy) = [];
        z(dummy) = [];
        amap2(dummy) = [];
        
        %create and interpolate onto regular meshgrid
        x_min = min(x(:)); x_max = max(x(:));
        y_min = min(y(:)); y_max = max(y(:));
        z_min = min(z(:)); z_max = max(z(:));
        x_size = size(phiM,1);
        y_size = size(phiM,2);
        z_size = size(phiM,3);
        dx = (x_max-x_min)/(x_size-1);  %just make grid fine enough
        dy = (y_max-y_min)/(y_size-1);  %just make grid fine enough
        dz = (z_max-z_min)/(z_size-1);  %just make grid fine enough
        fac = 1; %reducing size
        dx = dx*fac;
        dy = dy*fac;
        dz = dz*fac;
        
        [Xq,Yq,Zq] = meshgrid(x_min:dx:x_max,y_min:dy:y_max,z_min:dz:z_max);
        
        display('    [grid interpolation: this may take a while...]')
        amap_int = griddata(x,y,z,amap2,Xq,Yq,Zq); %%%slow
        
        isosurface(Xq,Yq,Zq,amap_int,isoval)
        
        axis equal off vis3d
        lighting phong
        camlight('right')

            

        
    elseif strcmp(SWITCH.yyPlotMode,'map') || strcmp(SWITCH.yyPlotMode,'mapOnSphere')
        for i_slice=1:PLOT.yyNumSlices
            if SWITCH.waitbar; waitbar(0.6+i_slice/PLOT.yyNumSlices*0.2,PLOT.wb); end
            z_num               = znumV(i_slice);           %grid number
            z_shift             = (i_slice-1)/4;
            z_level             = PLOT.yyZlevelV(i_slice);	%non-dim depth
            z_level_dim         = z_level*GRID.dimFactor; 	%dim depth [whatever]
            
            %set position:
            if i_slice>1; hold on; end
            if PLOT.yyNumSlices==1
                %nothing to be done
            elseif PLOT.yyNumSlices==2;  hax = axes('Position', [0.04, 0.07+z_shift*1.7, 0.8, 0.5]);
            elseif PLOT.yyNumSlices==3;  hax = axes('Position', [0.07, 0.1+z_shift, 0.75, 0.3]);
            elseif PLOT.yyNumSlices==4;  hax = axes('Position', [0.04, 0.07+z_shift*0.85, 0.75, 0.3]);
            else error('fc: check here!');
            end
            if i_slice>1 && PLOT.onlyBotPlumes; trackPlumes = logical(0); end
            
            %switches
            if strcmp(STYLE.colorMode,'white')
                LabelColor1         = keyColor-0.2;
                gridColor           = [1 1 1];
                backgroundColorm 	= 'w';
            else
                LabelColor1         = keyColor+0.2;
                gridColor           = [1 1 1];
                backgroundColorm 	= 'k';
            end
            axisVisibility   	= 'off';
            if strcmp(SWITCH.yyPlotMode,'map')
                SetFrame          	= 'on';
                
                if strcmp(STYLE.colorMode,'black'); gridColor = 1-gridColor; end
                LabelParallel = SWITCH.yyLabelParallel;  if i_slice>1; LabelParallel='off'; end
                haxm = axesm ('mollweid', 'Frame',SetFrame,'FLineWidth',0.25, ...
                    'Grid', 'on','GColor',gridColor,'GLineStyle','-','GLineWidth',0.1, ...
                    'MeridianLabel',SWITCH.yyLabelMeridian,'ParallelLabel',LabelParallel,...
                    'PLabelLocation',PLOT.yyPlabelTicks,'PLabelMeridian',PLOT.yyPlabelLocation,'Origin',[0 PLOT.yyOriginLong 0],...
                    'FontName',STYLE.AllFontName,'FontWeight','normal','FontColor',LabelColor1);  %
                if SWITCH.yyLimitMap
                    setm(haxm,'MapLatLimit',[PLOT.yyLimitS PLOT.yyLimitN],'MapLonLimit',[PLOT.yyLimitW PLOT.yyLimitE])
                end
            
                if strcmp(field_string,'streamfunction'); plotLineColor=PLOT.streamColor; else plotLineColor='none'; end
            end
            set(gca,'Color',backgroundColorm,'Visible',axisVisibility)

            %% PLOT MAIN FIELD
            hold on
            if strcmp(SWITCH.yyPlotMode,'map')
                if strcmp(PLOT.Style,'contour')
                    %---------------------------
                    contourfm(theta,phi,amap(:,:,i_slice),PLOT.numContours,'LineColor',plotLineColor)
                    %---------------------------
                elseif strcmp(PLOT.Style,'pcolor')
                    %---------------------------
                    sp = pcolorm(theta,phi,amap(:,:,i_slice)); set(sp,'EdgeColor','none');
                    %---------------------------
                else
                    error('fabio: unknown PLOT.Style!')
                end
                
            elseif strcmp(SWITCH.yyPlotMode,'mapOnSphere')
                Rmax        = max(GRID.Z_3Dp(:))+GRID.rcmb_p; %dimensional radius of planet [whatever]
                Rcurrent    = Rmax-z_level; %radius of slice [whatever]
                [phiM,thetaM,rM]    = meshgrid(deg2rad(phi),deg2rad(theta),Rcurrent); %has to be in radians and from 0:360 and 0:180!!!
                [x,y,z]             = sph2cart(phiM,thetaM,rM);
                %---------------------------
                sp = surf(x,y,z,amap(:,:,i_slice),'EdgeColor','none');
                %---------------------------
                axis([-Rcurrent,Rcurrent,-Rcurrent,Rcurrent,-Rcurrent,Rcurrent]) %keep axis constant and hence, make sphere smaller
                axis equal vis3d
                lighting phong
                camlight('right')
            end
            
            if PLOT.yyNumSlices>1 && i_slice==1 %for multiple slices
                p = get(gca,'Position');
                if strcmp(SWITCH.CB_Pos,'bottom')
                    cb=colorbar('horiz');
                    set(cb,'Position',[0.4 0.04 0.2 0.017]);
                elseif strcmp(SWITCH.CB_Pos,'right')
                    cb=colorbar;
                    set(cb,'Position',[p(1)+p(3) 0.17 0.017 0.164]);
                elseif strcmp(SWITCH.CB_Pos,'southeast')
                    cb=colorbar('horiz');
                    set(cb,'Position',[0.73 0.12 0.17 0.014]);
                end
            end
            if constColorbar; set(gca,'clim',[FIELD.cColorbarMIN,FIELD.cColorbarMAX]); end
            
            %% COLORMAP
            PLOT.hax = gca; %<<<<<<<<<<< some of it is done later on, but only for last axis...
            [SWITCH] = f_colormap(SWITCH,PLOT);
            
            if SWITCH.yyOnlyTopQuiver; if i_slice~=4; add_quiver=0; else add_quiver=1; end; end
            if SWITCH.yyOnlyBotQuiver; if i_slice==1; add_quiver=1; else add_quiver=0; end; end
            if add_quiver
                if i_slice==4
                    arrowScale1 = arrowScale; %3
                elseif i_slice==3
                    arrowScale1 = 2;
                elseif i_slice==2
                    arrowScale1 = 1;
                elseif i_slice==1
                    arrowScale1 = 1;
                else
                    error('check this line!!! fc')
                end
                %                 arrowScale1 = 0; %no scaling, all same length
                hold on
                [phi2,theta2] = meshgrid(phi_V,theta_V);
                q1 = quiverm(theta2,phi2,Vtheta_map(:,:,i_slice),Vphi_map(:,:,i_slice),'k',arrowScale1);
                set(q1,'Color',PLOT.quiverColor,'LineWidth',PLOT.quiverWidth)
            end
            
            %% STREAM LINES
            if add_streamline
                hold on
                [phi2,theta2] = meshgrid(phi_V,theta_V);
                %             [s1,s2] = meshgrid( phi2(:,10),theta2(:,10));     %starting points
                s1=phi2(5,10);
                s2=theta2(5,10);
                [sx,sy]=meshgrid(s1,s2);
                streamline(theta2,phi2,Vtheta_map(:,:,i_slice),Vphi_map(:,:,i_slice),sx,sy)
            end
            
            %% TRACK PLUMES
            if trackPlumes
                if strcmp(SWITCH.yyPlotMode,'mapOnSphere')
                    error('plumes not yet implemented for mapOnSphere option!')
                end
                numberPlumes = logical(0); %labels every connected plume area (on the 2-D map area) with a number; saved in PLUMEShot_nr + PLUMEScold_nr
                if numberPlumes
                    PLUMEShot_large(:,:) = PLUMEShot(:,:,z_num);
                    PLUMEScold_large(:,:) = PLUMEScold(:,:,z_num);
                    add_factor  = 1; %1 means 1 additional total field at each edge
                    nx_org      = size(PLUMEShot,2);
                    nx_add      = nx_org*add_factor;
                    PLUMEShot_large  = [PLUMEShot_large(:,(end-nx_add+1):end)   PLUMEShot_large   PLUMEShot_large(:,1:nx_add)]; %increase size
                    PLUMEScold_large = [PLUMEScold_large(:,(end-nx_add+1):end)  PLUMEScold_large  PLUMEScold_large(:,1:nx_add)];
                    PLUMEShot_large_nr(:,:)     = bwlabel(PLUMEShot_large(:,:), 8); %number plumes
                    PLUMEScold_large_nr(:,:)    = bwlabel(PLUMEScold_large(:,:), 8);
                    PLUMEShot_large_nr 	= PLUMEShot_large_nr(:,(nx_add+1):end-nx_add,:); %decrease size
                    PLUMEScold_large_nr	= PLUMEScold_large_nr(:,(nx_add+1):end-nx_add,:);
                    PLUMEShot_nr(:,:,i_slice)     = PLUMEShot_large_nr; %read in matrix to save
                    PLUMEScold_nr(:,:,i_slice)    = PLUMEScold_large_nr;
                    clearvars PLUMEShot_large PLUMEScold_large PLUMEShot_large_nr PLUMEScold_large_nr
                    %                figure(31),clf
                    %                subplot(2,1,1); contourfm(theta,phi,PLUMEShot_nr(:,:,i_slice),numContours);
                    %                subplot(2,1,2); contourfm(theta,phi,PLUMEScold_nr(:,:,i_slice),numContours);
                end
                hold on
                h_hot = contourm(theta,phi,PLUMEShot(:,:,z_num),PLOT.numContours,'LineColor',PLOT.plumeColorHot);
                hold on
                h_cold = contourm(theta,phi,PLUMEScold(:,:,z_num),PLOT.numContours,'LineColor',PLOT.plumeColorCold);
            end
            %     shading interp
            
            %% COLORBAR
            if SWITCH.Colorbar(1,1)
                cb=colorbar;
                if constColorbar
                    set(gca,'clim',[ColorbarMIN,ColorbarMAX])
                else
                    if SWITCH.MversionSupported; set(gca,'clim',cb.Limits); end %only for newer versions
                end
                %label colorbar ticks if needed:
                if strcmp(FIELD.name,'deformation mechanism');
                    set(cb,'Ticks',[1,2,3,4],'TickLabels',{'diff. creep','disl. creep','plasticity','cut-off'});
                else
                    title(cb,CBtitle_plot); %on top
                    %ylabel(cb,CBtitle_plot); %on left hand side
                end
            end
            
            %% TITLE
            axisXlim = get(gca,'Xlim');
            axisYlim = get(gca,'Ylim');
            if SWITCH.title && i_slice==PLOT.yyNumSlices
                titlePos = [axisXlim(1)+(axisXlim(2)-axisXlim(1))/2, max(axisYlim)]; %centered
                if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
                    htitle = text(titlePos,{title_plot{1,1}{1,1},title_plot{1,1}{1,2}},'HorizontalAlignment','center','VerticalAlignment','top');
                else
                    htitle = text(titlePos(1),titlePos(2),title_plot,'HorizontalAlignment','center','VerticalAlignment','bottom');
                end
                set(htitle,'FontName',STYLE.AllFontName,'FontSize',13,'Color',LabelColor1);
                if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.loop_case,:)); end
            end
            
            %% TEXTING
            if SWITCH.texting %display min/max values
                display(['   ',FIELD.name,' variation: ',num2str(min(min(amap(:,:,i_slice))),4),' <-> ',num2str(max(max(amap(:,:,i_slice))),4),' ',FIELD.dim])
            end
            
            %% DEPTH ANNOTATION
            if PLOT.yyAnnDepth && ~strcmp(FIELD.name,'topography')
                if PLOT.yyNumSlices>1 %multiple slices
                    tx = text(1.75, -1.2,['z = ',num2str(z_level_dim,4),' km']); %top right
                    set(tx,'FontName',STYLE.AllFontName,'FontSize',14,'Color',LabelColor1);
                else
                    tx = text(axisXlim(2)/2, axisYlim(1)*0.65,['z = ',num2str(z_level_dim,4),' km']); %top right
                    set(tx,'FontName',STYLE.AllFontName,'FontSize',STYLE.keyFontSize+1,'Color',LabelColor1);
                end
                if PLOT.yyNumSlices>1 %multiple slices
                    %create text background
                    set(gca,'XLimMode', 'manual', 'YLimMode', 'manual'); % prevent the axes from resizing automatically ???
                    p = get(tx,'Extent'); %Get the outer position of the text
                    % now create a  patch around the text object
                    p(1) = p(1)/2;
                    p(3) = p(3)+p(1)+0.1;
                    pObj = patch([p(1) p(1) p(1)+p(3) p(1)+p(3)], [p(2) p(2)+p(4) p(2)+p(4) p(2)],...
                        [0.85 0.85 0.85],'EdgeColor','none',...
                        'FaceAlpha',0.8,'Clipping','off');
                    uistack(pObj,'bottom')
                end
                clearvars tx
            end
            
            %% PATCH AREA
            if logical(0)
                % now create a  patch at the bottom
                p(1) = 0;           p(3) = 2*pi;
                p(2) = -pi/2;       p(4) = pi;
                pObj = patch([p(1) p(1) p(1)+p(3) p(1)+p(3)], [p(2) p(2)+p(4) p(2)+p(4) p(2)],...
                    [0.85 0.85 0.85],'EdgeColor','none',...
                    'FaceAlpha',0.8);
                uistack(pObj,'bottom')
            end
            
            %% SOME STYLING
            set(gca,'Color',LabelColor1,'FontSize',12)
        end
    end
    
    %% SMALL DEPTH GRAPH
    if PLOT.yyDepthGraph && PLOT.yyNumSlices==1 && ~strcmp(field_string,'topography')
        haxD = axes('Position', [0.05, 0.8, 0.04, 0.17]);
        plot([0 1],[z_level_dim z_level_dim],'Color',[0.0 0.0 0.0],'LineWidth',1.5)
        
        axis ij
        ylabel(['depth [',GRID.Zdim,']'])
        axis([0 1 min(GRID.Z_3Dp(:)) max(GRID.Z_3Dp(:))])
        box on
        %         set(cla,'XTick',[])  %lscht auch den graph....
        set(gca,'XTickLabel','','XTick',[],'xColor','w','yColor',[0.5 0.5 0.5])
        axes(PLOT.hax); %re-activate main axis
    end
    
    %% SAVING PLUME DATA
    if trackPlumes && SWITCH.savePLUMES  %saves output variable
        display('   ...saving')
        
        SaveDirectory = [FILE.stem_im,FILE.name,'/+plumes/'];
        if ~exist(SaveDirectory,'dir'); mkdir(SaveDirectory); end
        Figure_Name = ['op_',FILE.name,'_',num2str(FILE.number)];
        if SWITCH.dim || SWITCH.dimensional_input; Figure_Name = ['opDIM_',FILE.name,'_',num2str(FILE.number)]; end
        dirF = pwd; cd(SaveDirectory)
        save([Figure_Name,'.mat'],'PLUMES')
        cd(dirF)
    end
    
    AXorig  = gca; %axis of big plot
    
else
    error('unknown grid type!')
end %grid type    





%_____________________________________________________________________________________________________________________

if strcmp(GRID.Type,'yinyang') && PLOT.yyNumSlices>1
    %nothing to be done for multiple yy-slices
else
    %% SPECIFY COLORMAP FOR CURRENT AXES
    AXhandles(1) = AXorig;  %big plot axis handle
    if exist('haxZ','var');
        AXhandles(2) = haxZ; %zoom plot axis handle
        loop_zoom = 2;
    else
        loop_zoom = 1;
    end
    PLOT.cb      = cb;      % colorbar handle
    for izoom=1:loop_zoom
        if ~PLOT.multipleColormap && izoom>1; continue; end
        PLOT.hax = AXhandles(izoom);
        
        [SWITCH] = f_colormap(SWITCH,PLOT);
    end
end

if ~strcmp(GRID.Type,'yinyang') %this is all done above for yy-cases
    %% GRID PLOT
    if SWITCH.plotgrid && strcmp(field_string,'viscosity') %&& nr_subplot==1  %plotting grid
        %add to plot
        figure(1)
        hold on
        plot(x2d,z2d,'k',x2d',z2d','k')
        %seperate plot
        figure(3)
        plot(x2d,z2d,'k',x2d',z2d','k')
        xlabel(['x [',GRID.Xdim,']']); ylabel(['y [',GRID.Xdim,']']);
        if SWITCH.axisEqual; axis equal; end
        axis tight; axis ij
        figure(1) %return to fig 1
    end
    
    %% AXIS LIMIT BIG PLOT
    if SWITCH.setAxisLimit
        if size(SWITCH.axisLimit,1)>1  %individual axes values
            axis(SWITCH.axisLimit(PLOT.loop_case,:));
        else %all plots the same
            axis(SWITCH.axisLimit);
        end
    end
    
end
%_____________________________________________________________________________________________________________________





%==========================================================================
%% STREAMFUNCTION
%==========================================================================
if (strcmp(field_string,'temperature') && streamfun_T) || ...
        (strcmp(field_string,'viscosity') && streamfun_eta) || ...
        (strcmp(field_string,'stress') && streamfun_str) || ...
        ((strcmp(field_string,'velocity') || strcmp(field_string,'horizontal velocity') || strcmp(field_string,'radial velocity')) ...
        && streamfun_v) || ...
        (strcmp(field_string,'strain rate') && streamfun_edot) || ...
        (strcmp(field_string,'density') && streamfun_rho) && ...
        ~strcmp(GRID.Type,'yinyang') % plot streamfunction
    
    if strcmp(GRID.Dim,'3-D')
        error('fc: 3-D streamfunction not implemented! - Switch it off!')
    else %2-D
        %Read velocity information
        [~,~,~,~,VX_3D,VY_3D,VZ_3D,~,~] = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'velocity', SWITCH.Precision);
            
        if strcmp(GRID.Type,'cartesian')
            if PLOT.YZ_2Dcartesian; %exchange x and y
                dummy_3D = zeros(size(VX_3D,2),size(VX_3D,1),size(VX_3D,3));
                dummy_3Dx = zeros(size(VX_3D,2),size(VX_3D,1),size(VX_3D,3));
                dummy_3D(:,1,:)     = VZ_3D(1,:,:); VZ_3D = dummy_3D;
                dummy_3Dx(:,1,:)    = VX_3D(1,:,:);
                dummy_3D(:,1,:)     = VY_3D(1,:,:); VY_3D = dummy_3Dx; VX_3D = dummy_3D;
            end
            if strcmp(GRID.Dim,'3-D')
            elseif strcmp(GRID.Dim,'2-D')
                vx2d(:,:)   = VX_3D(:,1,:);
                vy2d(:,:)   = VY_3D(:,1,:);
                vz2d(:,:)   = VZ_3D(:,1,:);
            end
            vz2d = -vz2d;  % reverse y-axis  (1.)
            [phi2d,psi2d] = flowfun(vx2d,vz2d);  % calculate the velocity potential (phi) and streamfunction (psi)
            %plotting grid variables:
            x2d_plot2 = x2d_plot;
            z2d_plot2 = z2d_plot;
            
        elseif strcmp(GRID.Type,'cylindrical')
            if max(VX_3D(:))==0 %exchange x and y
                dummy_3D = VX_3D;
                VX_3D = VY_3D; VY_3D = dummy_3D;
            elseif max(VX_3D(:))~=0 && max(VY_3D(:))==0
            else
                error('both VX_3D and VY_3D appear to be zero: check here!')
            end
            vx2d = zeros(nx,nz);
            vy2d = zeros(nx,nz); %JUST TO BE DEFINED
            vz2d = zeros(nx,nz);
            vx2d(:,:) = VX_3D(1,:,:);
            vz2d(:,:) = VZ_3D(1,:,:);
            
            % conversion to cylindrical grid
            VX_S = vx2d; VZ_S = vz2d;
            X_S = x2d_nd;
            
            [phi2d,psi2d] = flowfun(VX_S,-VZ_S);  % calculate the velocity potential (phi) and streamfunction (psi)

            %             vx2d    = VX_S.*cos(X_S)+VZ_S.*sin(X_S);
            %             vz2d    = -VX_S.*sin(X_S)+VZ_S.*cos(X_S);
            vx2d    = -VX_S.*cos(X_S)+VZ_S.*sin(X_S);
            vz2d    = VX_S.*sin(X_S)-VZ_S.*cos(X_S);
            %VZ_S = -VZ_S; %reverse axis for cylindrical-cartesian plot %not needed here
            
            %for plotting the correct grid variables
            x2d_plot2 = x2d_S;
            z2d_plot2 = z2d_S;
            if addOneRow
                vx2d(end+1,:)    = vx2d(1,:);
                vz2d(end+1,:)    = vz2d(1,:);
                phi2d(end+1,:)    = phi2d(1,:);
                psi2d(end+1,:)    = psi2d(1,:);
            end
        end
    end
    if strcmp(stream_data,'phi'); var2d = phi2d; elseif strcmp(stream_data,'psi'); var2d = psi2d; else error('fc: unknown stream data'); end
    
    loop_zoom = 1;
    if isfield(PLOT,'zoom') && PLOT.zoom
        loop_zoom = 2;
    end
    for izoom=1:loop_zoom
        if izoom==1; axes(AXcurrent); else axes(haxZ); end
        hold on
        if strcmp(PLOT.streamColoured,'false')
            hstr = contour(x2d_plot2,z2d_plot2,var2d,stream_numContours,...
                'LineColor',PLOT.streamColor,'LineWidth',PLOT.streamWidth);
            
        else %DOESN'T WORK PROPERLY ANYLONGER.. MIGHT REMOVE.
            caxis('manual');  %fix the colorbar scale (old style)
            for iizoom=1:loop_zoom; 
                if iizoom==1; axes(AXcurrent); else axes(haxZ); end 
                freezeColors;
                if izoom==1; axes(AXcurrent); else axes(haxZ); end
            end
            %if self-made colorbar:
            if size(PLOT.streamColoured,1)==1 && exist([PLOT.streamColoured,'.mat'],'file')==2
                load([PLOT.streamColoured,'.mat']); PLOT.streamColoured=eval( sprintf(PLOT.streamColoured) ); %load colorbar
            end
            %adjust colormap for streamfunction
            dummy = SWITCH.ColormapAll;
            SWITCH.ColormapAll = {PLOT.streamColoured 'noflip'};
            [SWITCH] = f_colormap(SWITCH,PLOT);
            SWITCH.ColormapAll = dummy;
            %colormap(PLOT.streamColoured);
            contour(x2d_plot2,z2d_plot2,var2d,stream_numContours);
            
            cval_max=max( abs(min(min(var2d))),abs(max(max(var2d))) );
            if constColorbar; set(gca,'clim',[-cval_max,cval_max]); end
            %colorbar
            for iizoom=1:loop_zoom; 
                if iizoom==1; axes(AXcurrent); else axes(haxZ); end 
                freezeColors;
                if izoom==1; axes(AXcurrent); else axes(haxZ); end
            end
            %back to original:
            if strcmp(SWITCH.ColormapAll{1,2},'flip'); colormap(flipud(SWITCH.ColormapAll{1,1}));
            elseif strcmp(SWITCH.ColormapAll{1,2},'noflip'); colormap(SWITCH.ColormapAll{1,1}); end
            if SWITCH.Colorbar(1,1); 
                if izoom==1; 
                    cb=colorbar; 
                    title(cb,CBtitle_plot); %on top
                    %ylabel(cb,CBtitle_plot); %on left hand side
                end
                if constColorbar; set(gca,'clim',[ColorbarMIN,ColorbarMAX]); end
            end
        end
        hold off
    end
    axes(AXcurrent)
end



%==========================================================================
%% STREAM LINES
%==========================================================================
if streamline_plot || ...
        (strcmp(field_string,'temperature') && streamline_T) || ...
        (strcmp(field_string,'viscosity') && streamline_eta) || ...
        (strcmp(field_string,'stress') && streamline_str) && ...
        ~strcmp(GRID.Type,'yinyang') % plot streamlines
    
    if strcmp(GRID.Type,'cartesian')
        % Read pressure & velocity information
        [~,X_3D,Y_3D,Z_3D,VX_3D,VY_3D,VZ_3D,~,~] = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,'velocity',SWITCH.Precision);
        if PLOT.YZ_2Dcartesian; %exchange x and y
            dummy_3D = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
            dummy_3Dx = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
            dummy_3D(:,1,:)     = VZ_3D(1,:,:); VZ_3D = dummy_3D;
            dummy_3Dx(:,1,:)    = VX_3D(1,:,:);
            dummy_3D(:,1,:)     = VY_3D(1,:,:); VY_3D = dummy_3Dx; VX_3D = dummy_3D;
            dummy_3D(:,1,:)     = Z_3D(1,:,:); Z_3D = dummy_3D;
        end
        if strcmp(GRID.Dim,'3-D')
        elseif strcmp(GRID.Dim,'2-D')
            x2d(:,:) 	= X_3D(:,1,:);
            y2d         = 1; % just in order to have it defined
            z2d(:,:)    = Z_3D(:,1,:);
            vx2d(:,:)   = VX_3D(:,1,:);
            vy2d(:,:)   = VY_3D(:,1,:);
            vz2d(:,:)   = VZ_3D(:,1,:);
        end
        %--------------------------------
        z2d = 1.0-z2d;  % reverse y-axis  (1.)
        vz2d = -vz2d;
        if SWITCH.actualDepth
            z2d = z2d-d_air;  %set z=0 to real surface
        end
        %--------------------------------
    elseif strcmp(GRID.Type,'cylindrical')
        error('fc: cylindrical streamline not yet implemented...')
    end
    if SWITCH.dim
        x2d = x2d*SETUP.D_dim /1e3;  %[km]
        y2d = y2d*SETUP.D_dim /1e3;  %[km]
        z2d = z2d*SETUP.D_dim /1e3;  %[km]
    end
    if (streamline_plot && nr_subplot==1) || streamline_T || streamline_eta || streamline_str
        sx2d = sx2d.*max(x2d(:));  %convert <0-1> values to actual values of x and z
        sz2d = sz2d.*max(z2d(:));
        step_factor = 4; %!might need to be adjusted if not working!
        sxline = [sx2d(1,1):(x2d(2,1)-x2d(1,1))*step_factor:sx2d(1,2)];
        if size(sxline,2)==1
            szline = [sz2d(1,1):(z2d(1,1)-z2d(1,2))*step_factor:sz2d(1,2)];
        else
            szline = [sz2d(1,1):sz2d(1,2)/size(sxline,2):sz2d(1,2)]; %must have the same size than sxline
        end
        if size(sxline,2)==1; sxline=ones(1,size(szline,2))*sxline; end %in case of vertical lines
        if size(szline,2)==1; szline=ones(1,size(sxline,2))*szline; end %in case of horizontal lines
    end
    if streamline_T || streamline_eta || streamline_str
        figure(1)
        if strcmp(GRID.Dim,'3-D')
            hold on
            hs=streamline(y2d(1,:,1),x2d(:,1,1),z2d(1,1,:),vy2d',vx2d',vz2d',sy2d,sx2d,sz2d);
        elseif strcmp(GRID.Dim,'2-D')  % 2-D
            subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3))
            hold on 
            hs=streamline(x2d(:,1),z2d(1,:),vx2d',vz2d',sxline,szline);
        end
        set(hs,'Color',PLOT.streamColor)  %,'LineWidth',1
        hold off
    end
    if streamline_plot && nr_subplot==1
        figure(4); hold on;
        hs=streamline(x2d(:,1),z2d(1,:),vx2d',vz2d',sxline,szline);
        set(hs,'Color',PLOT.streamColor)
        if SWITCH.axisEqual; axis equal; end
        if strcmp(GRID.Type,'cartesian')
            axis tight
            %---------------------
            axis ij  % reverse axis (2.)
            %---------------------
            xlabel(['width [',GRID.Xdim,']'])
            ylabel(['depth [',GRID.Zdim,']'])
        end
        if PLOT.time_dim/1e6>100
            title(['streamline @ ',num2str(PLOT.time_dim/1e9,3),' Gyrs'])
        else
            title(['streamline @ ',num2str(PLOT.time_dim/1e6,3),' Myrs'])
        end
    end
end


%==========================================================================
%% DEFORMATION MECHANISM
%==========================================================================
if (strcmp(field_string,'temperature') && defmech_T) || ...
        (strcmp(field_string,'viscosity') && defmech_eta) || ...
        (strcmp(field_string,'stress') && defmech_str) || ...
        (strcmp(field_string,'strain rate') && defmech_edot) && ...
        ~strcmp(GRID.Type,'yinyang') % plot deformation mechanism
    
    if strcmp(GRID.Type,'cartesian')
        % Read pressure & velocity information
        [~,~,~,~,VAR_3D,~,~]     = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,'deformation mechanism',SWITCH.Precision);
        if PLOT.YZ_2Dcartesian; %exchange x and y
            dummy_3D = zeros(size(VAR_3D,2),size(VAR_3D,1),size(VAR_3D,3));
            dummy_3D(:,1,:)     = VAR_3D(1,:,:); VAR_3D = dummy_3D;
        end
        if strcmp(GRID.Dim,'3-D')
        elseif strcmp(GRID.Dim,'2-D')
            defm2d(:,:)  = VAR_3D(:,1,:);
            %make sure values are the exact numbers they should be down to 0.00x:
            defm2d(:,:)  = round(defm2d*1e3)/1e3;
            
            if defm2d(2,2)==1 && defm2d(3,2)==4 %check for artificial values
                defm2d(2,2) = defm2d(4,2);  %and remove them
                defm2d(3,2) = defm2d(4,2);
            end
        end
    elseif strcmp(GRID.Type,'cylindrical')
        error('fc: cylindrical defmormation mechanism plot not yet implemented...')
    end
    
%     figure(1)
%     subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3))
%     hold on
    
    loop_zoom = 1;
    if isfield(PLOT,'zoom') && PLOT.zoom
        loop_zoom = 2;
    end
    for izoom=1:loop_zoom
        if izoom==1; axes(AXcurrent); else axes(haxZ); end
        hold on
        
        caxis('manual') %fix the colorbar scale
        for i_cont = 1:size(defmech_contours,2) 
            %1: diffusion creep, 2: dislocation creep, 3: plasticity, 4: visc. cutoff
            var2d_defm = zeros(size(defm2d));
            if defmech_contours(i_cont)==1 %diffusion creep
                var2d_defm(defm2d<2) = 1;
            elseif defmech_contours(i_cont)==1.1  %1/10 dislocation creep
                var2d_defm(defm2d>=1.1 & defm2d<=2) = 1;
            elseif defmech_contours(i_cont)==1.3  %1/3 dislocation creep
                var2d_defm(defm2d>=1.3 & defm2d<=2) = 1;
            else  %other
                var2d_defm(defm2d==defmech_contours(i_cont)) = 1;  
            end
            if defmech_contours(i_cont)==1 || defmech_contours(i_cont)==2 || ...
                    defmech_contours(i_cont)==3 || defmech_contours(i_cont)==4
                linestyle1 = '-';
            else
                linestyle1 = ':';
            end
            contour(x2d_plot,z2d_plot,var2d_defm,[0.5 0.5],...
                'LineColor',PLOT.defmechColor(i_cont,:), 'LineStyle',linestyle1);
        end
        hold off
    end
    clearvars defm2d var2d_defm
    axes(AXcurrent)
end



%==========================================================================
%% FIELD CONTOUR
%==========================================================================
%ANY FIELD CONTOUR PLOT ADDITION
if (fieldContour_T && strcmp(field_string,'temperature')) || ...
    (fieldContour_eta && strcmp(field_string,'viscosity')) || ...
    (fieldContour_nstr && strcmp(field_string,'zz-stress component')) || ...
    (fieldContour_str && strcmp(field_string,'stress')) || ...
    (fieldContour_edot && strcmp(field_string,'strain rate')) || ...
    (fieldContour_vx && strcmp(field_string,'horizontal velocity')) && ...
    ~strcmp(GRID.Type,'yinyang')

    MarkerSizeContour = 0.5;

    loop_zoom = 1;
    if isfield(PLOT,'zoom') && PLOT.zoom
        loop_zoom = 2;
    end
    for izoom=1:loop_zoom
        if izoom==1; axes(AXcurrent); else axes(haxZ); end
        %read appropriate field
        [~,~,~,~,VAR_3D,~,~]     = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,PLOT.fContourField,SWITCH.Precision);
        if size(VAR_3D,1)==1; %exchange x and y
            dummy_3D = zeros(size(VAR_3D,2),size(VAR_3D,1),size(VAR_3D,3));
            dummy_3D(:,1,:) = VAR_3D(1,:,:); VAR_3D = dummy_3D;
        end
        if strcmp(GRID.Dim,'2-D')
            var2dF(:,:,:)  = VAR_3D(:,:,:);
            if strcmp(GRID.Type,'cylindrical') && addOneRow %add row for nicer visualisation
                    var2dF(end+1,:,:) = var2dF(1,:,:);
            end
        elseif strcmp(GRID.Dim,'3-D')
            error('field contour for 3-D not implemented yet!!!!')
        end
        var2dF = var2dF * FIELD_M{strcmp(FIELD_M(:,2),PLOT.fContourField),5}; %dimensionalize

        %find values below, at & above the contour value
        var2dF(var2dF<fieldContour_isoVal) = 0; %below
        var2dF(var2dF==fieldContour_isoVal) = 1; %at
        var2dF(var2dF>fieldContour_isoVal) = 2; %above
        
        %find contour (boundary values are not checked!)
        jj=1; iii=0;
        fieldContourLoc = zeros(size(var2dF,1)*size(var2dF,2)*size(var2dF,3)/2,3)*NaN; %max. possible size/2
        for ii=2:size(var2dF,1)-1
%             for jj=2:size(var2dF,2)-1
                for kk=2:size(var2dF,3)-1
                    if var2dF(ii,jj,kk)==0 && ... %just below contour
                        ( var2dF(ii+1,jj,kk)==2 || var2dF(ii,jj,kk+1)==2 || ...
                        var2dF(ii-1,jj,kk)==2 || var2dF(ii,jj,kk-1)==2 )
                        var2dF(ii,jj,kk) = 1;
                    end
                    if var2dF(ii,jj,kk)==1 %create contour points array
                        iii = iii+1;
                        if strcmp(GRID.Type,'cartesian')
                            fieldContourLoc(iii,:) = [GRID.X_3D(ii,jj,kk) GRID.Y_3D(ii,jj,kk) GRID.Z_3D(ii,jj,kk)];
                        elseif strcmp(GRID.Type,'cylindrical')
                            fieldContourLoc(iii,:) = [x2d_S(ii,kk) 1 z2d_S(ii,kk)];
                        end
                    end
                end
%             end
        end
        
        % FIND PLATE THICKNESS AND SLAB TIP
        findSlabTip = logical(0);
        findPlateThickness = logical(0);
        if findPlateThickness || findSlabTip
            if strcmp(GRID.Type,'cylindrical'); error('might not work for cylindrical grid, yet: Check!'); end
            fieldContourLoc(isnan(fieldContourLoc(:,1)),:) = []; %in [m]
            
            % PLATE THICKNESS
            % find depth value slightly deeper than LAB
            plateContourA = fieldContourLoc(fieldContourLoc(:,3)<=mean(fieldContourLoc(:,3)),:); %remove most of slab values
            plateContourA(plateContourA<0) = 0; %set negative values to zero to use geomean
            
            %         plateThicknessMean1 = harmmean(plateContourA(:,3)); %find most probable plate thickness harmonic mean
            plateThicknessMean2 = geomean(plateContourA(:,3));
            if PLOT.loop_field==1; display(['   > mean plate thickness is ',num2str(plateThicknessMean2/1e3),' km']); end
            %         plateThicknessMean3 = mean(plateContourA(:,3));
            
            %         figure(2)
            %         plot(fieldContourLoc(:,3)/1e3,'.')
            %         hold on
            %         plot(plateContourA(:,3)/1e3,'.r')
            %         hold on
            %         plot(plateThicknessMean1/1e3*ones(size(fieldContourLoc(:,3))),'k')
            %         hold on
            %         plot(plateThicknessMean2/1e3*ones(size(fieldContourLoc(:,3))),'g')
            %         hold on
            %         plot(plateThicknessMean3/1e3*ones(size(fieldContourLoc(:,3))),'y')
            
            % SLAB TIP
            % find depth value at slab tip
%             slabtipContourA = fieldContourLoc(fieldContourLoc(:,3)<=mean(fieldContourLoc(:,3)),:); %derive slab values
            
            %sort for depth (deepest first):
            [slabtipContourA,sortIndex] = sort(fieldContourLoc(:,3),'descend');
            %extract only the x% points that lie deepest
            x_percent = 0.05;
            slabtipContourA = fieldContourLoc(sortIndex(1:round(size(sortIndex,1)*x_percent),1),:);
            % geometric mean of the slab tip area
            slabtipCentreA  = [geomean(slabtipContourA(:,1))    geomean(slabtipContourA(:,3))];
            slabtipBottomA  = [slabtipContourA(1,1)             slabtipContourA(1,3)];
            slabtipLeftA    = [min(slabtipContourA(:,1))        max(slabtipContourA(slabtipContourA(:,1)==(min(slabtipContourA(:,1))),3))];
            slabtipRightA   = [max(slabtipContourA(:,1))        max(slabtipContourA(slabtipContourA(:,1)==(max(slabtipContourA(:,1))),3))];
            
            %             figure(2)
            %             plot(fieldContourLoc(:,1),fieldContourLoc(:,3),'.')
            %             hold on
            %             plot(slabtipContourA(:,1),slabtipContourA(:,3),'.r')
            %             plot(slabtipCentreA(:,1),slabtipCentreA(:,2),'ro')
            %             plot(slabtipBottomA(:,1),slabtipBottomA(:,2),'go')
            %             plot(slabtipLeftA(:,1),slabtipLeftA(:,2),'go')
            %             plot(slabtipRightA(:,1),slabtipRightA(:,2),'ro')
            
            defineSlabTipAutomatically = logical(1);
            if defineSlabTipAutomatically
                figure(1)
                hold on
                %!! ASSUMPTION !!: if x-left is further away from x-centre than x-right - then right hand side subduction
                if abs(slabtipCentreA(:,1)-slabtipLeftA(:,1)) == abs(slabtipCentreA(:,1)-slabtipRightA(:,1)) %DOWN
                    if PLOT.loop_field==1; display('   > Vertical subduction detected'); end
                    slabtipLocA = slabtipLeftA;
                    if PLOT.loop_field==1; display(['   >    slab tip bottom: [',num2str(slabtipBottomA(:,1)/1e3,4),',',num2str(slabtipBottomA(:,2)/1e3,4),'] km']); end
                elseif abs(slabtipCentreA(:,1)-slabtipLeftA(:,1)) > abs(slabtipCentreA(:,1)-slabtipRightA(:,1)) %RIGHT
                    if PLOT.loop_field==1; display('   > Right-hand side subduction detected'); end
                    slabtipLocA = slabtipRightA;
                    if PLOT.loop_field==1; display(['   >    slab tip right:  [',num2str(slabtipRightA(:,1)/1e3,4),',',num2str(slabtipRightA(:,2)/1e3,4),'] km']); end
                else                                                                                            %LEFT
                    if PLOT.loop_field==1; display('   > Left-hand side subduction detected'); end
                    slabtipLocA = slabtipLeftA;
                    if PLOT.loop_field==1; display(['   >    slab tip left:   [',num2str(slabtipLeftA(:,1)/1e3,4),',',num2str(slabtipLeftA(:,2)/1e3,4),'] km']); end
                end
                plot(slabtipLocA(:,1)/1e3,slabtipLocA(:,2)/1e3,'x','Color',TOPO.lineColor,...
                    'MarkerSize',6,'MarkerFaceColor',TOPO.lineColor);
                hold off
                
                %write to data file
                SAVE.datafile = logical(0);
                if SAVE.datafile && PLOT.loop_field==1 %only once per time step
                    SAVE.DataName               = 'slabTip_timeXZ';
                    SAVE.Directory              = [FILE.stem_im,FILE.name,'/'];
                    SAVE.data                   = [FILE.number PLOT.time slabtipLocA]; % output file - time - x - z
                    SAVE.write2existing         = logical(0);
                    SAVE.txt                    = logical(1);
                    SAVE.mat                    = logical(1);
                    
                    f_saveDat( SAVE );
                end
                
            else
                if PLOT.loop_field==1; display(['   > slab tip centre: [',num2str(slabtipCentreA(:,1)/1e3,4),',',num2str(slabtipCentreA(:,2)/1e3,4),'] km']); end
                if PLOT.loop_field==1; display(['   > slab tip bottom: [',num2str(slabtipBottomA(:,1)/1e3,4),',',num2str(slabtipBottomA(:,2)/1e3,4),'] km']); end
                if PLOT.loop_field==1; display(['   > slab tip left:   [',num2str(slabtipLeftA(:,1)/1e3,4),',',num2str(slabtipLeftA(:,2)/1e3,4),'] km']); end
                if PLOT.loop_field==1; display(['   > slab tip right:  [',num2str(slabtipRightA(:,1)/1e3,4),',',num2str(slabtipRightA(:,2)/1e3,4),'] km']); end
                figure(1)
                hold on
                plot(slabtipCentreA(:,1)/1e3,slabtipCentreA(:,2)/1e3,'x','Color',TOPO.lineColor,...
                    'MarkerSize',6,'MarkerFaceColor',TOPO.lineColor);
                plot(slabtipBottomA(:,1)/1e3,slabtipBottomA(:,2)/1e3,'x','Color',TOPO.lineColor,...
                    'MarkerSize',6,'MarkerFaceColor',TOPO.lineColor);
                plot(slabtipLeftA(:,1)/1e3,slabtipLeftA(:,2)/1e3,'x','Color',TOPO.lineColor,...
                    'MarkerSize',6,'MarkerFaceColor',TOPO.lineColor);
                plot(slabtipRightA(:,1)/1e3,slabtipRightA(:,2)/1e3,'x','Color',TOPO.lineColor,...
                    'MarkerSize',6,'MarkerFaceColor',TOPO.lineColor);
                hold off
            end
        end
        
        figure(1)
        hold on
        if strcmp(GRID.Dim,'3-D')
            error('fc: Field contour option not yet implemented in 3-D/for cylindrical!')
        elseif strcmp(GRID.Dim,'2-D')           
            if strcmp(GRID.Type,'cartesian')
                plot(GRID.X_3D(var2dF==1)/1e3,GRID.Z_3D(var2dF==1)/1e3,'o','Color',TOPO.lineColor,...
                    'MarkerSize',MarkerSizeContour,'MarkerFaceColor',TOPO.lineColor,'LineWidth',TOPO.lineWidth);
            elseif strcmp(GRID.Type,'cylindrical')
                plot(x2d_S(var2dF(:,1,:)==1),z2d_S(var2dF(:,1,:)==1),'o','Color',TOPO.lineColor,...
                    'MarkerSize',MarkerSizeContour,'MarkerFaceColor',TOPO.lineColor,'LineWidth',TOPO.lineWidth);
            end
        end
        hold off
    end
    clearvars var2dF z2dF in
    axes(AXcurrent)
end



%==========================================================================
%% QUIVER
%========================================================================== 
if quiver_plot || ...
        (strcmp(field_string,'temperature') && quiver_T) || ...
        (strcmp(field_string,'viscosity') && quiver_eta) || ...
        (strcmp(field_string,'stress') && quiver_str) || ...
        (strcmp(field_string,'streamfunction') && quiver_psi) || ...
        (strcmp(field_string,'zz-stress component') && quiver_nstr) || ...
        (strcmp(field_string,'strain rate') && quiver_edot) || ...
        (strcmp(field_string,'density') && quiver_rho) && ...
        ~strcmp(GRID.Type,'yinyang')% plot velocity arrows

    if strcmp(GRID.Type,'cartesian')
        if plate_velocity
            quiver_numDel	= 6;
            scale  	= 20;
        end
        % Read pressure & velocity information
        [~,~,~,~,VX_3D,VY_3D,VZ_3D,~,~] = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,'velocity',SWITCH.Precision);
        X_3D = GRID.X_3Dp;
        Y_3D = GRID.Y_3Dp;
        Z_3D = GRID.Z_3Dp;
        if PLOT.YZ_2Dcartesian; %exchange x and y
            dummy_3D = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
            dummy_3Dx = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
            dummy_3D(:,1,:)     = VZ_3D(1,:,:); VZ_3D = dummy_3D;
            dummy_3Dx(:,1,:)    = VX_3D(1,:,:);
            dummy_3D(:,1,:)     = VY_3D(1,:,:); VY_3D = dummy_3Dx; VX_3D = dummy_3D;
        end
        if SWITCH.ReduceSize
            wb = waitbar(0,'Slimming Matrix (quiver)...');
            %reduce size of matrix
            max_gridpoints = 500000;  %500000;   %<--------------------------=================
            if strcmp(GRID.Dim,'3-D')
                max_gridpoints=max_gridpoints/100;
            end
            nx_eff = nx;
            ny_eff = ny;
            nz_eff = nz;
            while (nx_eff*ny_eff*nz_eff)>max_gridpoints
                waitbar(max_gridpoints/(nx_eff*ny_eff*nz_eff),wb)
                for i=(nx_eff-2):-2:2
                    X_3D(i,:,:)     = []; Y_3D(i,:,:)     = []; Z_3D(i,:,:)     = [];
                    VX_3D(i,:,:)   	= []; VY_3D(i,:,:) 	= []; VZ_3D(i,:,:) 	= [];
                end
                for j=(ny_eff-2):-2:2
                    X_3D(:,j,:)     = []; Y_3D(:,j,:)     = []; Z_3D(:,j,:)     = [];
                    VX_3D(:,j,:)   	= []; VY_3D(:,j,:) 	= []; VZ_3D(:,j,:) 	= [];
                end
                for k=(nz_eff-2):-2:2
                    X_3D(:,:,k)     = []; Y_3D(:,:,k)     = []; Z_3D(:,:,k)     = [];
                    VX_3D(:,:,k)   	= []; VY_3D(:,:,k) 	= []; VZ_3D(:,:,k) 	= [];
                end
                X_3D(4,:,:) = []; X_3D(:,4,:) = []; X_3D(:,:,4) = [];
                Y_3D(4,:,:) = []; Y_3D(:,4,:) = []; Y_3D(:,:,4) = [];
                Z_3D(4,:,:) = []; Z_3D(:,4,:) = []; Z_3D(:,:,4) = [];
                VX_3D(4,:,:) = []; VX_3D(:,4,:) = []; VX_3D(:,:,4) = [];
                VY_3D(4,:,:) = []; VY_3D(:,4,:) = []; VY_3D(:,:,4) = [];
                VZ_3D(4,:,:) = []; VZ_3D(:,4,:) = []; VZ_3D(:,:,4) = [];
                nx_eff = size(X_3D,1);
                ny_eff = size(Y_3D,2);
                nz_eff = size(Z_3D,3);
            end
            display(['Size of plotted matrix decreased to ',num2str(size(X_3D))])
            clearvars nx_eff ny_eff nz_eff max_gridpoints
            close(wb)
        end
        if strcmp(GRID.Dim,'3-D')
            x2d2     = X_3D; y2d2     = Y_3D; z2d2     = Z_3D;
            vx2d    = VX_3D; vy2d    = VY_3D; vz2d    = VZ_3D;
        elseif strcmp(GRID.Dim,'2-D')
            x2d2(:,:) = X_3D(:,1,:); z2d2(:,:) = Z_3D(:,1,:); y2d2 = 1; % just in order to have it defined
            vx2d(:,:) = VX_3D(:,1,:); vy2d(:,:) = VY_3D(:,1,:); vz2d(:,:) = VZ_3D(:,1,:);
        end
        vz2d = -vz2d; % for reverse z-axis  (1.)
        
    elseif strcmp(GRID.Type,'cylindrical')
        %******************
        if plate_velocity
            quiver_numDel=10; %(only valid for 2-D)
            scale=5;
        end
        %******************
        % Read velocity information
        [~,~,~,~,VX_3D,VY_3D,VZ_3D,~,~] = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,'velocity',SWITCH.Precision);
        if max(VX_3D(:))==0 %exchange x and y
            dummy_3D = VX_3D;
            VX_3D = VY_3D; VY_3D = dummy_3D;
        elseif max(VX_3D(:))~=0 && max(VY_3D(:))==0
        else
            error('both VX_3D and VY_3D appear to be zero: check here!')
        end
        vx2d = zeros(nx,nz);
        vy2d = zeros(nx,nz); %JUST TO BE DEFINED
        vz2d = zeros(nx,nz);
        vx2d(:,:) = VX_3D(1,:,:);
        vz2d(:,:) = VZ_3D(1,:,:);
        % conversion to cylindrical grid
        VX_S = vx2d; VZ_S = vz2d; %this is for cylindrical-cartesian plot
        X_S = x2d_nd;
        %             vx2d    = VX_S.*cos(X_S)+VZ_S.*sin(X_S);
        %             vz2d    = -VX_S.*sin(X_S)+VZ_S.*cos(X_S);
        vx2d    = -VX_S.*cos(X_S)+VZ_S.*sin(X_S);
        vz2d    = VX_S.*sin(X_S)-VZ_S.*cos(X_S);
        VZ_S = -VZ_S; %reverse axis for cylindrical-cartesian plot
    end
    if strcmp(GRID.Dim,'3-D')   % reduce number of velocity arrows  (3-D)
        count=0;
        nn=size(x2d2,1)-1;
        for i=2:1:nn-1
            if count==2
                count=0.;
            else
                x2d2(i,:) = NaN; vx2d(i,:) = NaN;
            end
            count=count+1;
        end        
        count=0;
        nn=size(x2d2,2)-1;
        for j=2:1:nn-1
            if count==2
                count=0.;
            else
                y2d2(j,:) = NaN; vy2d(j,:) = NaN;
            end
            count=count+1;
        end
        count=0;
        nn=size(x2d2,3)-1;
        for k=2:1:nn-1
            if count==2
                count=0.;
            else
                z2d2(k,:) = NaN; vz2d(k,:) = NaN;
            end
            count=count+1;
        end
    elseif strcmp(GRID.Dim,'2-D') % reduce number of velocity arrows  (2-D)
        if strcmp(GRID.Type,'cylindrical')
            X_Sreduced = X_S; x2d_Sreduced = x2d_S; z2d_Sreduced = z2d_S;
        elseif strcmp(GRID.Type,'cartesian')
            %just to have them defined
            X_Sreduced = zeros(size(x2d2));
            x2d_Sreduced = zeros(size(x2d2)); z2d_Sreduced = zeros(size(x2d2));
        end
        %reduce in x-direction
        count=0;
        nn=nx-1;
        if strcmp(GRID.Type,'cartesian')
            M2reduce=ones(size(x2d2));
        elseif strcmp(GRID.Type,'cylindrical')
            M2reduce=ones(size(X_Sreduced));
        end
        for i=2:1:nn-1
            if count==quiver_numDel
                count=0.;
            else
                M2reduce(i,:) = NaN;
            end
            count=count+1;
        end
        %remove arrows in sticky-air layer
        if strcmp(SETUP.topBC,'sticky-air') && TOPO.area && SWITCH.actualDepth
            if strcmp(GRID.Type,'cartesian')
                idx2remove = find(z2d2(1,:)<0);
                x2d2(:,idx2remove) = NaN; y2d2(:,idx2remove) = NaN; z2d2(:,idx2remove) = NaN;
                vx2d(:,idx2remove) = NaN; vy2d(:,idx2remove) = NaN; vz2d(:,idx2remove) = NaN;
            elseif strcmp(GRID.Type,'cylindrical')
                idx2remove = find(z2d_plot(1,:)<0);
                X_Sreduced(:,idx2remove) = NaN; x2d_Sreduced(:,idx2remove) = NaN; z2d_Sreduced(:,idx2remove) = NaN;
                VX_S(:,idx2remove) = NaN; VZ_S(:,idx2remove) = NaN;
                vx2d(:,idx2remove) = NaN; vy2d(:,idx2remove) = NaN; vz2d(:,idx2remove) = NaN;
            end
        end
        %reduce in z-direction
        count=0;
        nn=nz-1;
        for k=2:1:nn-1
            if count==quiver_numDel
                count=0.;
            else
                M2reduce(:,k) = NaN;
            end
            count=count+1;
        end
        %remove values (i.e., replace them by NaNs)
        if strcmp(GRID.Type,'cartesian')
            x2d2 = x2d2.*M2reduce; z2d2 = z2d2.*M2reduce;
            vx2d = vx2d.*M2reduce; vz2d = vz2d.*M2reduce;
        elseif strcmp(GRID.Type,'cylindrical')
            if addOneRow
                x2d_Sreduced(1,:) = NaN; z2d_Sreduced(1,:) = NaN; %that is the one that gets dublicated
                vx2d(1,:) = NaN; vz2d(1,:) = NaN;
            end
            X_Sreduced = X_Sreduced.*M2reduce; 
            x2d_Sreduced(1:size(M2reduce,1),:) = x2d_Sreduced(1:size(M2reduce,1),:).*M2reduce; %also works if addOneRow
            z2d_Sreduced(1:size(M2reduce,1),:) = z2d_Sreduced(1:size(M2reduce,1),:).*M2reduce;
            vx2d = vx2d.*M2reduce; vz2d = vz2d.*M2reduce;
            VX_S = VX_S.*M2reduce; VZ_S = VZ_S.*M2reduce;
        end
    end
    if plate_velocity  %CAN BE OPTIMIZED.....
        nnx=size(x2d2,1);
        nny=size(x2d2,2);
        nnz=size(x2d2,3);
        for zz=1:nnz  %loop through z direction
            count=0;
            if z2d2(1,1,zz)>0.0 && z2d2(1,1,zz)<30.0  %keep values
                for xx=2:1:nnx-1
                    if count==6
                        count=0;
                    else
                        count=count+1;
                        x2d2(xx,:,zz) = NaN; y2d2(xx,:,zz) = NaN; z2d2(xx,:,zz) = NaN;
                        vx2d(xx,:,zz) = NaN; vy2d(xx,:,zz) = NaN; vz2d(xx,:,zz) = NaN;
                    end
                end
                for yy=2:1:nny-1
                    if count==6
                        count=0;
                    else
                        count=count+1;
                        x2d2(:,yy,zz) = NaN; y2d2(:,yy,zz) = NaN; z2d2(:,yy,zz) = NaN;
                        vx2d(:,yy,zz) = NaN; vy2d(:,yy,zz) = NaN; vz2d(:,yy,zz) = NaN;
                    end
                end
            else  %remove values
                x2d2(:,:,zz) = NaN; y2d2(:,:,zz) = NaN; z2d2(:,:,zz) = NaN;
                vx2d(:,:,zz) = NaN; vy2d(:,:,zz) = NaN; vz2d(:,:,zz) = NaN;
            end
        end
    end
    if strcmp(GRID.Type,'cylindrical')  %for plotting the correct variables
        x2d2 = x2d_Sreduced; %[km]
        z2d2 = z2d_Sreduced;
        if addOneRow
            vx2d(end+1,:)    = vx2d(1,:);
            vz2d(end+1,:)    = vz2d(1,:);
        end
    end
    loop_zoom = 1;
    if isfield(PLOT,'zoom') && PLOT.zoom
        loop_zoom = 2;
    end
    for izoom=1:loop_zoom
        if quiver_T || quiver_eta || quiver_str || quiver_psi || quiver_rho || quiver_nstr || quiver_edot
            figure(1)
            if izoom==1; axes(AXcurrent); else axes(haxZ); end
            xLimits = get(gca,'XLim');  %# Get the range of the x axis
            yLimits = get(gca,'YLim');  %# Get the range of the y axis
            zLimits = get(gca,'ZLim');  %# Get the range of the z axis
            if strcmp(GRID.Dim,'3-D')
                hold on
                quiver3(y2d2,x2d2,z2d2,vy2d,vx2d,vz2d,scale,'Color','k')
                axis([xLimits,yLimits,zLimits])  %make axes extent same as before quiver
            elseif strcmp(GRID.Dim,'2-D')
                hold on
                quiver(x2d2,z2d2,vx2d,vz2d,scale,...
                    'Color',PLOT.quiverColor,'LineWidth',PLOT.quiverWidth)
                %save velocity field =====================================
                if logical(0)
%                     pause
                    T2d = var2d;
                    time_Ga = PLOT.time_dim/1e9;
                    time_Ma = PLOT.time_dim/1e6;
                    save_string = ['/work/collapsing_plume/stagyy140211/+im/test/+output/plume_data',num2str(PLOT.number),'.mat'];
                    save(save_string,'time_Ga','x2d','z2d','vx2d','vz2d','T2d')
                end
                %save velocity field =====================================
                axis([xLimits,yLimits])  %make axes extent same as before quiver
            end
            hold off
            if strcmp(GRID.Type,'cylindrical') && (plotCylCart || SWITCH.me)  %plot also for cylindrical-cartesian plot
                figure(2)
                %subplot(PLOT.nrPlots,1,nr_subplot)
                hold on
                quiver(x2d_C,z2d_C,VX_S,VZ_S,scale,'Color','k')
                hold off
                figure(1) %CHECK IF THAT IS ENOUGH TO GO BACK OR IF AXIS HAS TO BE SPECIFIED!!!!
            end
        end
        if quiver_plot && nr_subplot==1
            figure(4); hold on;
            quiver(x2d,x2d,vx2d,vz2d,scale)
            if SWITCH.axisEqual; axis equal; end
            if strcmp(GRID.Type,'cartesian')
                axis tight
                %---------------------
                axis ij  % reverse axis (2.)
                %---------------------
                xlabel(['width [',GRID.Xdim,']'])
                ylabel(['depth [',GRID.Zdim,']'])
            end
            if PLOT.time_dim/1e6>100
                title(['velocity @ ',num2str(PLOT.time_dim/1e9,3),' Gyrs'])
            else
                title(['velocity @ ',num2str(PLOT.time_dim/1e6,3),' Myrs'])
            end
        end
    end
    axes(AXcurrent)
end  %quiver plot




%==========================================================================
%% LITHOSPHERE THICKNESS
%==========================================================================
%LITHO THICKNESS PLOT ADDITION
if (lithoThickness_T && strcmp(field_string,'temperature')) || ...
    (lithoThickness_eta && strcmp(field_string,'viscosity')) || ...
    (lithoThickness_nstr && strcmp(field_string,'zz-stress component')) && ...
    ~strcmp(GRID.Type,'yinyang')

    loop_zoom = 1;
    if isfield(PLOT,'zoom') && PLOT.zoom
        loop_zoom = 2;
    end
    for izoom=1:loop_zoom
        if izoom==1; axes(AXcurrent); else axes(haxZ); end
        %read appropriate field
%         x2d_plot,z2d_plot,var2d_plot
        [~,~,~,Z_3D,VAR_3D,~,~]     = f_ReadStagYY(FILE.directory,FILE.name,FILE.number,lithoThickness_field,SWITCH.Precision);
        if PLOT.YZ_2Dcartesian; %exchange x and y
            dummy_3D = zeros(size(VAR_3D,2),size(VAR_3D,1),size(VAR_3D,3));
            dummy_3D(:,1,:)     = VAR_3D(1,:,:); VAR_3D = dummy_3D;
            dummy_3D(:,1,:)     = Z_3D(1,:,:); Z_3D = dummy_3D;
        end        
        if strcmp(GRID.Type,'cartesian')
                z2dF(:,:,:)    = Z_3D(:,:,:);
                var2dF(:,:,:)  = VAR_3D(:,:,:);
        else
            error('litho thickness not implemented for cylindrical setup!')
        end
        var2dF = var2dF * FIELD_M{strcmp(FIELD_M(:,2),lithoThickness_field),5}; %dimensionalize
        
        %z2dF = z2dF * FIELD_M.varScale(strcmp(FIELD_M.name,'topography')); %dimensionalize
        if strcmp(GRID.Dim,'2-D')
            z2dF(:,1,:) = z2d_plot(:,:);
        elseif strcmp(GRID.Dim,'3-D')
            error('check here: 3-D not implemented yet!!!!')
        end
        
        %derive lithosphere thickness
        LITHO.Tisovalue = lithoThickness_isoVal;
        LITHO.plot      = false;
        if SWITCH.dim || SWITCH.dimensional_input
            LITHO.zmax      = lithoThickness_zmax; % [km] 
            if ~strcmp(GRID.Xdim,'km'); warning(['f_lithoThickness input should be in [',GRID.Xdim,']!']); end
        else
            LITHO.zmax      = lithoThickness_zmax *1e3*GRID.ndFactor; %from [km] to grid dimensions
        end
        [LITHO] = f_lithoThickness(var2dF,z2dF,LITHO);
        
        lithoIsoline = LITHO.thickness;
        
        figure(1)
        if strcmp(GRID.Dim,'3-D') || strcmp(GRID.Type,'cylindrical')
            error('fc: Litho Thickness option not yet implemented in 3-D!')
        elseif strcmp(GRID.Dim,'2-D')          
            hold on
            plot(x2d_plot,lithoIsoline,'Color',TOPO.lineColor,'LineWidth',TOPO.lineWidth);
        end
        hold off
    end
    axes(AXcurrent)
end


%==========================================================================
%% TOPOGRAPHY
%==========================================================================
%TOPOGRAPHY PLOT ADDITION
if TOPO.field && ~strcmp(GRID.Type,'yinyang')
    loop_zoom = 1;
    if isfield(PLOT,'zoom') && PLOT.zoom
        loop_zoom = 2;
    end
    for izoom=1:loop_zoom
        if izoom==1; axes(AXcurrent); else axes(haxZ); end
        
        if strcmp(SETUP.topBC,'free-slip')
            display('...topo set to zero due to free-slip surface');
            topo2d = 0*TOPO.topo2d; %set topo (derived from zz-stress component) to zero
        else  %sticky air
            topo2d = -TOPO.topo2d;
        end
        
        figure(1)
        if strcmp(GRID.Dim,'2-D') 
            hold on
            if TOPO.area %&& ~strcmp(GRID.Type,'cylindrical')
                %     %*****************************
                xpoints = x2d_plot(:,1)';
                upper = topo2d';
                if strcmp(SETUP.topBC,'free-slip') && SWITCH.setAxisLimit %in case of free slip surface with fixed axes
                    lower = SWITCH.axisLimit(1,3)*ones(size(topo2d,1),1)';
                else
                    if strcmp(GRID.Type,'cartesian')  %for plotting the correct variables
                        lower = min(z2d_plot(:))*ones(size(topo2d,1),1)';
                    elseif strcmp(GRID.Type,'cylindrical')
                        lower = min(z2d_S(:))*ones(size(topo2d,1),1)';
                    end
                end
                if strcmp(GRID.Type,'cartesian')
                    color = TOPO.color;
                    fill([xpoints fliplr(xpoints)],[upper,fliplr(lower)],color,'EdgeColor',color)
                elseif strcmp(GRID.Type,'cylindrical')
                    %topo2d_nd 	= (topo2d+SETUP.D_dim/1e3-SETUP.d_air_dim/1e3) /TOPO.varScale; %non-dimensionalize topography
                    topo2d_nd 	= (topo2d+GRID.dimFactor-SETUP.d_air*GRID.dimFactor) /TOPO.varScale; %non-dimensionalize topography
                    R           = topo2d_nd+GRID.rcmb_nd; %[nd]
                    x2d_ndS     = R.*-sin(x2d_nd(:,1)); %.*cos(y2d_nd(:,1));
                    z2d_ndS  	= R.*-cos(x2d_nd(:,1));
                    upper       = z2d_ndS*TOPO.varScale; %dimensionalize
                    xpoints1    = x2d_ndS*TOPO.varScale; %dimensionalize

                    lower = min(z2d_S(:))*ones(size(topo2d,1),1)';
                    R           = -lower' /TOPO.varScale; %non-dimensionalize topography
                    x2d_ndS     = R.*-sin(x2d_nd(:,1)); %.*cos(y2d_nd(:,1));
                    z2d_ndS  	= R.*-cos(x2d_nd(:,1));
                    lower       = z2d_ndS*TOPO.varScale; %dimensionalize
                    xpoints2    = x2d_ndS*TOPO.varScale; %dimensionalize
            
                    color = TOPO.color;
                    fill([xpoints2;xpoints1],[lower;upper],color,'EdgeColor',color)                
                end
            end
            if TOPO.line
                if strcmp(GRID.Type,'cartesian')
                    x2d_plot2   = x2d_plot;
                elseif strcmp(GRID.Type,'cylindrical')
                    % Transform coordinates for cylindrical grid
                    % This needs to be in non-dimensional form (i.e., 0-1)
                    %topo2d_nd 	= (topo2d+SETUP.D_dim/1e3-SETUP.d_air_dim/1e3) /TOPO.varScale; %non-dimensionalize topography
                    topo2d_nd 	= (topo2d+GRID.dimFactor-SETUP.d_air*GRID.dimFactor) /TOPO.varScale; %non-dimensionalize topography
                    R           = topo2d_nd+GRID.rcmb_nd; %[nd]
                    x2d_ndS     = R.*-sin(x2d_nd(:,1)); %.*cos(y2d_nd(:,1));
                    z2d_ndS  	= R.*-cos(x2d_nd(:,1));
                    topo2d      = z2d_ndS*TOPO.varScale; %dimensionalize
                    x2d_plot2   = x2d_ndS*TOPO.varScale; %dimensionalize
                end
                plot(x2d_plot2,topo2d,'Color',TOPO.lineColor,'LineWidth',TOPO.lineWidth);
            end
            
        elseif strcmp(GRID.Dim,'3-D')
            error('fc: Topography field not yet implemented in 3-D!')
        end
        hold off
    end
    axes(AXcurrent)
end

%==========================================================================
%% INDICATE PLATE BOUNDARIES
%==========================================================================
if PLOT.indicateTrench || PLOT.indicateRidge
    
    % PLOT.SubPolarity can be larger than just one value!!!!.......
    
    if strcmp(GRID.Type,'yingyang'); error('Plate boundary tracking not yet implemented for yinyang mode!'); end
    
    if ~isfield(PLOT,'IndicationDepth');    PLOT.IndicationDepth = -0.0263; end %[nd]
    if ~isfield(PLOT,'IndicationSize');     PLOT.IndicationSize  = 20;  end
    PBmarkerFaceColour = [0 0 0];
    PBmarkerEdgeColour = keyColor;
    if strcmp(STYLE.colorMode,'black')
        PBmarkerFaceColour = 1-PBmarkerFaceColour; %invert colour
    end
    %derive plate boundaries
    if PLOT.loop_field==1
        [TRACK] = f_plateDiagnostics(FILE,GRID,SETUP,SWITCH); %<<<<<<<<
        
        PLOT.IndicationTrench = TRACK.Subduction;
        if isfield(TRACK,'SubPolarity'); PLOT.SubPolarity = TRACK.SubPolarity; end
        if isfield(TRACK,'Spreading'); PLOT.IndicationRidge = TRACK.Spreading; end
    else
        TRACK.Subduction = PLOT.IndicationTrench;
        if isfield(PLOT,'SubPolarity'); TRACK.SubPolarity = PLOT.SubPolarity; end
        if isfield(PLOT,'IndicationRidge'); TRACK.Spreading = PLOT.IndicationRidge; end
    end
    if ~strcmp(TRACK.Subduction,'noTracking')
        loop_zoom = 1;
        if isfield(PLOT,'zoom') && PLOT.zoom
            loop_zoom = 2;
        end
        for izoom=1:loop_zoom
            if izoom==1; axes(AXcurrent); else axes(haxZ); end
            LPcolor             = [0.0 0.0 0.0]; %lower/subducting plate
            UPcolor             = [0.3 0.3 0.3]; %upper plate
            indicationDepth     = PLOT.IndicationDepth *GRID.nd2dim; %[nd]->[whatever]
            hShift4indicationND = 0.06; %set horizontal shift for string [nd]
            hShift4indication   = hShift4indicationND *GRID.nd2dim; %[nd]->[whatever]
            figure(1)
            if strcmp(GRID.Type,'cylindrical')
                % Transform coordinates for cylindrical grid
                % This needs to be in non-dimensional form (i.e., 0-1)
                R = max(GRID.Z_3Dndnf(:))+GRID.rcmb_nd +PLOT.IndicationDepth; %[nd]
                if SWITCH.dim || SWITCH.dimensional_input
                    XSnd_Subduction = TRACK.Subduction ./GRID.dimFactor; %[whatever]->[nd]
                    XSnd_Spreading  = TRACK.Spreading ./GRID.dimFactor; %[whatever]->[nd]
                    if ~SWITCH.dim && SWITCH.dimensional_input
                        warning('plate boundary tracking for non-converted dimensional input not implemented!')
                    end
                else
                    XSnd_Subduction = TRACK.Subduction;
                    XSnd_Spreading  = TRACK.Spreading;
                end
                textLocX0_sub = XSnd_Subduction(:,1); %[nd]
                textLocX0_spr = XSnd_Spreading(:,1); %[nd]
                textLocXLeft0 = XSnd_Subduction(:,1)-hShift4indicationND; %[nd]
                textLocXRight0 = XSnd_Subduction(:,1)+hShift4indicationND; %[nd]

                XS_Subduction = R.*-sin(XSnd_Subduction); ZS_Subduction = R.*-cos(XSnd_Subduction);
                XS_Spreading = R.*-sin(XSnd_Spreading); ZS_Spreading = R.*-cos(XSnd_Spreading);
                textLocX_sub = R.*-sin(textLocX0_sub); textLocZ_sub = R.*-cos(textLocX0_sub);
                textLocX_spr = R.*-sin(textLocX0_spr); textLocZ_spr = R.*-cos(textLocX0_spr);
                textLocXLeft = R.*-sin(textLocXLeft0); textLocZLeft = R.*-cos(textLocXLeft0);
                textLocXRight = R.*-sin(textLocXRight0); textLocZRight = R.*-cos(textLocXRight0);
                anglePosSubduction = rad2deg( -sin(XSnd_Subduction(:,1)) );
                angleHorizontal_sub = rad2deg( -tan(XSnd_Subduction(:,1)) );
                angleHorizontal_spr = rad2deg( -tan(XSnd_Spreading(:,1)) );
                angleHorizontalL = rad2deg( -tan(textLocXLeft0) );
                angleHorizontalR = rad2deg( -tan(textLocXRight0) );
                if SWITCH.dim || SWITCH.dimensional_input
                    XS_Subduction   = XS_Subduction *GRID.nd2dim; %[nd]->[whatever]
                    ZS_Subduction   = ZS_Subduction *GRID.nd2dim; 
                    XS_Spreading    = XS_Spreading *GRID.nd2dim; %[nd]->[whatever]
                    ZS_Spreading    = ZS_Spreading *GRID.nd2dim;
                    textLocX_sub    = textLocX_sub *GRID.nd2dim; %[nd]->[whatever]
                    textLocZ_sub    = textLocZ_sub *GRID.nd2dim;
                    textLocX_spr    = textLocX_spr *GRID.nd2dim; %[nd]->[whatever]
                    textLocZ_spr    = textLocZ_spr *GRID.nd2dim;
                    textLocXLeft    = textLocXLeft *GRID.nd2dim; %[nd]->[whatever]
                    textLocZLeft    = textLocZLeft *GRID.nd2dim;
                    textLocXRight   = textLocXRight *GRID.nd2dim; %[nd]->[whatever]
                    textLocZRight   = textLocZRight *GRID.nd2dim;
                end
                hold on
                if PLOT.indicateTrench %TRENCH INDICATION
                    scatterPlot = logical(0);
                    if scatterPlot
                        scatter(XS_Subduction(:,1),ZS_Subduction(:,1),...
                            PLOT.IndicationSize,'v','fill','MarkerEdgeColor',PBmarkerEdgeColour,...
                            'MarkerFaceColor',PBmarkerFaceColour,'LineWidth',0.2)
                    else
                        for ii=1:size(textLocX_sub,1)
                            if ~isnan(textLocX_sub(ii,1))
                                text(textLocX_sub(ii,1),textLocZ_sub(ii,1),'|',...
                                    'Color',PBmarkerFaceColour,'HorizontalAlignment','center','VerticalAlignment','middle',...
                                    'FontWeight','bold','Rotation',angleHorizontal_sub(ii,1),'FontSize',PLOT.PlateIndSize+2);
                            end
                        end
                    end
                end
                if PLOT.indicateRidge %RIDGE INDICATION
                    scatterPlot = logical(0);
                    if scatterPlot
                        scatter(XS_Spreading(:,1),ZS_Spreading(:,1),...
                            PLOT.IndicationSize,'d','fill','MarkerEdgeColor',PBmarkerEdgeColour,...
                            'MarkerFaceColor',PBmarkerFaceColour,'LineWidth',0.2)
                    else
                        for ii=1:size(textLocX_spr,1)
                            if ~isnan(textLocX_spr(ii,1))
                                text(textLocX_spr(ii,1),textLocZ_spr(ii,1),'|',...
                                    'Color',PBmarkerFaceColour,'HorizontalAlignment','center','VerticalAlignment','middle',...
                                    'FontWeight','bold','Rotation',angleHorizontal_spr(ii,1),'FontSize',PLOT.PlateIndSize+0);
                            end
                        end
                    end
                end
                if PLOT.indicateUpperPlate %UPPER PLATE INDICATION
                    for ii=1:size(TRACK.Subduction,1)
                        if TRACK.SubPolarity(ii,1)=='L' %left-hand side subduction
                            text(textLocXLeft(ii,1),textLocZLeft(ii,1),'UP',...
                                'Color',UPcolor,'HorizontalAlignment','center','VerticalAlignment','middle',...
                                'Rotation',angleHorizontalL(1,1)','FontSize',PLOT.PlateIndSize);
                        elseif TRACK.SubPolarity(ii,1)=='R' %right-hand side subduction
                            text(textLocXRight(ii,1),textLocZRight(ii,1),'UP',...
                                'Color',UPcolor,'HorizontalAlignment','center','VerticalAlignment','middle',...
                                'Rotation',angleHorizontalR(1,1)','FontSize',PLOT.PlateIndSize);
                        else
                            %nothing found
                        end
                    end
                end
                if PLOT.indicateLowerPlate %LOWER PLATE INDICATION
                    for ii=1:size(TRACK.Subduction,1)
                        if TRACK.SubPolarity(ii,1)=='L' %left-hand side subduction
                            text(textLocXRight(ii,1),textLocZRight(ii,1),'LP',...
                                'Color',LPcolor,'HorizontalAlignment','center','VerticalAlignment','middle',...
                                'Rotation',angleHorizontalL(1,1),'FontSize',PLOT.PlateIndSize);
                        elseif TRACK.SubPolarity(ii,1)=='R' %right-hand side subduction
                            text(textLocXLeft(ii,1),textLocZLeft(ii,1),'LP',...
                                'Color',LPcolor,'HorizontalAlignment','center','VerticalAlignment','middle',...
                                'Rotation',angleHorizontalR(1,1)','FontSize',PLOT.PlateIndSize);
                        else
                            %nothing found
                        end
                    end
                end
                
            elseif strcmp(GRID.Type,'cartesian')
                hold on
                AxLim       = axis(gca); %[x1 x2 y1 y2 (z1) (z2)]
                if strcmp(get(gca,'XDir'),'reverse') %account for reverse axes
                    dummy=AxLim(1,2); AxLim(1,2)=AxLim(1,1); AxLim(1,1)=dummy;
                end
                if strcmp(get(gca,'YDir'),'reverse') %account for reverse axes
                    dummy=AxLim(1,4); AxLim(1,4)=AxLim(1,3); AxLim(1,3)=dummy;
                end
                    
                if strcmp(GRID.Dim,'3-D')
                    warning('fc: TRACKING PLATE BOUNDARIES IN 3-D still in beta phase!')
                    
                    if strcmp(get(gca,'ZDir'),'reverse') %account for reverse axes
                        dummy=AxLim(1,6); AxLim(1,6)=AxLim(1,5); AxLim(1,5)=dummy;
                    end
                    indZlevel = 0.1*min(zlim); %indication z-level; e.g., min(zlim)
                    TRACK.BoundariesColored     = logical(0);
                    TRACK.BoundariesEdgeColor   = logical(0);
                    BIndicationAlpha            = 0.5;
                    TriangleHeight      = 0.05 *(max(GRID.Z_3Dp(:))-min(GRID.Z_3Dp(:))); %[whatever]
                    TriangleWidth       = sqrt(4/3*TriangleHeight^2); %gleichschenkliges Dreieck [whatever]
                    if TRACK.BoundariesColored
                        colorBNDRY = [0 0.2 0.4]; colorSPR = [0.4 0.2 0];
                    else
                        colorBNDRY = PBmarkerFaceColour; colorSPR = colorBNDRY;
                    end
                    if TRACK.BoundariesEdgeColor
                        colorBNDRYedge = PBmarkerEdgeColour;
                    else
                        colorBNDRYedge = 'none';
                    end
                    if PLOT.indicateTrench
                        %plot3(TRACK.Subduction(:,2),TRACK.Subduction(:,1),TRACK.Subduction(:,1).*indZlevel,'b')
                        for iarea=1:size(TRACK.Subduction,1)
                            indicateTrenchTriangles = logical(1);
                            if indicateTrenchTriangles
                                for ipoint=1:size(TRACK.SubCenterP,2) %loop only through characteristic points
                                    arPosX = [TRACK.SubCenterP(iarea,ipoint,1)-TRACK.SubStrikeP(iarea,ipoint,1)*TriangleWidth/2,...
                                        TRACK.SubCenterP(iarea,ipoint,1)+TRACK.SubStrikeP(iarea,ipoint,1)*TriangleWidth/2,...
                                        TRACK.SubCenterP(iarea,ipoint,1)+TRACK.LowerPlateP(iarea,ipoint,1)*TriangleHeight]; %left right middle
                                    arPosY = [TRACK.SubCenterP(iarea,ipoint,2)-TRACK.SubStrikeP(iarea,ipoint,2)*TriangleWidth/2,...
                                        TRACK.SubCenterP(iarea,ipoint,2)+TRACK.SubStrikeP(iarea,ipoint,2)*TriangleWidth/2,...
                                        TRACK.SubCenterP(iarea,ipoint,2)+TRACK.LowerPlateP(iarea,ipoint,2)*TriangleHeight]; %left right middle
                                    patch([arPosY(1,1) arPosY(1,2) arPosY(1,3)], ...
                                        [arPosX(1,1) arPosX(1,2) arPosX(1,3)],...
                                        [indZlevel indZlevel indZlevel],...
                                        PBmarkerFaceColour,'FaceAlpha',BIndicationAlpha,...
                                        'EdgeColor',colorBNDRYedge,'LineWidth',0.1); %trench triangles
                                    if PLOT.indicateLowerPlate %LOWER PLATE INDICATION
                                        text(TRACK.SubCenterP(iarea,ipoint,2)+TRACK.LowerPlateP(iarea,ipoint,2)*TriangleHeight*2,...
                                            TRACK.SubCenterP(iarea,ipoint,1)+TRACK.LowerPlateP(iarea,ipoint,1)*TriangleHeight*2,indZlevel,...
                                            'LP','BackgroundColor','w')
                                    end
                                    if PLOT.indicateUpperPlate %UPPER PLATE INDICATION
                                        text(TRACK.SubCenterP(iarea,ipoint,2)+TRACK.UpperPlateP(iarea,ipoint,2)*TriangleHeight*2,...
                                            TRACK.SubCenterP(iarea,ipoint,1)+TRACK.UpperPlateP(iarea,ipoint,1)*TriangleHeight*2,indZlevel,...
                                            'UP','BackgroundColor','w')
                                    end
                                end
                            end
                            %plot(TRACK.Subduction(iarea,:,2),TRACK.Subduction(iarea,:,1),'b.')
                            patch(TRACK.SubductionOut(iarea,~isnan(TRACK.SubductionOut(iarea,:,1)),2),... %make sure to only patch non-NaN values!
                                TRACK.SubductionOut(iarea,~isnan(TRACK.SubductionOut(iarea,:,1)),1),...
                                ones(size(TRACK.SubductionOut(iarea,~isnan(TRACK.SubductionOut(iarea,:,1)),1))).*indZlevel,...
                                colorBNDRY,'EdgeColor',colorBNDRYedge,'LineWidth',0.1,'FaceAlpha',BIndicationAlpha) %trench line
                        end
                    end
                    if PLOT.indicateRidge
                        TriangleHeight  = TriangleHeight/2;
                        TriangleWidth   = TriangleWidth/2;
                        %plot3(TRACK.Spreading(:,2),TRACK.Spreading(:,1),TRACK.Spreading(:,1).*indZlevel,'r')
                        for iarea=1:size(TRACK.Spreading,1)
                            indicateRidgeTriangles = logical(1);
                            if indicateRidgeTriangles
                                for ipoint=1:size(TRACK.SprCenterP,2) %loop only through characteristic points
                                    for ipair=1:2 %loop to produce a pair of indicators
                                        if ipair==1; dummy=1; else dummy=-1; end
                                        arPosX = [TRACK.SprCenterP(iarea,ipoint,1)-TRACK.SprStrikeP(iarea,ipoint,1)*TriangleWidth/2,...
                                            TRACK.SprCenterP(iarea,ipoint,1)+TRACK.SprStrikeP(iarea,ipoint,1)*TriangleWidth/2,...
                                            TRACK.SprCenterP(iarea,ipoint,1)+dummy*TRACK.SprNormalP(iarea,ipoint,1)*TriangleHeight]; %left right middle
                                        arPosY = [TRACK.SprCenterP(iarea,ipoint,2)-TRACK.SprStrikeP(iarea,ipoint,2)*TriangleWidth/2,...
                                            TRACK.SprCenterP(iarea,ipoint,2)+TRACK.SprStrikeP(iarea,ipoint,2)*TriangleWidth/2,...
                                            TRACK.SprCenterP(iarea,ipoint,2)+dummy*TRACK.SprNormalP(iarea,ipoint,2)*TriangleHeight]; %left right middle
                                        patch([arPosY(1,1) arPosY(1,2) arPosY(1,3)], ...
                                            [arPosX(1,1) arPosX(1,2) arPosX(1,3)],...
                                            [indZlevel indZlevel indZlevel],...
                                            PBmarkerFaceColour,'FaceAlpha',BIndicationAlpha,...
                                            'EdgeColor',colorBNDRYedge,'LineWidth',0.1); %ridge triangles
                                    end
                                end
                            end
                            %plot(TRACK.Spreading(iarea,:,2),TRACK.Spreading(iarea,:,1),'r.')
                            patch(TRACK.SpreadingOut(iarea,~isnan(TRACK.SpreadingOut(iarea,:,1)),2),... %make sure to only patch non-NaN values!
                                TRACK.SpreadingOut(iarea,~isnan(TRACK.SpreadingOut(iarea,:,1)),1),...
                                ones(size(TRACK.SpreadingOut(iarea,~isnan(TRACK.SpreadingOut(iarea,:,1)),1))).*indZlevel,...
                                colorSPR,'EdgeColor',colorBNDRYedge,'LineWidth',0.1,'FaceAlpha',BIndicationAlpha)
                        end
                    end
                    
                elseif strcmp(GRID.Dim,'2-D')
                    axis manual %freezes scaling at current limits (needed to not alter axis limits when patch indicators are slightly outside domain
                    BIndicationAlpha    = 0.5;
                    BIndicationBot      = 0;
                    BIndicationTop      = AxLim(1,4);
                    BIndicationHeight   = abs(BIndicationTop-BIndicationBot);
                    BIndicationWidth    = sqrt(4/3*BIndicationHeight^2); %gleichschenkliges Dreieck
                    if PLOT.indicateTrench
                        for ii=1:size(TRACK.Subduction,1)
                            arPosX = [TRACK.Subduction(ii,1)-BIndicationWidth/2, TRACK.Subduction(ii,1)+BIndicationWidth/2, TRACK.Subduction(ii,1)]; %left right bottom
                            arPosZ = [BIndicationTop, BIndicationTop, BIndicationBot]; %left right bottom
                            if ~isnan(TRACK.Subduction(ii,1)) && TRACK.Subduction(ii,1)>AxLim(1,1) && TRACK.Subduction(ii,1)<AxLim(1,2)
                                patch([arPosX(1,1) arPosX(1,2) arPosX(1,3)], ...
                                    [arPosZ(1,1) arPosZ(1,2) arPosZ(1,3)],...
                                    PBmarkerFaceColour,'FaceAlpha',BIndicationAlpha,...
                                    'EdgeColor',PBmarkerEdgeColour,'LineWidth',0.1);
                            end
                        end
                    end
                    if PLOT.indicateRidge
                        for ii=1:size(TRACK.Spreading,1)
                            arPosX = [TRACK.Spreading(ii,1)-BIndicationWidth/2, TRACK.Spreading(ii,1)+BIndicationWidth/2, TRACK.Spreading(ii,1)]; %left right top
                            arPosZ = [BIndicationBot, BIndicationBot, BIndicationTop]; %left right top
                            if ~isnan(TRACK.Spreading(ii,1)) && TRACK.Spreading(ii,1)>AxLim(1,1) && TRACK.Spreading(ii,1)<AxLim(1,2)
                                patch([arPosX(1,1) arPosX(1,2) arPosX(1,3)], ...
                                    [arPosZ(1,1) arPosZ(1,2) arPosZ(1,3)],...
                                    PBmarkerFaceColour,'FaceAlpha',BIndicationAlpha,...
                                    'EdgeColor',PBmarkerEdgeColour,'LineWidth',0.1);
                            end
                        end
                    end
                    if PLOT.indicateUpperPlate %UPPER PLATE INDICATION
                        for ii=1:size(TRACK.Subduction,1)
                            if TRACK.SubPolarity(ii,1)=='L' %left
                                text(TRACK.Subduction(ii,1)-hShift4indication,indicationDepth,'UP',...
                                    'Color',UPcolor,'HorizontalAlignment','right','VerticalAlignment','middle','FontSize',PLOT.PlateIndSize);
                            elseif TRACK.SubPolarity(ii,1)=='R' %right
                                text(TRACK.Subduction(ii,1)+hShift4indication,indicationDepth,'UP',...
                                    'Color',UPcolor,'HorizontalAlignment','left','VerticalAlignment','middle','FontSize',PLOT.PlateIndSize);
                            else
                                %nothing found
                            end
                        end
                    end
                    if PLOT.indicateLowerPlate %LOWER PLATE INDICATION
                        for ii=1:size(TRACK.Subduction,1)
                            if TRACK.SubPolarity(ii,1)=='L' %left
                                text(TRACK.Subduction(ii,1)+hShift4indication,indicationDepth,'LP',...
                                    'Color',LPcolor,'HorizontalAlignment','left','VerticalAlignment','middle','FontSize',PLOT.PlateIndSize);
                            elseif TRACK.SubPolarity(ii,1)=='R' %right
                                text(TRACK.Subduction(ii,1)-hShift4indication,indicationDepth,'LP',...
                                    'Color',LPcolor,'HorizontalAlignment','right','VerticalAlignment','middle','FontSize',PLOT.PlateIndSize);
                            else
                                %nothing found
                            end
                        end
                    end
                end
            end
%             if strcmp(SETUP.topBC,'free-slip') && izoom==1
%             else  %sticky air
%             end
            hold off
        end
        axes(AXcurrent)
        
        %% SAVING PLATE VELOCITY DATA ------------------------
        if SAVE.plateVelocityData && PLOT.loop_field==1
            SAVE.Directory              = FILE.directory;
            SAVE.DataName               = [FILE.name,'_platevel',num2str(FILE.number)];
            SAVE.data                   = [TRACK.PlateVelocity(:,1), GRID.x2d(:,1)]; %plate-V, x
            SAVE.dat                    = logical(0);
            SAVE.txt                    = logical(0);
            SAVE.mat                    = logical(1);
            SAVE.write2existing         = logical(0);
            f_saveDat( SAVE )
        end
        %% SET SAVING TIME DATA ---------------------
        if (SAVE.subductionZoneData || SAVE.plateVelocityData) && PLOT.loop_field==1
            SAVE.timeDat = true;
        end
        %% SAVING SUBDUCTION ZONE DATA ------------------------
        if SAVE.subductionZoneData && PLOT.loop_field==1 %%CHECK ALSO IF SUBDUCTION ZONE PRESENT
            % trench x-location, subduction polarity, trench/UP vel, LP vel, Convergence vel
            %'1': left, '2': right, or '0': unknown
            SAVE.Directory              = FILE.directory;
            SAVE.DataName               = [FILE.name,'_subZone',num2str(FILE.number)];
            SAVE.data                   = [TRACK.Subduction(:,1),TRACK.SubPolarityNum(:,1),...
                                            TRACK.UPvelocity,TRACK.LPvelocity,TRACK.PlateConvergence]; %nd or [km],[cm/a] 
            SAVE.dat                    = logical(0);
            SAVE.txt                    = logical(0);
            SAVE.mat                    = logical(1);
            SAVE.write2existing         = logical(0);
            f_saveDat( SAVE )
        end
    end
end


%% INSERT RECTANGLE INDICATING ZOOM PLOT
if isfield(PLOT,'zoom') && PLOT.zoom
    for i_rect=1:2
        hold on
        %rectangle('Position',[x,y,w,h]) %white bold in the back
        h_rectangle = rectangle('Position',[PLOT.zoomVal(PLOT.loop_case,1),...
            PLOT.zoomVal(PLOT.loop_case,3),...
            PLOT.zoomVal(PLOT.loop_case,2)-PLOT.zoomVal(PLOT.loop_case,1),...
            PLOT.zoomVal(PLOT.loop_case,4)-PLOT.zoomVal(PLOT.loop_case,3)]);
        h_rectangle.LineWidth = 0.5;
        h_rectangle.EdgeColor = [1 1 1];
        %rectangle('Position',[x,y,w,h])
        h_rectangle = rectangle('Position',[PLOT.zoomVal(PLOT.loop_case,1),...
            PLOT.zoomVal(PLOT.loop_case,3),...
            PLOT.zoomVal(PLOT.loop_case,2)-PLOT.zoomVal(PLOT.loop_case,1),...
            PLOT.zoomVal(PLOT.loop_case,4)-PLOT.zoomVal(PLOT.loop_case,3)]);
        h_rectangle.LineWidth = 0.25;
        h_rectangle.EdgeColor = [0 0 0];
    end
end


%% TRACK COMPOSITION
if SWITCH.trackC && strcmp(field_string,'composition')
    %find specified compostional field
    findCval = 1; %this is primordial material
    findRange = 0.5;
    Cfield  = var2d(var2d<findCval+findRange & var2d>findCval-findRange); %make small range instead of one exact findCvalue
    Cfieldx = x2d_plot(var2d<findCval+findRange & var2d>findCval-findRange);
    Cfieldz = z2d_plot(var2d<findCval+findRange & var2d>findCval-findRange);
    %find specified extreme of the compositional field
    %maximum height (at outermost left-hand side):
    maxValuesx  = Cfieldx(Cfieldz==min(Cfieldz(:))); %shallowest
    maxValx     = min(maxValuesx(:)); %most left
    maxValuesz  = Cfieldz(Cfieldz==min(Cfieldz(:))); %shallowest
    maxValz     = maxValuesz(maxValuesx(:)==maxValx);
    %create/add to data array
    if PLOT.number==SAVE.StartNum %first time
        %[dimensional time in years  /  x  /  z  ]
        PLOT.topCval = [ PLOT.time maxValx maxValz ];
    else
        PLOT.topCval = [ SAVE.topCval;  PLOT.time maxValx maxValz ];
    end
    %plot indication point
    hold on
    plot(PLOT.topCval(end,2),PLOT.topCval(end,3),'or')
    %save data
    if FILE.LastFile
        SAVE.Directory              = FILE.directory;
        SAVE.DataName               = ['+topCval_',FILE.name];
        SAVE.data                   = PLOT.topCval;
        SAVE.dat                    = logical(1);
        SAVE.txt                    = logical(0);
        SAVE.mat                    = logical(1);
        SAVE.write2existng          = logical(0);
        
        f_saveDat( SAVE )
    end
end


%==========================================================================
%% SAVE DATA
%==========================================================================
%% SAVING TIME DATA ---------------------
if SAVE.timeDat && PLOT.loop_field==1
    SAVE.Directory              = FILE.directory;
    SAVE.DataName               = [FILE.name,'_time',num2str(FILE.number)];
    SAVE.data                   = [PLOT.time, PLOT.time_dim*SETUP.secyear,PLOT.time_dim]; %[nd, seconds, years]
    SAVE.dat                    = logical(0);
    SAVE.txt                    = logical(0);
    SAVE.mat                    = logical(1);
    SAVE.write2existing         = logical(0);
    
    f_saveDat( SAVE )
end



%==========================================================================
%% STYLE PLOTS
%==========================================================================
figure(1)
%SIMPLIFY FIGURE
if SWITCH.simplify
    %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
    PLOT.spcurrent          = sub_current;
    PLOT.sp_chax            = AXcurrent;
    if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else PLOT.sp_chaxz = NaN; end
    PLOT.sp_ccb             = cb;           %colorbar handle
    PLOT.title              = title_plot;  	%title string
    
    [PLOT] = f_splayout(SWITCH,PLOT,GRID,FIELD);
end
%ADJUST TICK MARKS
set(gca,'Layer','top') % make sure axes ticks are visible
set(gca,'TickDir',SWITCH.tickDir) %set tickmarks out- or inside
if isfield(PLOT,'zoom') && PLOT.zoom
    axes(haxZ) %set zoom plot back on top
end
PLOT.layout         = sub_current(1,1:2);
if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else nr_hax = 1; end
PLOT.hax(nr_hax,1)  = AXcurrent;
if isfield(PLOT,'zoom') && PLOT.zoom
    if isfield(PLOT,'haxZ'); nr_haxZ = size(PLOT.haxZ,1)+1; PLOT.haxZ(nr_haxZ,1) = haxZ;
    else nr_haxZ = 1; PLOT.haxZ(nr_haxZ,1) = haxZ; end
end



%% FUNCTION OUTPUT
SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent]; %remember graph handles (main subplot)
if isfield(PLOT,'zoom') && PLOT.zoom
    SAVE.PlotHandles = [SAVE.PlotHandles; haxZ]; %remember graph handles (zoom subplot)
end















