%
%% plot Topography of STAGYY
%________________________________
% Fabio Crameri

function [topo2d,PLOT,SAVE] = f_plotTOPO(TOPO,FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE)

fname       = FILE.name;
number      = FILE.number;
directory   = FILE.directory;
TOPO.plotLineWidth = STYLE.keyLineWidth;

if TOPO.field && ~strcmp(FIELD.name,'topography') && ~strcmp(FIELD.name,'geoid')
    plotCMB 	= false;
    plotSURF	= true;
    Tfieldname  = 'topography';
elseif strcmp(FIELD.name,'topography')
    plotCMB 	= TOPO.cmb;
    plotSURF	= TOPO.surf;
    Tfieldname  = 'topography';
elseif strcmp(FIELD.name,'geoid')
    plotCMB     = TOPO.GEOIDcmb;
    plotSURF    = TOPO.GEOIDsurf;
    Tfieldname  = 'geoid';
else
    error('fc: unknown Tfieldname')
end

% READ TOPOGRAPHY ---------------------------------------------------
if TOPO.ascii  %topo from ascii file
    if number<10000
        number_string = num2str(10000+number);
        number_string(1)='0';
    else
        number_string = num2str(10000+number);
    end
    filename    = strcat(directory,fname,'_sc',number_string,'.dat');
    if ~exist(filename)        %else try:  _fstopo00000.dat
        filename    = strcat(directory,fname,'_fstopo',number_string,'.dat'); display('     -> _fstopo.dat used for topography!');
    end
    if ~exist(filename)  %else: _sc00000.dat
        filename    = strcat(directory,fname,'_cs',number_string,'.dat'); display('     -> _cs.dat used for topography!'); %try: _cs00000.dat
    end
    topo_dat = load(filename);
    %         topo_dat(:,2) = topo_dat(:,2)-mean(topo_dat(:,2)); % remove mean value  %!!!!!! neccessary ?????!!!!!!
    
    x = topo_dat(:,1);
    if strcmp(GRID.Dim,'2-D') %size(topo_dat,2)<4  %2-D
        %GRID.Dim = '2-D';
        x2d = x;
        topo2d(:,1) = topo_dat(:,3); %cmb topo
        topo2d(:,2) = topo_dat(:,2); %surf topo
    elseif strcmp(GRID.Dim,'3-D')
        %GRID.Dim = '3-D';
        y = topo_dat(:,2);
        topo2d(:,1) = topo_dat(:,4); %cmb topo
        topo2d(:,2) = topo_dat(:,3); %surf topo
    end
    
else  %topo from outputfile
    % Read topo information
    [~, X_3D, Y_3D, ~,TOPO_3D, time, ~]     = f_ReadStagYY(directory,fname,number,Tfieldname,SWITCH.Precision);
    if PLOT.YZ_2Dcartesian; %exchange x and y
        dummy_3D = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
        dummy_3Dx = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
        dummy_3D(:,1,:)     = TOPO_3D(1,:,:); TOPO_3D = dummy_3D;
        dummy_3Dx(:,1,:)    = X_3D(1,:,:);
        dummy_3D(:,1,:)     = Y_3D(1,:,:); Y_3D = dummy_3Dx; X_3D = dummy_3D;
    end
    if strcmp(GRID.Type,'cartesian')
        if strcmp(GRID.Dim,'2-D')
            x2d = X_3D(:,1,1);
            y2d = Y_3D(1,:,1)';
            topo2d(:,:) = TOPO_3D(:,1,:);
        elseif strcmp(GRID.Dim,'3-D')
            x2d(:,:) = X_3D(:,1,1);
            y2d(:,:) = Y_3D(1,:,1)';
            topo2d(:,:,:) = TOPO_3D(:,:,:);
        end
    elseif strcmp(GRID.Type,'cylindrical')
        x2d = Y_3D(1,:,1)';
        y2d = X_3D(:,1,1);
        topo2d(:,:) = TOPO_3D(1,:,:);
    end
%     %actually not needed - just to be sure:  %might only be correct for 2-D?
%     topo2d(:,1) = topo2d(:,1)-mean(topo2d(:,1));    % remove mean value (CMB topo)
%     topo2d(:,2) = topo2d(:,2)-mean(topo2d(:,2));    % remove mean value (surf topo)
end

nloopComp = 1;
if SWITCH.plotDifference
    if ~isfield(PLOT,'topo2d_A') %for odd cases/snapshots
        PLOT.topo2d_A = topo2d;
        return  %end execution of function here
    else
        if strcmp(TOPO.difference,'diff')
            topo2d_diff = PLOT.topo2d_A - topo2d;
            topo2d = topo2d_diff;
            clearvars topo2d_diff
            PLOT = rmfield(PLOT,'topo2d_A');
        elseif strcmp(TOPO.difference,'comp')
            nloopComp = 2;
        else
            error(['TOPO.difference = ',TOPO.difference,' not available!'])
        end
    end
end

for iloopComp = 1:nloopComp
    if SWITCH.plotDifference && strcmp(TOPO.difference,'comp')
        if iloopComp==1
            PLOT.topo2d_B = topo2d;
            topo2d = PLOT.topo2d_A;
        else
            topo2d = PLOT.topo2d_B;
        end
    end
    topo_smooth_2 = zeros(size(topo2d));
    topo_smooth_1 = topo2d;

    %% SMOOTHING
    if strcmp(GRID.Dim,'2-D')
        %------------------------
        % SMOOTHING 2-D
        %------------------------
        smoothingMethod = 3;
        if smoothingMethod==1 %DOESN'T WORK FOR 2-D YET!!!!!!!!! TOPO BECOMES SMALL!?
            filterSize = 5; %has to be an odd number!!!!
            %F = [.05 .1 .05; .1 .4 .1; .05 .1 .05]; %filter
            %F = [1/9 1/9 1/9; 1/9 1/9 1/9; 1/9 1/9 1/9]; %like 2-D filter - with one loop!
            F = fspecial('gaussian',filterSize); %filterSize is the size of matrix
            F = F(:,ceil(end/2)); %convert for 2D
            
            %add ghost points to prevent side effects from smoothing
            dummy = topo_smooth_1; %surf and cmb
            for ii=1:filterSize
                dummy = [dummy(1,:); dummy; dummy(end,:)];
            end
            topo_smooth_2 = zeros(size(dummy));
            %smoothing
            for jj=1:17
                topo_smooth_2(:,1) = conv(dummy(:,1),F,'same');
                topo_smooth_2(:,2) = conv(dummy(:,2),F,'same');
                dummy = topo_smooth_2;
            end
            %remove ghostpoints
            topo_smooth_2 = dummy(filterSize+1:end-filterSize,:);
            
        elseif smoothingMethod==2
            for jj=1:2
                topo_smooth_2(:,1) = smooth(topo_smooth_1(:,1),5,'loess');
                topo_smooth_2(:,2) = smooth(topo_smooth_1(:,2),5,'loess');
                topo_smooth_1 = topo_smooth_2;
            end
        elseif smoothingMethod==3
            for jj=1:2
                topo_smooth_2(:,1) = smooth(topo_smooth_1(:,1),5,'moving');
                topo_smooth_2(:,2) = smooth(topo_smooth_1(:,2),5,'moving');
                topo_smooth_1 = topo_smooth_2;
            end
        end
        topo_smooth = topo_smooth_2;
        %------------------------
        if (plotCMB && plotSURF)
            % nothing to be done
        elseif (plotCMB)
            topo2d(:,2)=[];
            topo_smooth(:,2)=[];
        elseif (plotSURF)
            topo2d(:,1)=[];
            topo_smooth(:,1)=[];
        end
        
    elseif strcmp(GRID.Dim,'3-D')
        if TOPO.ascii
            if (plotCMB && plotSURF)
                display('only one topography plot available at once!! -fc')
                z = topo2d(:,2); %surf topo
            elseif (plotCMB)
                z = topo2d(:,1); %cmb topo
            elseif (plotSURF)
                z = topo2d(:,2); %surf topo
            end
            low = min(x); high = max(x); tix = low:0.01:high;
            low = min(y); high = max(y); tiy = low:0.01:high;
            
            [xi,yi] = meshgrid(tix,tiy);
            topo_PLOT = griddata(x,y,z,xi,yi);
        else
            if (plotCMB && plotSURF)
                display('only one topography plot available at once!! -fc')
                topo_PLOT = topo2d(:,:,2); %surf topo
            elseif (plotCMB)
                topo_PLOT = topo2d(:,:,1); %cmb topo
            elseif (plotSURF)
                topo_PLOT = topo2d(:,:,2); %surf topo
            end
        end
        if SWITCH.plotTOPOsmooth
            %------------------------
            % SMOOTHING 3-D
            %------------------------
            smoothingMethod = 1;
            if smoothingMethod==1
                filterSize = 5;
                %F = [.05 .1 .05; .1 .4 .1; .05 .1 .05]; %filter
                %F = [1/9 1/9 1/9; 1/9 1/9 1/9; 1/9 1/9 1/9]; %like 2-D filter - with one loop!
                F = fspecial('gaussian',filterSize); %filterSize is the size of matrix
                %F = fspecial('gaussian');
                
                %add ghost points to prevent side effects from smoothing
                dummy = topo_PLOT;
                for ii=1:filterSize
                    dummy = [dummy(1,:); dummy; dummy(end,:)];
                    dummy = [dummy(:,1), dummy, dummy(:,end)];
                end
                %smoothing
                for jj=1:17
                    topo_PLOTsmooth = conv2(dummy,F,'same');
                    dummy = topo_PLOTsmooth;
                end
                %remove ghostpoints
                topo_PLOTsmooth = dummy(filterSize+1:end-filterSize,filterSize+1:end-filterSize);
                
            elseif smoothingMethod==2 
                %according to smooth2a
                Nr = 3; %rows
                Nc = 3; %colums
                % You end up replacing element "i" by the mean of a (2*Nr+1)-by-
                % (2*Nc+1) rectangle centered on element "i".
                [row,col] = size(topo_PLOT);
                eL = spdiags(ones(row,2*Nr+1),(-Nr:Nr),row,row);
                eR = spdiags(ones(col,2*Nc+1),(-Nc:Nc),col,col);
                % Setting all "NaN" elements of "matrixIn" to zero so that these will not
                % affect the summation.  (If this isn't done, any sum that includes a NaN
                % will also become NaN.)
                A = isnan(topo_PLOT);
                topo_PLOT(A) = 0;
                % For each element, we have to count how many non-NaN elements went into
                % the sums.  This is so we can divide by that number to get a mean.  We use
                % the same matrices to do this (ie, "eL" and "eR").
                nrmlize = eL*(~A)*eR;
                nrmlize(A) = NaN;
                % Actually taking the mean.
                topo_PLOTsmooth = eL*topo_PLOT*eR;
                topo_PLOTsmooth = topo_PLOTsmooth./nrmlize;
            end
        end
    end
     
    %% DIMENSIONALISATION
    if strcmp(GRID.Dim,'2-D')
        x_PLOT          = x2d(:,1)      *GRID.dimFactor;
        topo_PLOT       = topo2d        *GRID.dimFactor;
        topoSmooth_PLOT = topo_smooth   *GRID.dimFactor;
    else
        x_PLOT          = x2d(:,1)      *GRID.dimFactor;
        y_PLOT          = y2d(:,1)      *GRID.dimFactor;
        topo_PLOT       = topo_PLOT  	*GRID.dimFactor;
        topo_PLOTsmooth = topo_PLOTsmooth *GRID.dimFactor;
    end
    
    if strcmp(FIELD.name,'topography')
        %% COUNT SUBPLOTS
        if iloopComp==1 
            PLOT.nr_subplot = PLOT.nr_subplot+1;
            nr_subplot = PLOT.nr_subplot; 
        end
        
        %% TITLE STRING & TIME
        fieldString1 = 'topography @ '; if PLOT.titleOnlyTime; fieldString1 = ''; end
        if SWITCH.dim || SWITCH.dimensional_input
            title_plot  = [fieldString1,num2str(PLOT.time2plot,3),' ',PLOT.time2plotDim];
        else
            title_plot  = [fieldString1,num2str(time,3),' '];
        end
        if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
        if ~isfield(SAVE,'AllFilesTitleString');
            SAVE.AllFilesTitleString = title_plot;
        else
            SAVE.AllFilesTitleString = [SAVE.AllFilesTitleString, {title_plot}];
        end
        
        %% FIGURE...
        figure(1)
        
        %% SUBPLOT LAYOUT...
        if iloopComp==1;
            if isfield(PLOT,'subplotLayout') %manual arrangement
                sub_current=[PLOT.subplotLayout(1,1),PLOT.subplotLayout(1,2),nr_subplot];
            else
                if PLOT.nrPlots>=4
                    if mod(PLOT.nrPlots,2)
                        sub_current=[(PLOT.nrPlots+1)/2 2 nr_subplot];
                    else
                        sub_current=[PLOT.nrPlots/2 2 nr_subplot];
                    end
                else
                    sub_current=[PLOT.nrPlots 1 nr_subplot];
                end
            end
            if PLOT.reverseLayout %top-down plotting
                if ~isfield(PLOT,'layoutNum')
                    PLOT.layoutNum = zeros(sub_current(1,1),sub_current(1,2));
                    idx = 0;
                    for ii=1:size(PLOT.layoutNum,1)
                        for jj=1:size(PLOT.layoutNum,2)
                            idx = idx+1;
                            PLOT.layoutNum(ii,jj) = idx;
                        end
                    end
                    idx = 0; PLOT.layoutNumTransposed = PLOT.layoutNum;
                    for jj=1:size(PLOT.layoutNum,2)
                        for ii=1:size(PLOT.layoutNum,1)
                            idx = idx+1;
                            PLOT.layoutNumTransposed(ii,jj) = idx; %transposed layout
                        end
                    end
                end
                %UPDATE TO NEW LAYOUT
                %       while PLOT.nr_subplot is still setup the old way!
                nr_subplot = PLOT.layoutNum(PLOT.layoutNumTransposed==nr_subplot);
                sub_current(1,3) = nr_subplot;
            end
            %% SUBPLOT
            if SWITCH.PlotInPlot && isfield(SAVE,'PlotInPlot_Topo_hax')
                SAVE.PlotInPlot_Topo_hax %needed to prevent erasing subplot
                hold on
            else
                subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3));
            end
            
            %% CURRENT AXIS
            AXcurrent = gca; %save current axes handle
        end
        
        %% SETUP PLOTTING VARIABLES
        if strcmp(GRID.Dim,'2-D')   % 2-D
%             x_PLOT          = x2d(:,1)*GRID.dimFactor;
%             topo_PLOT       = topo2d*GRID.dimFactor;
%             topoSmooth_PLOT = topo_smooth*GRID.dimFactor;
            if iloopComp==1;
                topoCOLOUR0 = STYLE.keyLineColor;
                topoCOLOUR  = STYLE.keyLineColor;
                topoOPACITY = 0.7;
            else
                topoCOLOUR0 = [0.7 0.2 0.2];
                topoCOLOUR  = [0.7 0.2 0.2];
                topoOPACITY = 0.4;
            end
            if SWITCH.PlotInPlot
                topoCOLOUR0 = PLOT.gradColor4File;
                topoCOLOUR  = PLOT.gradColor4File;
            end
            
            %% SAVING TOPOGRAPHY ------------------------
            if TOPO.saveData
                SAVE.Directory              = FILE.directory;
                SAVE.DataName               = [FILE.name,'_topo',num2str(FILE.number)];
                SAVE.data                   = [x_PLOT, topo_PLOT, topoSmooth_PLOT]; %[x, topo, topo_smooth]
                SAVE.dat                    = logical(0);
                SAVE.txt                    = logical(0);
                SAVE.mat                    = logical(1);
                SAVE.write2existing         = logical(0);
                f_saveDat( SAVE )
            end
            
            %% PLOTTING TOPOGRAPHY ----------------------------------------------
            if SWITCH.plotTOPOtrue; i_start=1; else i_start=2; end
            if SWITCH.plotTOPOsmooth; i_end=2; else i_end=1; end
            
            %plot topo
            for i_topo=i_start:i_end
                if i_topo==1 %plot true topo
                    topo2plot   = topo_PLOT;
                    color2plot  = topoCOLOUR0;
                elseif i_topo==2 %plot smooth topo
                    topo2plot   = topoSmooth_PLOT;
                    color2plot  = topoCOLOUR;
                end
                if TOPO.water && ~strcmp(TOPO.areaFill,'updown') %add water layer
                    colorWater = [0.4 0.6 0.7]; alphaWater = 0.2;
                    if strcmp(STYLE.colorMode,'black');
                        colorWater = [0.4 0.6 0.7]; alphaWater = 0.7;
                    end
                    topoNegative = topo2plot';
                    topoNegative(topo2plot>=0) = NaN; %remove positive topo values
                    if max(isnan(topoNegative))==1 %if there are NaNs
                        %seperate the two lines
                        NanLocations = find(isnan(topoNegative));
                        NanLocations = [0 NanLocations size(topoNegative,2)+1]; %add start and end point
                        nLineSegment = size(NanLocations,2)-1;
                        for iLineSegment=1:nLineSegment
                            startLoc = NanLocations(1,iLineSegment) +1;
                            endLoc = NanLocations(1,iLineSegment+1) -1;
                            if endLoc<=startLoc+1; continue; end %skip this one: no line in between
                            
                            S_xpoints = x_PLOT(startLoc:endLoc,1)';
                            S_upper = topoNegative(1,startLoc:endLoc);
                            S_lower = zeros(size(S_upper));
                            
                            fill([min(S_xpoints); S_xpoints'; max(S_xpoints)],[min(S_lower); S_upper'; min(S_lower)],...
                                colorWater,'EdgeColor','none','FaceAlpha',alphaWater);
                            hold on
                        end
                    end
                end

                if ~SWITCH.GraphVsTimePlot %plot topo graph
                    
                    PLOT.TOPOhLine = plot(x_PLOT,topo2plot,'Color',color2plot,'LineWidth',TOPO.plotLineWidth);
                    hold on
                                
                elseif SWITCH.GraphVsTimePlot %remember x and topo for graph vs. time plot
                    if SAVE.LastFile; SAVE.graphX = x_PLOT'; end
                    if ~isfield(SAVE,'graphTopo'); 
                        SAVE.graphTopo = topo2plot'; 
                        SAVE.graphTime	= PLOT.time;
                    else
                        SAVE.graphTopo  = [SAVE.graphTopo; topo2plot'];
                        SAVE.graphTime	= [SAVE.graphTime; PLOT.time]; %non-dimensional time
                    end
                    if SAVE.LastFile
                        SAVE.graphTime = SAVE.graphTime.*PLOT.timeConvert; %make dimensional according to last automatic time dimension
                        contourf(SAVE.graphX,SAVE.graphTime,SAVE.graphTopo,PLOT.numContours,'LineColor','none');
                        cb=colorbar;
                        if SWITCH.Colorbar(1,2); set(gca,'clim',[-max(abs(SAVE.graphTopo(:))),max(abs(SAVE.graphTopo(:)))]); end %constant cb
                        if SWITCH.dim || SWITCH.dimensional_input; title(cb,'topography [km]'); else title(cb,'topography [nd]'); end
                    end
                end
                
                if ~strcmp(TOPO.areaFill,'none')
                    xpoints = x_PLOT;
                    upper = topo2plot;
                    if strcmp(TOPO.areaFill,'down')
                        color = color2plot;
                        lower = zeros(size(upper))+(min(upper)-1/10*(max(upper)-min(upper)));
                        if TOPO.both; PLOT.topoLOWval = lower(1,1); lower = zeros(size(upper))-50; end %set very low to be deeper than dynamic topo low
                        if SWITCH.Colorbar(1,2); lower = zeros(size(upper))+FIELD.cColorbarMIN; end %constant axis min/max
                        if SWITCH.plotDifference && strcmp(TOPO.difference,'diff'); lower = lower*0; end %in relation to 0 topography
                    
                    elseif strcmp(TOPO.areaFill,'updown')
                        color = color2plot;
                        lower = zeros(size(upper));
                    else
                        error(['TOPO.areaFill mode ',TOPO.areaFill,'not recognised!'])
                    end
                    
                    PLOT.TOPOhArea(iloopComp,1) = fill([min(xpoints); xpoints; max(xpoints)],[min(lower); upper; min(lower)],color,'EdgeColor','none','FaceAlpha',topoOPACITY);
                end
            end
            
            %------------------------------------------------------------------
            %% ANNOTATIONS
            if iloopComp==1;
                xlabel(['width [',GRID.Xdim,']']); 
                ylabel(['topography [',GRID.Zdim,']']); 
                if SWITCH.GraphVsTimePlot
                    ylabel(['time [',PLOT.time2plotDim,']']);
                end
                if SWITCH.title
                    if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
                    if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
                        htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
                    else
                        htitle = title(title_plot); %centered
                    end
                    if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.nr_subplot,:)); end
                end
                axis tight
                if SWITCH.Colorbar(1,2) && ~SWITCH.GraphVsTimePlot; ylim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
                if SWITCH.setAxisLimit
                    if size(SWITCH.axisLimit,1)>1  %more than one axis-zoom value
                        xlim(SWITCH.axisLimit(PLOT.loop_case,1:2));
                    else
                        xlim(SWITCH.axisLimit(1,1:2));
                    end
                end             
%                 set(AXcurrent,'YGrid','on') %only horizontal grid
                if ~SWITCH.GraphVsTimePlot; grid on; end
                box on
                %set tickmarks out- or inside
                set(gca,'TickDir',SWITCH.tickDir)
                
                if SWITCH.texting
                    text(min(xlim),max(ylim),['min val: ',num2str(min(topo_PLOT(:)),2),'   (',num2str(min(topoSmooth_PLOT(:)),2),')'],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
                    text(max(xlim),max(ylim),['max val: ',num2str(max(topo_PLOT(:)),2),'   (',num2str(max(topoSmooth_PLOT(:)),2),')'],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
                    display(['   max.topo: ',num2str(max(topo_PLOT)),' / min.topo: ',num2str(min(topo_PLOT))])
                    % ...and smooth
                    display(['   max.topo_smooth: ',num2str(max(topoSmooth_PLOT)),' / min.topo_smooth: ',num2str(min(topoSmooth_PLOT))])
                end
                
                if SWITCH.plotDifference && iloopComp==nloopComp %only for difference plot
                    if isfield(PLOT,'titleString')
                        legend(PLOT.TOPOhArea,PLOT.titleString{1,:},'Location','southeast','Interpreter','none') %area
                    else
                        legend(PLOT.TOPOhArea,SWITCH.fname_vector,'Location','southeast','Interpreter','none') %area
                    end
                    
                elseif SWITCH.PlotInPlot && ~SWITCH.GraphVsTimePlot %only for plot in plot
                    SAVE.PlotInPlot_Topo_hax = gca; %needed for next file plot to find the subplot
                    if ~isfield(SAVE,'AllFilesTOPOhLine');
                        SAVE.AllFilesTOPOhLine = PLOT.TOPOhLine; %Remember topo handles for all individual files
                    else
                        SAVE.AllFilesTOPOhLine = [SAVE.AllFilesTOPOhLine, PLOT.TOPOhLine]; %Remember topo handles for all individual files
                    end
                    if SAVE.LastFile
                        if isfield(PLOT,'titleString') %only for last one
                            legend(SAVE.AllFilesTOPOhLine,PLOT.titleString{1,:},'Location','southeast')
                        else
                            if size(SAVE.AllFilesTitleString,2)>4
                                legString = [SAVE.AllFilesTitleString(1,1), SAVE.AllFilesTitleString(1,end)];
                                legHandle = [SAVE.AllFilesTOPOhLine(1,1), SAVE.AllFilesTOPOhLine(1,end)];
                            else
                                legString = SAVE.AllFilesTitleString; legHandle = SAVE.AllFilesTOPOhLine;
                            end
                            legend(legHandle,legString,'Location','southeast')
                        end
                    end
                end
            end
            
        elseif strcmp(GRID.Dim,'3-D') 
            %% 3-D
            if SWITCH.plotTOPOtrue && SWITCH.plotTOPOsmooth
                n_start     = 1;
                n_end       = 2;
            elseif SWITCH.plotTOPOtrue
                n_start     = 1;
                n_end       = 1;
            elseif SWITCH.plotTOPOsmooth
                n_start     = 2;
                n_end       = 2;
            end
            for i_field=n_start:n_end
                if SWITCH.plotTOPOtrue && SWITCH.plotTOPOsmooth
                    subplot(2,1,i_field)
                end
                if i_field==1 %plot topo
                    topo2plot = topo_PLOT;
                elseif i_field==2 %plot topo smooth
                    topo2plot = topo_PLOTsmooth;
                end
                if SWITCH.plot3Dtopo2D %2-D plot
                    contourf(x_PLOT,y_PLOT,topo2plot',PLOT.numContours,'EdgeColor','none')
                
                else %3-D topography plot
                    surf(y_PLOT,x_PLOT,topo2plot,'EdgeColor','none')
                    % contour(xi,yi,zi)
                    set(gca,'ztick',[]); %remove z ticks
                    %set camera position
                    campos(PLOT.cameraPosition.*[1 1 -1]) %z-axis is not flipped
                    %set perspective mode
                    camproj(PLOT.camProjection)
                    % zlabel(['topography [',GRID.Xdim,']']);
                end
                axis tight
                axis equal
                box on
                title(title_plot) %TITLE
                xlabel(['y-width [',GRID.Xdim,']']); 
                ylabel(['x-width [',GRID.Ydim,']']);
                
                %INPUT here:
                plotTopoProfiles = logical(0); xprofLoc = []; yprofLoc = [140, 20]; %[50, 206] %in [#gridpoints]
                %-----------
                if plotTopoProfiles
                    colors4Profiles = [[0 0 0]; [0.5 0.5 0.5]; [0.3 0.3 1.0]; [1 0.3 0.3]; [0.6 0.6 0.3]; [0.3 1 0.3]; [0.5 0.5 0.5]];
                    % add profile lines to previous plots
                    hold on
                    if ~isempty(xprofLoc)
                        numProfx = size(xprofLoc,2);
                        profx = y_PLOT';
                        for iprof=1:numProfx
                            profx(1+iprof,:) = topo2plot(xprofLoc(1,iprof),:);
                            if SWITCH.plot3Dtopo2D %2-D plot
                                plot(y_PLOT*0+x_PLOT(xprofLoc(1,iprof),1),y_PLOT,'Color',colors4Profiles(iprof,:))
                            else
                                plot3(y_PLOT,y_PLOT*0+x_PLOT(xprofLoc(1,iprof),1),topo2plot(xprofLoc(1,iprof),:),'Color',colors4Profiles(iprof,:))
                            end
                        end
                    end
                    if ~isempty(yprofLoc)
                        numProfy = size(yprofLoc,2);
                        profy = x_PLOT';
                        for iprof=1:numProfy
                            profy(1+iprof,:) = topo2plot(:,yprofLoc(1,iprof));
                            if SWITCH.plot3Dtopo2D %2-D plot
                                plot(x_PLOT,x_PLOT*0+y_PLOT(yprofLoc(1,iprof),1),'Color',colors4Profiles(iprof,:))
                            else
                                plot3(x_PLOT*0+y_PLOT(yprofLoc(1,iprof),1),x_PLOT,topo2plot(:,yprofLoc(1,iprof)),'Color',colors4Profiles(iprof,:))
                            end
                        end
                    end
                    %new figure with actual profiles
                    figure(2)
                    SwitchPlotSeparately = logical(1); %plot separately for each file
                    if SwitchPlotSeparately; clf; end
                    set(gcf,'Position',[47 1 685 300]);
                    if exist('profx','var')
                        if exist('profy','var'); subplot(1,2,1); end
                        for iprof=2:size(profx,1)
                            hpr(iprof-1) = plot(profx(1,:),profx(iprof,:),'-','Color',colors4Profiles(iprof-1,:));
                            if iprof-1==1; dummy=1.25; else dummy=0.75; end
                            set(hpr(iprof-1),'LineWidth',dummy)
                            hold on
                        end
                    end
                    if exist('profy','var')
                        if exist('profx','var'); subplot(1,2,2); end
                        for iprof=2:size(profy,1)
                            hpr(iprof-1) = plot(profy(1,:),profy(iprof,:),'-','Color',colors4Profiles(iprof-1,:));
                            if iprof-1==1; dummy=1.25; else dummy=0.75; end
                            set(hpr(iprof-1),'LineWidth',dummy)
                            hold on
                        end
% %                         to save profile data:
%                         TOPO1.x = profy(1,:)
%                         TOPO1.y = profy(iprof,:)
%                         TOPO1.yLoc = y_PLOT(yprofLoc(1))
%                         save('~/Desktop/TOPO1.mat','TOPO1')
                    end
                    if SwitchPlotSeparately || SAVE.LastFile
                        axis tight
                        ylim([-8 5])
                        grid on
                        box on
                        xlabel('x-width [km]')
                        ylabel('topography [km]')
                        %legend(hpr,'thin UP-plate part','thick UP-plate part')
                        legend(hpr,['y = ',num2str(y_PLOT(yprofLoc(1)),4),' km'],['y = ',num2str(y_PLOT(yprofLoc(2)),4),' km'])
                        %pause(0.1) %let the figure time to adjust
                        f_figStyle(STYLE);
                        if logical(1) %SWITCH.fBackground
                            BACK.ApplyTo = 'current';          %'current', 'all'
                            f_plotBackground(BACK) %set plot background of each subplot
                        end
                        %SAVE FIGURE
                        if SAVE.Plot; SAVE.FigureNr=2; f_saveFig(SAVE); end
                    end
                    figure(1) %back to fig. 1
                end
            end
            if SWITCH.Colorbar(1,1) %colorbar switch
                cb=colorbar;
                if SWITCH.Colorbar(1,2) %constant colorbar
                    set(gca,'clim',[FIELD.cColorbarMIN,FIELD.cColorbarMAX])
                else
                    if SWITCH.MversionSupported; set(gca,'clim',cb.Limits); end
                end
                title(cb,['topography [',GRID.Zdim,']']); %on top
                %ylabel(cb,CBtitle_plot); %on left hand side
            end
%             if SWITCH.Colorbar(1,2) %constant colorbar
%                 if SWITCH.plot3Dtopo2D
%                     cb=colorbar;
%                     if SWITCH.Colorbar(1,2); set(gca,'clim',[-max(abs(SAVE.graphTopo(:))),max(abs(SAVE.graphTopo(:)))]); end %constant cb
%                     title(cb,['topography [',GRID.Zdim,']']);
%                 else
%                     zlim([FIELD.cColorbarMIN FIELD.cColorbarMAX]);
%                 end
%             end
            clearvars low high tix tiy
        end %3-D
        
        if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else nr_hax = 1; end
        %for function output:
        PLOT.hax(nr_hax,1)  = AXcurrent;
        
        %% FIGURE SIZE & POSITION ==================================
        figure(1)
        hold on
        
        %% COLORBAR ==================================
        if strcmp(GRID.Dim,'3-D') || SWITCH.GraphVsTimePlot && SAVE.LastFile
            %% SPECIFY COLORMAP FOR CURRENT AXES
            AXhandles(1) = AXcurrent;  %big plot axis handle
            if exist('haxZ','var');
                AXhandles(2) = haxZ; %zoom plot axis handle
                loop_zoom = 2;
            else
                loop_zoom = 1;
            end
            if ~exist('cb','var'); cb = colorbar; end
            PLOT.cb      = cb;      % colorbar handle
            for izoom=1:loop_zoom
                if ~PLOT.multipleColormap && izoom>1; continue; end
                PLOT.hax = AXhandles(izoom);
                [SWITCH] = f_colormap(SWITCH,PLOT);
            end
        else
            colorbar;   %define dummy colorbar
            cb = NaN; 	%this is a flag if no colorbar is used
        end
        
        %% SIMPLIFY FIGURE ==================================
        if SWITCH.simplify
            if strcmp(GRID.Dim,'2-D')
                %SET AXES ASPECT RATIO ----
                XaxisAR = GRID.aspectRatio(1);
                YaxisAR = GRID.aspectRatio(2);
                ZaxisAR = 1;
                set(gca,'PlotBoxAspectRatio',[XaxisAR YaxisAR ZaxisAR])
                %--------------------------
            end
            
            %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
            PLOT.spcurrent          = sub_current;
            PLOT.sp_chax            = AXcurrent;
            if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else PLOT.sp_chaxz = NaN; end
            PLOT.sp_ccb             = cb;   %colorbar handle
            PLOT.title              = title_plot;  	%title string
            
            [PLOT] = f_splayout(SWITCH,PLOT,GRID,FIELD);
        end
    end

end

%% adjust for function output
topo2d = topo_PLOT;

if strcmp(FIELD.name,'topography') %indicate axis handle as graph subplot
    SAVE.graphPlotHandles = [SAVE.graphPlotHandles; AXcurrent];
    SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent];
end

    

